*! v20220525 hw
/*---------------------------------------------------------*/
*! Researchproject: Inequality and Inceom Dynamics in Germany (GRID project)
*! Author: Hannes Walz
/*---------------------------------------------------------*/


// =============== Preamble ================ //

{
//--- Settings ---//

* clearing
clear all
program drop _all
macro drop _all
cap log close _all
clear matrix

* set
version 16.1
set more off, perm
set varabbrev off, perm
set matsize 10000, perm
set maxiter 1000, perm
set iterlog on, perm
set linesize 255
set pagesize 100
set rmsg off, perm
set trace on
set tracedepth 2
set traceexpand off, perm
set tracesep off, perm
set traceindent off, perm
set tracenumber off, perm    

* date
global mydate: di %td_CY-N-D date("$S_DATE", "DMY")
global mydate=strltrim("$mydate")

* seed
set seed 190424


//--- paths ---//

* checks
pwd 
sysdir

* paths
global root     = "...\" 	 				// !!! change main dir path here !!!
	global do     = "${root}`c(dirsep)'do`c(dirsep)'"
	global data     = "${root}`c(dirsep)'dta`c(dirsep)'"
	global log      = "${root}`c(dirsep)'log`c(dirsep)'"
	global orig     = "${root}`c(dirsep)'orig`c(dirsep)'"
	global figs     = "${root}`c(dirsep)'figs`c(dirsep)'"
	global out      = "${root}`c(dirsep)'out`c(dirsep)'"	
foreach dir in "log" "data" "figs" "out" {
	cap mkdir "$`dir'"
}
cd "${root}"

* main log path
global mainlog "${log}${mydate}"
cap mkdir "${log}${mydate}"

* set project ado dir
adopath ++ "${do}/"

*check ado paths
adopath
}

/*===========================================================================================*/
/*                                      Main Program                                         */
/*===========================================================================================*/
capture program drop main
program define main
	set matsize 4000
	set li 120 // 200
	set trace on
	set tracesep off
	set tracedepth 1 //2
  
	local time = subinstr("`=c(current_time)'",":","",.)
	scalar d = date("`=c(current_date)'","DMY") 	// create log file including time and date in file name
	local b  _`=subinstr("`c(current_date)'"," ","",.)'_`time'
	global logfile ${mainlog}/${mydate}_GRID_Germany_longer_samples.log
	log using $logfile , text replace name(longer_samples_`b')
	
	
	// =====================================
    // IAB Core Analysis
    // =====================================	

	* loop over long (1993-2018) and siab (1985-2018) sample
	foreach sam in "long" "siab" { 
		    
		* global settings
		global vsample="`sam'"
		global LP=10
		global wo_mini_inc_threshold=1
		global rvl=""
		* individual for long sample
		if ("`sam'"=="long") {
			global yrsample=1993
			global DATAFILEOPT="data" 
			global xlab_sample = "1993 1996 2000(3)2018"
			global cohorts = "1993 1997 2001 2005 2009 2013"
		}
		* individual for siab sample
		if ("`sam'"=="siab") {
			global yrsample=1985
			global DATAFILEOPT="siab" 
			global xlab_sample = "1985(5)2015 2018"
			global cohorts = "1985 1990 1995 2001 2005 2009 2013"		
		}
			
		* run initialize do file for all (additional) settings stuff
		do "${do}0_Initialize.do"		
			
		do "${do}1_Gen_Base_Sample.do"
			
		do "${do}3_Inequality_P85.do"
		do "${do}4_Volatility_P85.do"
			
		* run adjusted figures do file
		do "${do}7_Paper_Figs_P85.do"	
	}
	
	cap log longer_samples_`b'

end // main program

	
/*---------------------------------------------------------*/
/* Run Main Program */
/*---------------------------------------------------------*/
main // run main program

cap log close _all
set trace off
clear
exit

/*========================================= END ==============================================*/
