*! v20220525 hw
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This code specify country-specific variables.  
// This version Dec 04, 2020
//	Halvorsen, Ozkan, Salgado
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

// PLEASE DO NOT CHANGE VALUES FRM LINE 7 TO 20. IF NEEDS TO BE CHANGED, CONTACT Ozkan/Salgado

set more off
set matsize 500
set linesize 255
version 13  // This program uses Stata version 13. 

global begin_age = 25 		// Starting age
global end_age = 55			// Ending age
global base_price = 2018	// The base year nominal values are converted to real. 
global winsor=99.999999		// The values above this percentile are going to be set to this percentile. 
global noise=0.0			// Noise added to income. See line 112 in 1_Gen_Base_Sample.do


// PLEASE MAKE THE APPROPRIATE CHANGES BELOW. 																								
global wide=0  // Please change this to 1 if your raw data is in wide format; 0 if long.
																								
global sep=c(dirsep) 																				

// If there are missing observations for earnings between $begin_age and $end_age
// set the below global to 1. Otherwise, the code will convert all missing earnings
// observations to zero.
global miss_earn=0 

//Please change the below to the name of the actual data set
global datafile="${maindir}${sep}dta${sep}clean_yearly_$DATAFILEOPT.dta" 		// ! DATAFILEOPT == data (original), SIAB (75-18 SIAB sample), data_01perc (0,01% IEB test sample)	

// Define the variable names in your dataset.
global personid_var="persid" 	// The variable name for person identity number.
global male_var="male" 		// The variable name for gender: 1 if male, 0 o/w.
global yob_var="byear" 	// The variable name for year of birth.
global yod_var="dyear" 		// The variable name for year of death.
global educ_var="educ" 		// The variable name education										
global labor_var="earn_all_imputed" // The variable name for total annual labor earnings from all jobs during the year.  
global year_var="year" 		// The variable name for year if the data is in long format
global weight_var= "weight"
global weights = "[aw=${weight_var}]"

// Define these variables for your dataset
global yrfirst = ${yrsample} 		// First year in the dataset 									
global yrlast =  2018 		// Last year in the dataset 											

global kyear = 5
	// This controls the years for which the empirical densities will be calculated.
	// The densisity is calculated every mod(year/kyear) == 0. Set to 1 if 
	// every year is needed (If need changes, contact  Ozkan/Salgado)
	
global nquantiles = 40 //40
global nquantiles2 = 20 //40
	// Number of quantiles used in the statistics conditioning on permanent income
	// One additional quintile will be added at the top for a total of 41 (see Guidelines)
		
global nquantilemob = 40 //40
global nquantilemob2 = 20 //40
	// Number of quantiles used in the rank-rank mobility measures.
	
global qpercent = 99 //TPP: 99	
	// Top percentile for which the change in top-share will be calculated. 
	// In this case 99 implies top 1%. 
	// Calculations are made using  Matthieu Gomez's paper
	
global mergecohort = 5 //2
	// Number of cohorts to be merged to prevent too few observations in year/age cells 
	
global hetgroup = `"male age educ "male age" "male educ" "male educ age" "' 
global hetgroupsimple = "male age"
global hetgrouplabor_ineq = `"male "male agegp" "male age""'
global hetgrouplabor_vola = `"male "male agegp""'
	// Define heterogenous groups for which time series stats will be calculated 

global pctiles_selected 1 2.5 5(5)95 97.5 99	
	
// Lower bounds of bins used for earnings tabulation
global lbfine		0(500)80000 ///
								81000(1000)100000 ///
								105000(5000)150000 ///
								160000(10000)200000 ///
								250000(50000)500000 ///
								1000000
global lbfine2	-1e10 0 1 1000(1000)80000 82000(2000)100000 ///
								105000(5000)150000 ///
								160000(10000)200000 ///
								250000(50000)500000 ///
								1000000 2000000 5000000
global lbfine3	-1e10 0 1 2000(2000)100000 ///
								105000(5000)150000 ///
								160000(10000)200000 ///
								250000(50000)500000 ///
								1000000 2000000 5000000
								
global lbfine4	0 2300 3000(1000)100000 ///
								105000(5000)150000 ///
								160000(10000)200000 ///
								250000(50000)500000 ///
								1000000 2500000

global lbfine5	0 2300 4000(2000)100000 ///
								110000(10000)200000 ///
								250000(50000)500000 ///
								1000000
	
// Lower bounds of bins used for earnings mobility tabulation
global lbcoarse 0(10000)80000 100000 150000 250000 500000
	
// Price index for converting nominal values to real, e.g., the PCE for the US.  
// IMPORTANT: Please set the LOCAL CPI starting from year ${yrfirst} and ending in ${yrlast}.

global cpi2018 = 103.7756292715450		// Set the value of the CPI in 2018.
if "${vsample}"=="siab" {		
	matrix cpimat = ///  CPI between ${yrfirst}  and ${yrlast}
	( ///
	58.8119446907169  , /// 1985. Source: https://fred.stlouisfed.org/series/DEUCPIALLMINMEI#0 (folder: the data file with ending "(1).xlsx")
	58.7358338360608  , ///
	58.8826190557548  , ///
	59.6328546230795  , ///
	61.2909839566595  , ///
	62.9436768006212  , ///
	65.4910288078316  , ///
	68.8028970737547  , ///
	71.8815351801058  , ///
	73.8173455045538  , ///
	75.0767883662429  , ///
	76.1651957775791  , ///
	77.6423201215354  , ///
	78.3497849389040  , ///
	78.8084709193957  , ///
	79.9435243626463  , ///
	81.5294894477363  , ///
	82.6878659069441  , ///
	83.5430431587083  , ///
	84.9346497774882  , ///
	86.2485130097440  , ///
	87.6090222739143  , ///
	89.6225759848864  , ///
	91.9782005965641  , ///
	92.2658511267030  , ///
	93.2842894901676  , ///
	95.2200998146156  , ///
	97.1325871231064  , ///
	98.5941627897579  , ///
	99.4882117347841  , ///
	100.0000000000000  , ///
	100.4917486247710  , ///
	102.0086681113520  , ///
	103.7756292715450  /// 2018
	)'
}

if "${vsample}"=="long" {		
	matrix cpimat = ///  CPI between ${yrfirst}  and ${yrlast}
	( ///
	71.8815351801058  , /// 1993, Source: https://fred.stlouisfed.org/series/DEUCPIALLMINMEI#0
	73.8173455045538  , ///
	75.0767883662429  , ///
	76.1651957775791  , ///
	77.6423201215354  , ///
	78.3497849389040  , ///
	78.8084709193957  , ///
	79.9435243626463  , ///
	81.5294894477363  , ///
	82.6878659069441  , ///
	83.5430431587083  , ///
	84.9346497774882  , ///
	86.2485130097440  , ///
	87.6090222739143  , ///
	89.6225759848864  , ///
	91.9782005965641  , ///
	92.2658511267030  , ///
	93.2842894901676  , ///
	95.2200998146156  , ///
	97.1325871231064  , ///
	98.5941627897579  , ///
	99.4882117347841  , ///
	100.0000000000000  , ///
	100.4917486247710  , ///
	102.0086681113520  , ///
	103.7756292715450    /// 2018
	)'
}

if "${vsample}"=="short" | "${vsample}"=="short_rw" {		
	matrix cpimat = ///  CPI between ${yrfirst}  and ${yrlast}
	( ///
	81.5294894477363  , /// 2001
	82.6878659069441  , ///
	83.5430431587083  , ///
	84.9346497774882  , ///
	86.2485130097440  , ///
	87.6090222739143  , ///
	89.6225759848864  , ///
	91.9782005965641  , ///
	92.2658511267030  , ///
	93.2842894901676  , ///
	95.2200998146156  , ///
	97.1325871231064  , ///
	98.5941627897579  , ///
	99.4882117347841  , ///
	100.0000000000000  , ///
	100.4917486247710  , ///
	102.0086681113520  , ///
	103.7756292715450    /// 2018
	)'
}

matrix cpimat = cpimat/${cpi2018}

if "${vsample}"=="siab" {																	//!hw Only use this for long sample (FRED: CCUSSP01DEA650N), for short adjust to same excahnge rate values as TPP !
global exrate2018 = 0.873362445 		// Set the value the exchange rate from LC to 1US$ in 2018 (e.g. 1US$ = $(exrate2018) LC)
matrix exrate = /*  Nominal average exchange rate from FRED between ${yrfirst}  and ${yrlast} (LC per dollar)
*/ ( ///
1.25844382 , /// 1985
0.992316136 , ///
0.808608234 , ///
0.910253072 , ///
0.868070658 , ///
0.763870119 , ///
0.77511803 , ///
0.825224679 , ///
0.882642551 , ///
0.791889058 , ///
0.73293723 , ///
0.794956048 , ///
0.916285483 , ///
0.855390789 , ///
0.995421063 , ///
1.074691026 , ///
1.134687394 , ///
0.953561552 , ///
0.791765637 , ///
0.734160487 , ///
0.847673137 , ///
0.759301443 , ///
0.679301678 , ///
0.718545664 , ///
0.694155213 , ///
0.748390959 , ///
0.772857253 , ///
0.757920267 , ///
0.725110579 , ///
0.823655383 , ///
0.918526683 , ///
0.948676596 , ///
0.833819728 , ///
0.873362445 /// 2018
)'
} 

if "${vsample}"=="long" {																	//!hw Only use this for long sample, for short adjust to same excahnge rate values as TPP !
global exrate2018 = 0.873362445 		// Set the value the exchange rate from LC to 1US$ in 2018 (e.g. 1US$ = $(exrate2018) LC)
matrix exrate = /*  Nominal average exchange rate from FRED between ${yrfirst}  and ${yrlast} (LC per dollar)
*/ ( ///
0.882642551 , /// 1993
0.791889058 , ///
0.73293723 , ///
0.794956048 , ///
0.916285483 , ///
0.855390789 , ///
0.995421063 , ///
1.074691026 , ///
1.134687394 , ///
0.953561552 , ///
0.791765637 , ///
0.734160487 , ///
0.847673137 , ///
0.759301443 , ///
0.679301678 , ///
0.718545664 , ///
0.694155213 , ///
0.748390959 , ///
0.772857253 , ///
0.757920267 , ///
0.725110579 , ///
0.823655383 , ///
0.918526683 , ///
0.948676596 , ///
0.833819728 , ///
0.873362445  /// 2018
)'
} 																							//!hw

if "${vsample}"=="short" | "${vsample}"=="short_rw" {																	//!hw ->
global exrate2018 = 0.846241921 		// Set the value the exchange rate from LC to 1US$ in 2018 (e.g. 1US$ = $(exrate2018) LC)
matrix exrate = /*  Nominal average exchange rate from FRED between ${yrfirst}  and ${yrlast} (LC per dollar)
*/ ( ///
1.117066316 , /// 2001
1.057770717 , ///
0.883347458 , ///
0.803977049 , ///
0.803296138 , ///
0.795992763 , ///
0.729361091 , ///
0.679089513 , ///
0.717593192 , ///
0.754096857 , ///
0.717806315 , ///
0.77768111 , ///
0.752932989 , ///
0.75206585 , ///
0.901217901 , ///
0.903183741 , ///
0.884916439 , ///
0.846241921  /// 2018
)'
} 																							//!hw <-

// Define years for recession bars/ These will be used to generate a variable called rece used in the plots
/*global receyears = "1993,1993,1995,2002,2003,2004,2009,2010,2015"	*/								//!hw
/*global receyears = "1993,1995,1998,2001,2003,2004,2008,2009,2012,2014"	*/						//!hw (sync TPP)
global receyears = "1975, 1982,1993,2002,2003,2009"															//!hw (Vorschlag Johannes, angenommen auch von TPP)

// Define the year that will be use for normalization. 
global normyear = ${yrfirst}


/*DO NOT CHANGE THIS SECTION**********************************************
THIS SECTION DEFINES THE REAL EXCHANGE CHANGE USING THE LOCAL AND US CPI
*/
global cpi2018us = 108.231		// DO NOT CHANGE. This is the US PCE  
								// Annual average from https://fred.stlouisfed.org/series/PCEPI#0
matrix cpimatus = /*  PCE between 1970  and 2018
*/ (20.951, 21.841, 22.586, 23.802, 26.280, 28.470, 30.032, 31.986, 34.211, 37.250,  /*
*/ 41.262, 44.959, 47.456, 49.475, 51.343, 53.134, 54.290, 55.964, 58.150, 60.690,  /*
*/ 63.355, 65.473, 67.218, 68.892, 70.330, 71.811, 73.346, 74.623, 75.216, 76.338, /*
*/ 78.235, 79.738, 80.789, 82.358, 84.411, 86.813, 89.174, 91.438, 94.180, 94.094,  /*
*/ 95.705, 98.130, 100.000, 101.347, 102.868, 103.126, 104.235, 106.073, 108.231 )'

matrix cpimatus = cpimatus/${cpi2018us}

forvalues yr =  $yrfirst/$yrlast{
	local ee = `yr' - ${yrfirst} + 1
	local ii = `yr' - 1970 + 1
	matrix exrate[`ee',1] = exrate[`ee',1]*(cpimatus[`ii',1]/cpimat[`ee',1])
			// Coverting nominal exchange rate to real exchange rate
}
**********************************************

global set_rmininc = 3
// Set to 1: 
// If you want to use US min wages to create the minimum income threshold. 
// If your country does not have a minimum wage, and you want to use the US specific threshold
// then set set_rmininc = 1

// Set to 2:
// If your country has a minimum wage 

// Set to 3:
// If you want to use a percentage criterion or a particular custom value, then you need to specify those rmininc values below.



if ${set_rmininc} == 1{
	
	// CREATING MINIMUM INCOME THRESHOLD USING US MINIMUM WAGE  
	matrix minwgus = /* Nominal minimum wage 1959-2018 in the US
	*/ (1.00,1.00,1.00,1.15,1.15,1.25,1.25,1.25,1.25,1.40,1.60,1.60,1.60,1.60,/*
	*/  1.60,1.60,2.00,2.10,2.10,2.30,2.65,2.90,3.10,3.35,3.35,3.35,3.35,3.35,/*
	*/  3.35,3.35,3.35,3.35,3.80,4.25,4.25,4.25,4.25,4.25,4.75,5.15,5.15,5.15,/*
	*/  5.15,5.15,5.15,5.15,5.15,5.15,5.15,5.85,6.55,7.25,7.25,7.25,7.25,7.25,/*
	*/  7.25,7.25,7.25)'

	local yinic = ${yrfirst} - 1959 + 1						
	local yend = ${yrlast} - 1959 + 1

	matrix minincus = 260*minwgus[`yinic'..`yend',1]		// Nominal min income in the US
															// This uses the factor of 260 given in the Guidelines
	matrix rmininc = J(${yrlast}-${yrfirst}+1,1,0)
	local tnum = ${yrlast}-${yrfirst}+1

	forvalues i = 1(1)`tnum'{
		local ii = `i' + ${yrfirst} - 1970
		matrix rmininc[`i',1] = minincus[`i',1]*${exrate2018}/cpimatus[`ii',1]				
						// real min income threshold in local currency 
	}
	
}
else if ${set_rmininc} == 2{
	
	// CREATING MINIMUM INCOME THRESHOLD USING COUNTRY SPECIFIC MINIMUM WAGE  
	
	matrix minwg_C = /* Nominal minimum wage 1959-2018 in YOUR COUNTRY
	*/ (1.00,1.00,1.00,1.15,1.15,1.25,1.25,1.25,1.25,1.40,1.60,1.60,1.60,1.60,/*
	*/  1.60,1.60,2.00,2.10,2.10,2.30,2.65,2.90,3.10,3.35,3.35,3.35,3.35,3.35,/*
	*/  3.35,3.35,3.35,3.35,3.80,4.25,4.25,4.25,4.25,4.25,4.75,5.15,5.15,5.15,/*
	*/  5.15,5.15,5.15,5.15,5.15,5.15,5.15,5.85,6.55,7.25,7.25,7.25,7.25,7.25,/*
	*/  7.25,7.25,7.25)'

	// Change 1959 to the first year in your minwg_C matrix
	local yinic = ${yrfirst} - 1959 + 1	
	local yend = ${yrlast} - 1959 + 1

	matrix mininc_C = 260*minwg_C[`yinic'..`yend',1]		// Nominal min income in the US
															// This uses the factor of 260 given in the Guidelines
	matrix rmininc = J(${yrlast}-${yrfirst}+1,1,0)
	local i = 1
	local tnum = ${yrlast}-${yrfirst}+1
	forvalues pp = 1(1)`tnum'{
		matrix rmininc[`i',1] = 100*mininc_C[`i',1]/cpimat[`i',1]					
						// real min income threshold in local currency 
		local i = `i' + 1
	}
}	
else if ${set_rmininc} == 3{
	// CREATING MINIMUM INCOME THRESHOLD USING CUSTOM VALUES 
	// (E.G., the bottom 23% of the gender, combined earnings distribution, etc.)  
	// here: 260*min_wage=260*8.5=2210 [2015] (edit: 8.84*260=2298.4-> 2300 [2018]) )				//!hw
if ${wo_mini_inc_threshold}==0 { 																	//!hw
matrix rmininc = /* REAL MINIMUM INCOME THRESHOLD ${yrfirst}-${yrlast} in YOUR COUNTRY
*/	 (2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300,/*
	*/2300)'	
}	

// here: 6000 in 2015 (edit: 6250 in 2018) for excluding minijobs and slighly above (up to 500/month in 2015)			//!hw
if ${wo_mini_inc_threshold}==1 {																	//!hw
matrix rmininc = /* REAL MINIMUM INCOME THRESHOLD ${yrfirst}-${yrlast} in YOUR COUNTRY without mini jobs
*/	 (6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250, /*
	*/6250)'
}																									//!hw
}



// PLEASE DO NOT CHANGE THIS PART. IF NEEDS TO BE CHANGED, CONTACT Ozkan/Salgado


*global yrlist = ///
*	"${yrfirst} 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 ${yrlast}"
*	// Define the years for which the inequality and concetration measures are calculated

global  yrlist = ""
forvalues yr = $yrfirst(1)$yrlast{
	global yrlist = "${yrlist} `yr'"
}		
	
*global d1yrlist = ///
*	"1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012"
	// Define years for which one-year log-changes measures are calculated

global d1yrlist = ""
local tempyr = $yrlast-1
forvalues yr = $yrfirst(1)`tempyr'{
	global d1yrlist = "${d1yrlist} `yr'"
}
	
global d1yrlistcomma = "$yrfirst"
local tempyr = $yrlast-1
local tempyrb = $yrfirst+1
forvalues yr = `tempyrb'(1)`tempyr'{
	local tmp = ",`yr'"
	global d1yrlistcomma = "${d1yrlistcomma}`tmp'"
}
	
*global d5yrlist = ///
*	"1993,1994,1995,1996,1997,1998,1999,2000,2001,2002,2003,2004,2005,2006,2007,2008"
	// Define years t for which five-years log-changes between t+5 and t are calculated
	
global d5yrlist = "$yrfirst"
local tempyrb = $yrfirst+1
local tempyr = $yrlast-5
forvalues yr = `tempyrb'(1)`tempyr'{
	local tmp = ",`yr'"
	global d5yrlist = "${d5yrlist}`tmp'"
}	
	
*global perm3yrlist = /// 
*	"1995,1996,1997,1998,1999,2000,2001,2002,2003,2004,2005,2006,2007,2008,2009,2010,2011,2012,${yrlast}"
	// Define the ending years (t) to construct permanent income between t-2 and t 
	
local tempyrb = $yrfirst+2	
global perm3yrlist = "`tempyrb'"
local tempyrb = $yrfirst+3	
local tempyre = $yrlast
forvalues yr = `tempyrb'(1)`tempyre'{
	local tmp = ",`yr'"
	global perm3yrlist = "${perm3yrlist}`tmp'"
}	

global years_Hsample = ""
foreach yr of numlist $yrfirst/$yrlast {
  local yrp = `yr' - 1
	if inlist(`yr', $d5yrlist) & inlist(`yrp', $perm3yrlist) {
		global years_Hsample = "${years_Hsample} `yr'"
	}
}


