cap program drop append_and_export
program append_and_export
  syntax , filestub(string) years(numlist) [dataprivacy(string) var(string) *]
  // append annual files
  clear 
  foreach yr of numlist `years' {
    append using "`filestub'`yr'"
    //erase "`filestub'`yr'.dta"
  }
  // DATA PRIVACY
	local comma = cond("`options'" == "", "", ",")
	if "`dataprivacy'" == "" local dataprivacy data_privacy_sumstats
  if $protect == 1 `dataprivacy' `var' `comma' `options'
  // Export
  if substr("`filestub'", -1, .) == "_" local outstub = substr("`filestub'", 1, `= strlen("`filestub'") -1')
  else local outstub `filestub'
  export delimited using "`outstub'.csv", delimiter("$csvdelim") replace nolabel
  noi disp "save to CSV: $outfolder/`outstub'.csv"
end

cap program drop data_privacy_density
program define data_privacy_density
	local varname = "`1'"
	replace value_`varname' = . if N < 30
	replace density_`varname' = . if N < 30
	replace N = . if N < 30
end

cap program drop data_privacy_sumstats
program data_privacy_sumstats
	local varname = "`1'"
	foreach v of varlist mean* {
		cap replace `v' = . if N < 30 
	}
	cap replace min`varname' 		= .
	cap replace max`varname' 		= .
	cap replace mean`varname' 	= . if N < 30
	cap replace sd`varname' 		= . if N < 30
	cap replace m2`varname' = . if N < 30
	cap replace m3`varname' = . if N < 30
	cap replace m4`varname' = . if N < 30
	cap replace skew`varname' = . if N < 30
	cap replace kurt`varname' = . if N < 30
	cap replace gini`varname' = . if N < 30
	cap replace theil`varname' = . if N < 30
	foreach var of varlist p*`varname' {
		//local p = subinstr(substr("`var'", 2, .), "`varname'", "", .)
		//local p = subinstr("`p'", "_", ".", .)
		replace `var' = . if N < 30
		cap replace p25`varname' = . if (N < 80) | (N>=200 & N<400)
		cap replace p75`varname' = . if (N < 80) | (N>=200 & N<400)
		foreach pp of numlist 10(10)40 60(10)90 {
			cap replace p`pp'`varname' = . if N < 200
		}
		foreach pp of numlist 5 15 35(10)65 85 95 {
			cap replace p`pp'`varname' = . if N < 400
		}		
		foreach pp of numlist 1(1)4 6(1)9 91(1)94 96(1)99 {
			cap replace p`pp'`varname' = . if N < 2000
		}
		cap replace p0_5`varname' = . if N < 4000
		cap replace p99_5`varname' = . if N < 4000
		cap replace p0_1`varname' = . if N < 20000
		cap replace p99_9`varname' = . if N < 20000
		cap replace p0_01`varname' = . if N < 200000
		cap replace p99_99`varname' = . if N < 200000
		cap replace p0_001`varname' = . if N < 2000000
		cap replace p99_999`varname' = . if N < 2000000		
		// muss als letztes gecheckt werden wegen missing-conditions auf andere vars
		foreach pp in 2 97 {
			local ppp=`pp'+1
			local pppp=`pp'+2
			local mpp=`pp'-1
			gen marker=1
			replace marker=0 if N>=4000
			foreach e in mppe ppe pppe ppppe {
				local `e' =0
			}
			capture confirm variable p`mpp'`varname' 
			if _rc local mppe=1
			capture confirm variable p`pp'`varname' 
			if _rc local ppe=1
			capture confirm variable p`ppp'`varname' 
			if _rc local pppe=1
			capture confirm variable p`pppp'`varname'
			if _rc local ppppe=1
			if `mppe'==0 & `ppe'==0 & `ppp'==0 & `pppp'==0 replace marker=0 if N<4000 & N >=800
			if `mppe'==1 & `ppe'==0 & `ppp'==0 & `pppp'==0 replace marker=0 if N<4000 & N >=800 & mi(p`mpp'`varname')
			if `mppe'==1 & `ppe'==0 & `ppp'==0 & `pppp'==1 replace marker=0 if N<4000 & N >=800 & mi(p`pppp'`varname')
			if `mppe'==1 & `ppe'==0 & `ppp'==0 & `pppp'==1 replace marker=0 if N<4000 & N >=800 & mi(p`mpp'`varname') & mi(p`pppp'`varname')
			if `mppe'==0 & `ppe'==1 & `ppp'==1 & `pppp'==0 replace marker=0 if N<4000 & N >=800 & mi(p`pp'`varname') & mi(p`ppp'`varname')
			if `mppe'==1 & `ppe'==1 & `ppp'==1 & `pppp'==1 replace marker=0 if N<4000 & N >=800 & mi(p`mpp'`varname') & mi(p`pp'`varname') & mi(p`ppp'`varname') & mi(p`pppp'`varname')
			cap replace p`pp'_5`varname' = . if marker==1 
			drop marker
		}

	}
	cap replace sum_weights = . if N < 30
	replace N = . if N < 30
end

cap program drop data_privacy_mean
program data_privacy_mean
  foreach var of varlist mean* {
    replace `var' 	= . if N < 30
  }
	replace N = . if N < 30
	cap replace sum_weights = . if N == .
end

cap program drop data_privacy_obsbins
program data_privacy_obsbins
	cap replace n = . if obs < 30 // does not exist without weights
	foreach var of varlist mean* {
		cap replace `var' = . if obs < 30 
	}
	replace obs = . if obs < 30
end


cap program drop data_privacy_obsbinsmobp
program data_privacy_obsbinsmobp
	local var = "`1'"
	cap replace n = . if obs < 30 // does not exist without weights
	foreach v of varlist mean* {
		cap replace `v' = . if obs < 30 
	}
	replace sd_`var' 	= . if obs < 30 
	replace shareup_`var' 	= . if obs < 30 
	replace sharedown_`var' = . if obs < 30 
	replace sharestay_`var' = . if obs < 30 
	foreach v of varlist p*_`var' {
		local p = subinstr(substr("`v'", 2, .), "`var'", "", .)
		local p = subinstr("`p'", "_", ".", .)
		replace `v' = . if N`var' < max(30, ceil(100 / min(100-`p', `p') * 3))
	}

	replace obs = . if obs < 30
end


cap program drop data_privacy_hist
program data_privacy_hist
	qui: count
	local n = r(N)
	foreach var of varlist N_* {
		local suffix = substr("`var'", 3, .)
		replace den_`suffix' = . if `var' < `n' * 30
	}
end


cap program drop data_privacy_con
program data_privacy_con
	replace p20 = . if N < 30
	replace p40 = . if N < 30
	replace p50 = . if N < 30
	replace p60 = . if N < 30
	replace p80 = . if N < 30
	replace p90 = . if N < 30
	replace p95 = . if N < 60
	replace p99 = . if N < 300
	replace p995 = . if N < 600
	replace p999 = . if N < 3000
	replace p9999 = . if N < 30000
	replace q1share = . if N < 30
	replace q2share = . if N < 30
	replace q3share = . if N < 30
	replace q4share = . if N < 30
	replace q5share = . if N < 30
	replace bot50share = . if N < 30
	replace top10share = . if N < 30
	replace top5share = . if N < 60
	replace top1share = . if N < 300
	replace top05share = . if N < 600
	replace top01share = . if N < 3000
	replace top001share = . if N < 30000
	replace top10metop90 = . if N < 30
	replace top5metop95 = . if N < 60
	replace top1metop99 = . if N < 300
	replace top05metop995 = . if N < 600
	replace top01metop999 = . if N < 3000
	replace top001metop9999 = . if N < 30000
	replace Ntop10 = . if N < 30
	replace Ntop5 = . if N < 60
	replace Ntop1 = . if N < 300
	replace Ntop05 = . if N < 600
	replace Ntop01 = . if N < 3000
	replace Ntop001	= . if N < 30000
	replace gini = . if N < 30
	replace N = . if N < 30
	cap replace sum_weights = . if N == .
end

cap program drop data_privacy_idex
program data_privacy_idex
	foreach var of varlist N* {
		local suffix = substr("`var'", 2, .)
		replace t`suffix' = . if N`suffix' < 10
		replace me`suffix' = . if N`suffix' < 10
		replace N`suffix' = . if N`suffix' < 10
	}
end

cap program drop data_privacy_gStPop
program data_privacy_gStPop
	replace St = . if N < 30
	replace Stp = . if N < 30
	replace gSt = . if N < 30
	replace Rwithin = . if N < 30
	replace Rdispla = . if N < 30
	replace Rretir = . if N < 30
	replace Rgrowth = . if N < 30
	replace N = . if N < 30
	cap replace sum_weights = . if N == .
end


cap program drop data_privacy_kurperc
program data_privacy_kurperc
	replace sd = . if N < 30
	replace sharep_m5top5 = . if N < 30
	replace sharep_m10top10 = . if N < 30
	replace sharep_m20top20 = . if N < 30
	replace sharep_m5tosd = . if N < 30
	replace sharep_sdto2sd = . if N < 30
	replace sharep_2sdto3sd = . if N < 30
	replace share_3sdp = . if N < 30
	replace sharep_msdtom5 = . if N < 30
	replace sharep_m2sdtomsd = . if N < 30
	replace sharep_m3sdtom2sd = . if N < 30
	replace sharem_3sdm = . if N < 30
	replace N 			= . if Nobs < 30
end

cap program drop data_privacy_mobstat
program data_privacy_mobstat
	foreach var of varlist N* {
		local suffix = substr("`var'", 2, .)
		replace mean`suffix' = . if N`suffix' < 30
		replace N`suffix' = . if N`suffix' < 30
	}
end
