*! v20211215 hw
********************************************************************************
* This program generates the core figures for the draft						   *
* This version January 11, 2020												   *
* Serdar Ozkan and Sergio Salgado											   *
********************************************************************************
*------------------------------------------------------------------------------*

*** Preamble
{

* clear 
clear
set more off

* set dirs dep on user
if "${curr_user}"=="IAB" { 															
	global maindir ="${root}"+"${sep}"
}
else{
	global maindir ="/Users/johannes/Dropbox/Research/Global_Income_Dynamics/Stata"
} 						 																

* Where the data is stored AND get file dates
// Data on Inequality 
	global filedate="$mydate" //set to current date
	local i=1
	local filesearch = "${maindir}"+"\out\"+"${filedate}"+" Inequality"+" - "+"${vsample}"
	cap cd "`filesearch'"
	while _rc {
		global filedate: display %tdCY-N-D date("`c(current_date)'", "DMY") - `i'
		global filedate=strltrim("$filedate")
		local i=`i'+1
		local filesearch = "${maindir}out/${filedate} Inequality - ${vsample}"
		cap cd "`filesearch'"
	}
global ineqdata = "${maindir}"+"\out\"+"${filedate}"+" Inequality"+" - "+"${vsample}"	
// Data on Volatility
	global filedate="$mydate" //set to current date
	local i=1
	local filesearch = "${maindir}"+"\out\"+"${filedate}"+" Volatility"+" - "+"${vsample}"
	cap cd "`filesearch'"
	while _rc {
		global filedate: display %tdCY-N-D date("`c(current_date)'", "DMY") - `i'
		global filedate=strltrim("$filedate")
		local i=`i'+1
		local filesearch = "${maindir}out/${filedate} Volatility - ${vsample}"
		cap cd "`filesearch'"
	}
global voladata = "${maindir}"+"\out\"+"${filedate}"+" Volatility"+" - "+"${vsample}"
// Data on Mobility
	global filedate="$mydate" //set to current date
	local i=1
	local filesearch = "${maindir}"+"\out\"+"${filedate}"+" Mobility"+" - "+"${vsample}"
	cap cd "`filesearch'"
	while _rc {
		global filedate: display %tdCY-N-D date("`c(current_date)'", "DMY") - `i'
		global filedate=strltrim("$filedate")
		local i=`i'+1
		local filesearch = "${maindir}out/${filedate} Mobility - ${vsample}"
		cap cd "`filesearch'"
	}
global mobidata = "${maindir}"+"\out\"+"${filedate}"+" Mobility"+" - "+"${vsample}"		

* Where the firgures are going to be saved 
global outfolder="${mydate}"+"_"+"${vsample}"
capture noisily mkdir "$maindir${sep}figs${sep}${outfolder}"
global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"
capture noisily mkdir "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"	

* Read initialize and plotting code. Do not change myplots.do
do "$maindir/do/0_Initialize.do"
do "$maindir${sep}do${sep}myplots.do"		

* Define these variables for your dataset
global yrfirst = ${yrsample} 	// First year in the dataset 
global yrlast =  2018 		// Last year in the dataset

* Define some common charactristics of the plots 
qui do "${do}/myplotsettings.do"

* change working dir to folder with out 
cd "$maindir${sep}" // Cd to the folder containing the files
	
// Which section are we ploting 
	global figineq =  "yes"			// Inequality
	global figcoh =   "yes"			// Cohorts and initial inequality
	global figvol =   "yes" 			// Volatility
	global figquan =  "yes"			// Income growth heterogeneity 
	global figmob =   "yes"			// Mobility
	global figtail =  "yes" 			// Tail 
	global figcon =   "yes"			// Concentration 
	global figden =   "yes"			// Density Plots

// timeframe selectio to replace the original/initial points in time, depending on short/long sample
if "$vsample"=="short" {							
	global gr_yr1=2005
	global gr_yr2=2010
	global gr_yr3=2008
	global gr_yr4=2015
	global gr_yr5=2003 //mob T+10 t1
	global gr_yr6=2008 //mob T+10 t2
	global gr_yr7=2003 //mob T+5  t1
	global gr_yr8=2009 //mob T+5  t1
} 
else if "$vsample"=="long" {
	global gr_yr1=1995
	global gr_yr2=2005
	global gr_yr3=2005
	global gr_yr4=2015
	global gr_yr5=1995 //mob T+10 t1
	global gr_yr6=2000 //mob T+10 t2
	global gr_yr9=2005 //mob T+10 t3
	global gr_yr7=1995 //mob T+5  t1
	global gr_yr8=2005 //mob T+5  t2			
} 
}

*------------------------------------------------------------------------------*
	
//===================================================//	
//--- Inequality
//===================================================//

if "${figineq}" == "yes"{ 	

// PLOTS OF LOG EARN: The limints need to change for each variable; Better seperate them
foreach subgp in fem male all {	
	
	*For residual-education earnings we are only ploting the aggregated results
	if 	"`subgp'" == "all"{
		local wlist = "logearn researne researn"			
	}	
	else {
		local wlist = "logearn researn"	
	}
	
	*Start main loop over variables
	foreach var of local wlist {
	
	*Which variable will be ploted
	global vari = "`var'"						 
	
	*What is the group under analysis? 
	*You can add more groups to this section 
	if "`subgp'" == "all"{
		insheet using "${ineqdata}${sep}L_`var'_sumstat.csv", clear									//!hw
		local labname = "All"
	}
	if "`subgp'" == "male"{
		insheet using "${ineqdata}${sep}L_`var'_male_sumstat.csv", clear							//!hw
		keep if male == 1	// Keep the group we want to plot 
		local labname = "Men"
	}
	
	if "`subgp'" == "fem"{
	    insheet using "${ineqdata}${sep}L_`var'_male_sumstat.csv", clear							//!hw
		keep if male == 0	// Keep the group we want to plot 
		local labname = "Women"
	}
	
	*What is the label for title 
	if "${vari}" == "logearn"{
		local labtitle = "Log Earnings"
// 		local labtitle = "log y{sub:it}"
	}
	if "${vari}" == "researn" | "${vari}" == "researne"{
		local labtitle = "Residual Log Earnings"
// 		local labtitle = "{&epsilon}{sub:it}"
	}

	*What are the x-axis limits
	local lyear = ${yrfirst}
	local ryear = ${yrlast}
	
	*Normalize Percentiles 
	gen var${vari} = sd${vari}^2
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9901${vari} = p99${vari} - p1${vari}
	gen p99901${vari} = p99_9${vari} - p1${vari}
	gen p999901${vari} = p99_99${vari} - p1${vari}
	
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p999_p99${vari} = p99_9${vari} - p99${vari}
	gen p9999_p999${vari} = p99_99${vari} - p99_9${vari}
		
	gen p9505${vari} = p95${vari} - p5${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	
	*Rescale by first year 
	foreach vv in sd$vari  var$vari p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
		p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
		p97_5$vari p99$vari p99_9$vari p99_99$vari p9010$vari  p9901$vari  p9505$vari p9050${vari} p5010${vari} ksk${vari} ///
		p99901${vari} p999901${vari} p9990${vari} p999_p99${vari} p9999_p999${vari}{
		sum  `vv' if year == `lyear', meanonly
		gen n`vv' = `vv' - r(mean)
		}
	
	*Generate recession vars
	gen rece = inlist(year,${receyears})
	
	*Rescale standard deviation for plots
	replace sd${vari} = 2.56*sd${vari}

	// Keep selected years
	keep if year>=${yrfirst} & year<=${yrlast}	
	
**********************************************
//--- Figure 1 (percentiles) ---//

	local colors blue green red navy black
	local fcolors = ""
	foreach co of local colors {
		local fcolors = "`fcolors'" + " " + "`co'*0.25"
	}

*** Figure 1A: normalized percentiles
	if "${vari}"=="logearn" local yrange="range(-0.25 0.2)"
	if "${vari}"=="researn" local yrange="range(-0.15 0.1)"
	twoway (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
	       (connected np90${vari} np75${vari} np50${vari} np25${vari} np10${vari} year, ///
    			lcolor(`colors')  /// Line colors
    			lpattern(solid longdash dash dash_dot solid) ///
    			msymbol(O + S X D) /// Markers
    			mlcolor(`colors')  /// Marker  line color
                mfcolor(`fcolors')  ///	Fill color
    			yaxis(2)  yscale(alt axis(2) `yrange') ///
                ytitle("Percentiles Relative to `lyear'", axis(2)) ///
                ylabel(#6, axis(2))),  ///
    	xtitle("") ///
        xlabel(2000(3)2018, grid) ///
    	legend(position(11) order(2 "p90" 3 "p75" 4 "p50" 5 "p25" 6 "p10"))
  cap noisily: graph export "${folderfile}/fig1A_`subgp'_${vari}.${formatfile}", replace

*** Figure 1B: normalized top percentiles 
	twoway (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
	       (connected np99_99${vari} np99_9${vari} np99${vari} np95${vari} np90${vari} year, ///
    			lcolor(`colors')  /// Line colors
    			lpattern(solid longdash dash dash_dot solid) ///
    			msymbol(O + S X D) /// Markers
    			mlcolor(`colors')  /// Marker  line color
                mfcolor(`fcolors')  ///	Fill color
    			yaxis(2)  yscale(alt axis(2) range(-0.2 0.3)) ///
                ytitle("Percentiles Relative to `lyear'", axis(2)) ///
                ylabel(#6, axis(2)) ///
            ),  ///
    	xtitle("") ///
        xlabel(2000(3)2018, grid) ///		xaxis options
    	legend(position(11) order(2 "p99.99" 3 "p99.9" 4 "p99" 5 "p95" 6 "p90"))
  cap noisily: graph export "${folderfile}/fig1B_`subgp'_${vari}.${formatfile}", replace

  
********************************************** 
//--- Figure 2 (Inequality) ---//  

	local colors blue red
	local fcolors = ""
	foreach co of local colors {
		local fcolors = "`fcolors'" + " " + "`co'*0.25"
	}
	
*** Figure 2A: std. dev. and P90-P10
	if "${vari}"=="logearn" local yrange="range(1.3 2.4)"
	if "${vari}"=="researn" local yrange="range(1.1 2.4)"
	twoway (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
	       (connected sd${vari} p9010${vari} year, ///
    			lcolor(`colors')  /// Line colors
    			lpattern(solid longdash) ///
    			msymbol(O S) /// Markers
    			mlcolor(`colors')  /// Marker  line color
                mfcolor(`fcolors')  ///	Fill color
    			yaxis(2)  yscale(alt axis(2) `yrange') ///
                ytitle("Dispersion of `labtitle'", axis(2)) ///
                ylabel(#6, axis(2)) ///
            ),  ///
    	xtitle("") ///
        xlabel(2000(3)2018, grid) ///		xaxis options
    	legend(position(7) order(2 "2.56*{&sigma}" 3 "P90-P10"))
  cap noisily: graph export "${folderfile}/fig2A_`subgp'_${vari}.${formatfile}", replace

*** Figure 2B: P90-P50 and P50-P10
	if "${vari}"=="logearn" local yrange="range(0.6 1.6)"
	if "${vari}"=="researn" local yrange="range(0.55 1.6)"
	local legpos=11
	if "`subgp'"=="fem" local legpos=5
	twoway (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
	       (connected p9050${vari} p5010${vari} year, ///
    			lcolor(`colors')  /// Line colors
    			lpattern(solid longdash) ///
    			msymbol(O S) /// Markers
    			mlcolor(`colors')  /// Marker  line color
                mfcolor(`fcolors')  ///	Fill color
    			yaxis(2)  yscale(alt axis(2) `yrange') ///
                ytitle("Dispersion of `labtitle'", axis(2)) ///
                ylabel(#6, axis(2)) ///
            ),  ///
    	xtitle("") ///
        xlabel(2000(3)2018, grid) ///		xaxis options
    	legend(position(`legpos') order(2 "P90-P50" 3 "P50-P10"))
    cap noisily: graph export "${folderfile}/fig2B_`subgp'_${vari}.${formatfile}", replace

}	// END of loop over subgroups
}	// END loop over variables
}	// END of inequality section
	
//===================================================//
//--- Cohorts and Initial Inequality
//===================================================//

if "${figcoh}" == "yes"{ 

//loop over vars
foreach var in logearn{
	
	//loop of subgroups
	foreach subgp in male fem {	
									
	*The code generates for raw earnimgs and residuals earnigs
	global vari = "`var'"		
	
	*Label for plots
	local labtitle = "Log Earnings"
								
	*You can add more groups to this section 
	if "`subgp'" == "all"{
		insheet using "${ineqdata}${sep}L_`var'_age_sumstat.csv", clear
		local tlocal = "All Sample"
	}
	if "`subgp'" == "male"{
		insheet using "${ineqdata}${sep}L_`var'_maleage_sumstat.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local tlocal = "Men"
	}	
	if "`subgp'" == "fem"{
		insheet using "${ineqdata}${sep}L_`var'_maleage_sumstat.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local tlocal = "Women"
	}	
			
	*Calculate additional moments 
	gen p99990${vari} = p99_9${vari} - p99${vari}
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p9010${vari} = p90${vari} - p10${vari}	
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Gen cohort that is the age at which cohort was 25 years old 
	gen cohort25 = year - age + 25
	order year age cohort25
		
*************************************
//--- Plots at the age of entry ---//		 			

	local colors blue red
    local fcolors = ""
	foreach co of local colors {
		local fcolors = "`fcolors'" + " " + "`co'*0.25"
	}

	foreach ageval in 25{
	preserve
		*Keep only the sub sample at the age of age val 
		keep if age == `ageval'
		
		*Rescale by first year 
		foreach vv in sd$vari p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
			p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
			p97_5$vari p99$vari p99_9$vari p99_99$vari{
			
			sum  `vv' if year == ${yrfirst}, meanonly
			gen n`vv' = `vv' - r(mean)
			
			}
		*Recessions bars 
		gen rece = inlist(year,${receyears})

		*What is the last year in the x axis 
    	local lyear = ${yrfirst}
    	local ryear = ${yrlast}

		
*** Percentiles Plot
    	twoway (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
    	       (connected p9050${vari} p5010${vari} year, ///
        			lcolor(`colors')  /// Line colors
        			lpattern(solid longdash) ///
        			msymbol(O S) /// Markers
        			mlcolor(`colors')  /// Marker  line color
                    mfcolor(`fcolors')  ///	Fill color
        			yaxis(2)  yscale(alt axis(2) range(0.3 1.6)) ///
                    ytitle("Dispersion of `labtitle'", axis(2)) ///
                    ylabel(#6, axis(2)) ///
                ),  ///
        	xtitle("") ///
            xlabel(2000(3)2018, grid) ///		xaxis options
        	legend(position(5) order(2 "P90-P50" 3 "P50-P10"))
        cap noisily: graph export "${folderfile}/fig3_`subgp'_${vari}.${formatfile}", replace 	
		 
	restore
	
	} // END of loop over age val		
	
	
*** Plots by cohorts 			
	*Which variable is under analysis? 
	*The code generates for raw earnimgs and residuals earnigs
	global vari = "`var'"		
	
	*Label for plots
	local labtitle = "log y{sub:it}"
								
	*You can add more groups to this section 
	if "`subgp'" == "all"{
		insheet using "${ineqdata}${sep}L_`var'_age_sumstat.csv", clear
		local tlocal = "All Sample"
	}
	if "`subgp'" == "male"{
		insheet using "${ineqdata}${sep}L_`var'_maleage_sumstat.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local tlocal = "Men"
	}	
	if "`subgp'" == "fem"{
		insheet using "${ineqdata}${sep}L_`var'_maleage_sumstat.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local tlocal = "Women"
	}
		
	*Calculate additional moments 
	gen p99990${vari} = p99_9${vari} - p99${vari}
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p9010${vari} = p90${vari} - p10${vari}	
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Gen cohort that is the age at which cohort was 25 years old 
	gen cohort25 = year - age + 25
	order year age cohort25

*** Fig 3B: Gen cohort that is the age at which cohort was 25 years old
	plot_cohortage_inequality p9010${vari} year, ///
        cohorts(2002 2005 2008) /// what cohorts
		ages(25 30) /// what ages
        agesarrow(25 30) ///
		twowayoptions( ///
        xlabel(2000(3)2018, grid) /// x-axis
        ylabel(#6) ///
		ytitle("P90-P10 of Log Earnings") xtitle("") ///
        yscale(range(1.2 2.4))) ///
		legpos(5) ///
        //arrow1(1.3 2006 1.2 2004 (12) "25 yrs old") // this overrides default in agesarrow
		cap noisily: graph export "${folderfile}/fig3B_`subgp'_${vari}.${formatfile}", replace

	plot_cohortage_inequality p9010${vari} year, ///
        cohorts(2000 2005 2010) /// what cohorts
		ages(25 30) /// what ages
        agesarrow(25 30) ///
		twowayoptions( ///
        xlabel(2000(3)2018, grid) /// x-axis
        ylabel(#6) ///
		ytitle("P90-P10 of Log Earnings") xtitle("") ///
		yscale(range(1.2 2.4))) ///
		legpos(5) ///
        //arrow1(1.3 2006 1.2 2004 (12) "25 yrs old") // this overrides default in agesarrow		
		cap noisily: graph export "${folderfile}/fig3B_`subgp'_${vari}_2.${formatfile}", replace
	
}	// END loop subgroups
}	// END loop over variables 
}	// END section cohorts
 
//===================================================//	
//--- Volatility
//===================================================//

if "${figvol}" == "yes"{  

*Time series for slides 

	*Plot One-year changes
	foreach jj in 1 5{ 
		
	global vari = "researn`jj'F"
	
	*Figure 4
	foreach subgp in men women {
		
		if "${vari}" == "researn1F"{
			local lyear = ${yrfirst}
			local ryear = ${yrlast}
			local labtitle = "g{sup:1}{sub:it}"
		}		
		if "${vari}" == "researn5F"{
			local lyear = ${yrfirst} + 2
			local ryear = ${yrlast} - 3	
			local labtitle = "g{sup:5}{sub:it}" // ?? what labels here?
		}
		
		*Load data 				
		insheet using "${voladata}${sep}L_${vari}_male_sumstat.csv", case clear
		
		if "`subgp'" == "men"{
			keep if male == 1
		}
		else{
			keep if male == 0
		}	
		
		// Recession years
		gen rece = inlist(year,${receyears})
		
		gen p9050$vari = p90$vari - p50$vari
		gen p5010$vari = p50$vari - p10$vari
		
		// This is to center the 5-year changes
		if "${vari}" == "researn5F" {
			replace year = year + 2
		}

*********************************************************
//--- Figure 4 (Volatility, Dispersion P9050 P5010) ---//		

		//colors
		local colors blue red
		local fcolors = ""
		foreach co of local colors {
			local fcolors = "`fcolors'" + " " + "`co'*0.25"
		}

		//legend position
		local legpos=11
		if "`subgp'"=="women" local legpos=11
		
		// y scale range
		if "${vari}" == "researn1F" local yrange="range(0.11 0.43)"
		if "${vari}" == "researn5F" local yrange="range(0.3 0.9)"
		
		twoway (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
		       (connected p9050${vari} p5010${vari} year, ///
		    			lcolor(`colors')  /// Line colors
		    			lpattern(solid longdash) ///
		    			msymbol(O S) /// Markers
		    			mlcolor(`colors')  /// Marker  line color
		                mfcolor(`fcolors')  ///	Fill color
		    			yaxis(2)  yscale(alt axis(2) `yrange') ///
              ytitle("Dispersion of `labtitle'", axis(2)) ///
              ylabel(#6, axis(2)) ///
	            ),  ///
			    	xtitle("") ///
			      xlabel(2000(3)2018, grid) ///		xaxis options
			    	legend(position(`legpos') order(2 "P90-P50" 3 "P50-P10"))
	  cap noisily: graph export "${folderfile}/fig4_`subgp'_${vari}.${formatfile}", replace

	} // subgp
	
********************************************************
//--- Figure 5 (Skewness and Kurtosis time series) ---//

	//data
	insheet using "${voladata}${sep}L_${vari}_male_sumstat.csv", case clear
	
	//colors
	local colors red blue
	local fcolors = ""
	foreach co of local colors {
		local fcolors = "`fcolors'" + " " + "`co'*0.25"
	}
	
	gen ksk${vari} = ((p90${vari} - p50${vari}) - (p50${vari} - p10${vari}) )/(p90$vari - p10${vari})
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75$vari - p25${vari}) - 2.91
	
	//reshape
	keep year male ksk${vari} cku${vari}
	reshape wide ksk${vari} cku${vari}, i(year) j(male)
	
	//recession years
	gen rece = inlist(year,${receyears})
	
	// This is to center the 5-year changes
	if "${vari}" == "researn5F" {
		replace year = year + 2
	}
	
*** Figure 5A (Skewness)
	// y scale range
	if "${vari}" == "researn1F" local yrange="range(-0.3 0.3)"
	if "${vari}" == "researn5F" local yrange="range(-0.1 0.25)"	
	twoway (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
	       (connected ksk${vari}0 ksk${vari}1 year, ///
	    			lcolor(`colors')  /// Line colors
	    			lpattern(solid longdash) ///
	    			msymbol(O S) /// Markers
	    			mlcolor(`colors')  /// Marker  line color
	                mfcolor(`fcolors')  ///	Fill color
	    			yaxis(2)  yscale(alt axis(2) `yrange') ///
            ytitle("Skewness of `labtitle'", axis(2)) ///
            ylabel(#6, axis(2)) ///
            ),  ///
		    	xtitle("") ///
		      xlabel(2000(3)2018, grid) ///		xaxis options
		    	legend(position(11) order(2 "Women" 3 "Men"))
		cap noisily: graph export "${folderfile}/fig5A_${vari}.${formatfile}", replace

*** Figure 5B (Kurtosis)
	// y scale range
	if "${vari}" == "researn1F" local yrange="range(6 22)"
	if "${vari}" == "researn5F" local yrange="range(4 8)"	
	twoway (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
	       (connected cku${vari}0 cku${vari}1 year, ///
	    			lcolor(`colors')  /// Line colors
	    			lpattern(solid longdash) ///
	    			msymbol(O S) /// Markers
	    			mlcolor(`colors')  /// Marker  line color
	                mfcolor(`fcolors')  ///	Fill color
	    			yaxis(2)  yscale(alt axis(2) `yrange') ///
            ytitle("Excess Kurtosis of `labtitle'", axis(2)) ///
            ylabel(#6, axis(2)) ///
            ),  ///
		    	xtitle("") ///
		      xlabel(2000(3)2018, grid) ///		xaxis options
		    	legend(position(11) order(2 "Women" 3 "Men"))
		cap noisily: graph export "${folderfile}/fig5B_${vari}.${formatfile}", replace
	}	// END loop jj
} // END section Volatility
  
*------------------------------------------------------------------------------*

//===================================================//	
//--- Income growth heterogeneity 
//===================================================//		

if "${figquan}" == "yes"{ 
	
	foreach mm in  0 1 2 {		// 0: Women; 1: Men; 2: All		
		foreach jj in  1 5{
			
		local var = "researn`jj'F"
		global vari = "`var'"

		*What is the label for title 
		if "${vari}"== "researn1F" local labtitle = "g{sub:it}"	
		if "${vari}" == "researn5F" local labtitle = "g{sub:it}{sup:5}"	
	 
		*Load the data for the last percentile
		insheet using "${voladata}${sep}L_`var'_maleagerank.csv", clear case
		
		*Calculate additional moments 
		gen p9010${vari} = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}
		gen p7525${vari} = p75${vari} - p25${vari}
		gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
		gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari} - 2.91	// Excess Kurtosis
		replace kurt${vari} = kurt${vari} - 3.0		// Excess Kurtosis
		
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}
		
						
		collapse  p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, by(agegp permrank)
		reshape wide p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, i(permrank) j(agegp)
		
		*Idex for plot: the code calculates the top 0.1% in a seperated group (group 42). Since some countries might have 
		*top coded values, we do not plot the top 0.1%
		gen idex = _n
		order idex 
	
****************************************************
//--- Figure 6 (Earnings Change Heterogeneity) ---//
	
	
*** Figure 6A: P90 - P10
		if "${vari}" == "researn1F" local yrange="yscale(range(0 2))"
		if "${vari}" == "researn5F" local yrange="yscale(range(0 2.5))"
		twoway (connected p9010${vari}1 p9010${vari}2 p9010${vari}3 permrank if idex<=42, ///
							msymbol(none none o)  ///
							color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
				legend(position(12) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") cols(1) symxsize(7)) ///
				xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100") ///
				xtitle("Quantiles of Permanent Income P{sub:it-1}") ///
				ytitle("P90-P10 Differential of `labtitle'") ///
				`yrange' ylabel(#6)
		cap noisily: graph export "${folderfile}/fig6A_${vari}_`lname'.${formatfile}", replace

*** Figure 6B: Kelley Skewness
		local yrange="yscale(range(-0.6 0.65))"
		local legpos=2
		if ("`lname'"=="men" & "${vari}"== "researn5F") local legpos=7	
		twoway (connected ksk${vari}1 ksk${vari}2 ksk${vari}3 permrank if idex<=42, ///
							msymbol(none none o)  ///
							color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
				legend(position(`legpos') order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") cols(1) symxsize(7)) ///
				xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100") ///
				xtitle("Quantiles of Permanent Income P{sub:it-1}") ///
				ytitle("Kelley Skewness of `labtitle'") ///
				`yrange' ylabel(#6)
		cap noisily: graph export "${folderfile}/fig6B_${vari}_`lname'.${formatfile}", replace

*** Figure C: Excess Crow-Siddiqui Kurtosis
		local yrange="yscale(range(0 25))"
		tw (connected cku${vari}1 cku${vari}2 cku${vari}3 permrank if idex<=42, ///
							msymbol(none none o)  ///
							color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
				legend(position(6) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") cols(1) symxsize(7)) ///
				xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100") ///
				xtitle("Quantiles of Permanent Income P{sub:it-1}") ///
				ytitle("Excess Crow-Siddiqui Kurtosis of `labtitle'") ///
				`yrange' ylabel(#6)
		cap noisily: graph export "${folderfile}/fig6C_${vari}_`lname'.${formatfile}", replace	

//----------------------//		
// --- For appendix --- //

*** Figure AA
		if "${vari}" == "researn1F" local yrange="yscale(range(0.1 0.8))"
		if "${vari}" == "researn5F" local yrange="yscale(range(0.2 1.1))"
		local legpos=12
		if "`lname'"=="women" local legpos=12
		twoway (connected sd${vari}1 sd${vari}2 sd${vari}3 permrank if idex<=42, ///
							msymbol(none none o)  ///
							color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
				legend(position(`legpos') order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") cols(1) symxsize(7)) ///
				xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100") ///
				xtitle("Quantiles of Permanent Income P{sub:it-1}") ///
				ytitle("Standard Deviation of `labtitle'") ///
				`yrange' ylabel(#6)
		cap noisily: graph export "${folderfile}/fig6A_${vari}_`lname'_ct.${formatfile}", replace


*** Figure BB
		if "${vari}" == "researn1F" local yrange="yscale(range(-6 1))"
		if "${vari}" == "researn5F" local yrange="yscale(range(-5 1))"
		local legpos=7
		if ("`lname'"=="women" & "${vari}"== "researn1F") local legpos=8
		if ("`lname'"=="men" & "${vari}"== "researn1F") local legpos=12		
		twoway (connected skew${vari}1 skew${vari}2 skew${vari}3 permrank if idex<=42, ///
							msymbol(none none o)  ///
							color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
				legend(position(`legpos') order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") cols(1) symxsize(7)) ///
				xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100") ///
				xtitle("Quantiles of Permanent Income P{sub:it-1}") ///
				ytitle("Skewness of `labtitle'") ///
				`yrange' ylabel(#6)
		cap noisily: graph export "${folderfile}/fig6B_${vari}_`lname'_ct.${formatfile}", replace

*** Figure CC
		if "${vari}" == "researn1F" local yrange="yscale(range(0 110))"
		if "${vari}" == "researn5F" local yrange="yscale(range(0 40))"
		twoway (connected kurt${vari}1 kurt${vari}2 kurt${vari}3 permrank if idex<=42, ///
							msymbol(none none o)  ///
							color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
				legend(position(11) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") cols(1) symxsize(7)) ///
				xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100") ///
				xtitle("Quantiles of Permanent Income P{sub:it-1}") ///
				ytitle("Excess Kurtosis of `labtitle'") ///
				`yrange' ylabel(#6)
		cap noisily: graph export "${folderfile}/fig6C_${vari}_`lname'_ct.${formatfile}", replace

		}	// END loop variables
		}	// END loop men/women
}	
	
//===================================================//	
//--- Mobility
//===================================================//

if "${figmob}" == "yes"{ 
	
	foreach mm in  0 1 {			/*Gender: Men 1; Women 0*/	

*******************************
//--- Mobility t+5 & t+10 ---//	
		
		//Load Data
		insheet using "${mobidata}${sep}L_male_agegp_permearnalt_mobstat.csv", clear
		
		//sample group
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}		
		//collapse
		collapse meanpermearnaltranktp5 [aw=npermearnaltranktp5], by(permearnaltrankt year)
		keep meanpermearnaltranktp5 permearnaltrankt year
		reshape wide meanpermearnaltranktp5 , i(permearnaltrankt) j(year)
		gen idex = _n
		
		cap: drop  y1 x1 y2 x2
		if `mm' == 1{			
			gen y1 = 95 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 95 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 95
			local t2pos = 85 
		
		}
		else{
			gen y1 = 94 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 94 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 94
			local t2pos = 85 
		}
	
*** Fig 7 t+5	
		tw (line meanpermearnaltranktp5${gr_yr7} meanpermearnaltranktp5${gr_yr8} permearnaltrankt permearnaltrankt if idex <= 41, ///
				color(red blue black) lpattern(solid dash dash) lwidth(thick thick )) ///
				(scatter meanpermearnaltranktp5${gr_yr7} meanpermearnaltranktp5${gr_yr8} permearnaltrankt if idex == 42, ///
				color(red blue green) lpattern(dash dash dash) msymbol(D S O)  msize(large large large)) ///
				(pcarrow y1 x1 y2 x2, msize(medlarge) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
				text(`t1pos' `t2pos' "Top 0.1% of P{sub:it-1}", place(w) size(large) color(black))  ///
				legend(position(11) order(1 "${gr_yr7}" 2 "${gr_yr8}") cols(1) symxsize(7)) ///
				xtitle("Percentiles of Permanent Income, P{sub:it}") ///
				xlabel(0(10)90 99) ///
				ytitle("Mean Percentiles of P{sub:it+5}") ylabel(0(20)100)
		cap noisily: graph export "${folderfile}/fig7_mobility_`lname'_yrs_T5.pdf", replace			

*---
		
		//load data
		insheet using "${mobidata}${sep}L_male_agegp_permearnalt_mobstat.csv", clear	
		//subgroup
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}	
		//collapse & reshape
		collapse meanpermearnaltranktp10 [aw=npermearnaltranktp10], by(permearnaltrankt year)
		keep meanpermearnaltranktp10 permearnaltrankt year
		reshape wide meanpermearnaltranktp10 , i(permearnaltrankt) j(year)
		gen idex = _n
		
		cap: drop  y1 x1 y2 x2
		if `mm' == 1{	
			gen y1 = 93 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 93 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 93
			local t2pos = 85 
				   			
		}
		else{			
			gen y1 = 92 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 92 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 92
			local t2pos = 85 

		}
*** Fig 7 t+10			
		tw  (line meanpermearnaltranktp10${gr_yr5} meanpermearnaltranktp10${gr_yr6} permearnaltrankt permearnaltrankt if idex<= 41, ///
				color(red blue black) lpattern(solid dash dash) lwidth(thick thick)) ///
				(scatter meanpermearnaltranktp10${gr_yr5} meanpermearnaltranktp10${gr_yr6} permearnaltrankt if idex==42, ///
				color(red blue green) lpattern(dash dash dash) msymbol(D S O)  msize(large large large) ) ///
				(pcarrow y1 x1 y2 x2, msize(medlarge) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
				text(`t1pos' `t2pos' "Top 0.1% of P{sub:it-1}", place(w) size(large) color(black))  ///
				legend(position(11) order(1 "${gr_yr5}" 2 "${gr_yr6}") cols(1) symxsize(7)) ///
				xtitle("Percentiles of Permanent Income, P{sub:it}") ///
				xlabel(0(10)90 99) ///
				ytitle("Mean Percentiles of P{sub:it+10}") ylabel(0(20)100)
		cap noisily: graph export "${folderfile}/fig7_mobility_`lname'_yrs_T10.pdf", replace
	
	
*********************************
//--- Mobility by age group ---//					
				
		//load Data
		insheet using "${mobidata}${sep}L_male_agegp_permearnalt_mobstat.csv", clear
		//subgrp
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}	
		//collapse & reshape
		collapse meanpermearnaltranktp5, by(permearnaltrankt agegp)
		keep meanpermearnaltranktp5 permearnaltrankt agegp
		reshape wide meanpermearnaltranktp5 , i(permearnaltrankt) j(agegp)
		gen idex = _n
		
		cap: drop  y1 x1 y2 x2
		if `mm' == 1{			
			gen y1 = 96 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 96 if _n == 1
			gen x2 = 97 if _n == 1
			gen y3 = 96 if _n == 1
			gen x3 = 85 if _n == 1
			gen y4 = 96 if _n == 1
			gen x4 = 97 if _n == 1
			local t1pos = 96
			local t2pos = 85 
		
		}
		else{
			gen y1 = 95 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 95 if _n == 1
			gen x2 = 97 if _n == 1
			gen y3 = 95 if _n == 1
			gen x3 = 85 if _n == 1
			gen y4 = 91 if _n == 1
			gen x4 = 97 if _n == 1
			local t1pos = 95
			local t2pos = 85 
		}

*** Fig 7 t+5 mobility by age group		
		tw (line meanpermearnaltranktp51 meanpermearnaltranktp52 permearnaltrankt permearnaltrankt if idex<= 41, ///
				color(red blue black) lpattern(solid dash dash) lwidth(thick thick)) ///
				(scatter meanpermearnaltranktp51 meanpermearnaltranktp52 permearnaltrankt if idex==42, ///
				color(red blue green) lpattern(dash dash dash) msymbol(D S O)  msize(large large large) ) ///
				(pcarrow y1 x1 y2 x2, msize(medlarge) mlwidth(medthick) mlcolor(black) lcolor(black) ) ///
				(pcarrow y3 x3 y4 x4, msize(medlarge) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
				text(`t1pos' `t2pos' "Top 0.1% of P{sub:it-1}", place(w) size(large) color(black))  ///
				legend(position(11) order(1 "[25-34]" 2 "[35-44]") cols(1) symxsize(7)) ///
				xtitle("Percentiles of Permanent Income, P{sub:it}") ///
				xlabel(0(10)90 99) ///
				ytitle("Mean Percentiles of P{sub:it+5}") ylabel(0(20)100)
		cap noi: graph export "${folderfile}/fig7_mobility_`lname'_T5.pdf", replace
		
*---
			 
		//load data
		insheet using "${mobidata}${sep}L_male_agegp_permearnalt_mobstat.csv", clear
		//subgrp
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}	
		//collapse & reshape
		collapse meanpermearnaltranktp10, by(permearnaltrankt agegp)
		keep meanpermearnaltranktp10 permearnaltrankt agegp
		reshape wide meanpermearnaltranktp10 , i(permearnaltrankt) j(agegp)
		gen idex = _n
		
		cap: drop  y1 x1 y2 x2
		if `mm' == 1{	
			gen y1 = 93 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 93 if _n == 1
			gen x2 = 97 if _n == 1
			gen y3 = 93 if _n == 1
			gen x3 = 85 if _n == 1
			gen y4 = 93 if _n == 1
			gen x4 = 97 if _n == 1
			local t1pos = 93
			local t2pos = 85 
				   			
		}
		else{			
			gen y1 = 94 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 94 if _n == 1
			gen x2 = 97 if _n == 1
			gen y3 = 94 if _n == 1
			gen x3 = 85 if _n == 1
			gen y4 = 89 if _n == 1
			gen x4 = 97 if _n == 1
			local t1pos = 94
			local t2pos = 85 

		}	
		
*** Fig 7 t+10 mobility by age group	
		tw (line meanpermearnaltranktp101 meanpermearnaltranktp102 permearnaltrankt permearnaltrankt if idex<= 41, ///
				color(red blue black) lpattern(solid dash dash) lwidth(thick thick)) ///
				(scatter meanpermearnaltranktp101 meanpermearnaltranktp102 permearnaltrankt if idex==42, ///
				color(red blue green) lpattern(dash dash dash) msymbol(D S O)  msize(large large large) ) ///
				(pcarrow y1 x1 y2 x2, msize(medlarge) mlwidth(medthick) mlcolor(black) lcolor(black) ) ///
				(pcarrow y3 x3 y4 x4, msize(medlarge) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
				text(`t1pos' `t2pos' "Top 0.1% of P{sub:it-1}", place(w) size(large) color(black))  ///
				legend(position(11) order(1 "[25-34]" 2 "[35-44]") cols(1) symxsize(7)) ///
				xtitle("Percentiles of Permanent Income, P{sub:it}") ///
				xlabel(0(10)90 99) ///
				ytitle("Mean Percentiles of P{sub:it+10}") ylabel(0(20)100)
		cap noi: graph export "${folderfile}/fig7_mobility_`lname'_T10.pdf", replace			
	}	// END loop over men and women	
}

*------------------------------------------------------------------------------*

//===================================================//
//--- Tail For Appendix 
//===================================================//

if "${figtail}" == "yes"{
	
****************
//--- CDFs ---//	
			
	//load and reshape data 		
	forvalues mm = 0/2 {			/*0: Women; 1: Men; 2: All*/
				
		if `mm' == 1{
			insheet using "${ineqdata}${sep}RI_male_earn_idex.csv", clear comma
			keep if male == `mm'
			local llabel = "Male"
		}
		else if `mm' == 0{
			insheet using "${ineqdata}${sep}RI_male_earn_idex.csv", clear comma
			keep if male == `mm'
			local llabel = "Women"		
		}
		else {
			insheet using "${ineqdata}${sep}RI_earn_idex.csv", clear comma	
			local llabel = "all"
		}
		
		reshape long n t me ra ob, i(year) j(level) string
		split level, p(level) 
		drop level1
		rename level2 numlevel
		destring numlevel, replace 
		order numlevel level year 
		sort year numlevel
		
		*Re scale and share of pop
		replace n = ob
		by year: gen aux = 20*ob if numlevel == 0 
		by year: egen tob = max(aux)   // Because ob is number of observations in top 5%
		drop aux
		by year: gen  shob = ob/tob
				 gen  lshob = log(shob)		  	
		
		gen t1000s = (t/1000)/${exrate2018}				// Tranform to dollars of 2018
		gen lt1000s = log(t1000s)
		gen lt = log(t)
		gen l10t = log10(t)
		
		//Re-reshape 
		reshape wide n t me ra ob tob shob lshob t1000s lt l10t lt1000s, i(numlevel) j(year)
		
		//reg predict etc. for 5% tail
		reg lshob${gr_yr1} lt${gr_yr1}
		predict lshob${gr_yr1}_hat, xb
		global slopep${gr_yr1} : di %4.2f _b[lt${gr_yr1}]
		
		reg lshob${gr_yr4} lt${gr_yr4}
		predict lshob${gr_yr4}_hat, xb
		global slopep${gr_yr4} : di %4.2f _b[lt${gr_yr4}]
		
*** Figure 5% tail of log CDF				
		tw (line lshob${gr_yr1} lshob${gr_yr1}_hat lt${gr_yr1}, color(red red) lwidth(thick) lpattern(solid dash)) ///
			(line  lshob${gr_yr4} lshob${gr_yr4}_hat lt${gr_yr4} , color(blue blue)  lwidth(thick) lpattern(solid dash)) , ///
			legend(ring(0) position(2) ///
			order(1 "${density_yr1} Level (Slope: ${slopep${density_yr1}})" 3 "${density_yr3} Level (Slope: ${slopep${density_yr3}})") size(medium) cols(1) symxsize(7) region(color(none))) ///
			xtitle("log y{sub:it}", size(${xtitlesize})) title(, color(black) size(medlarge)) ///
			xlabel(, grid labsize(${xlabsize})) graphregion(color(white)) plotregion(lcolor(black)) ///
			ytitle("log(1-CDF)", color(black) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) yscale(range(-12 -2))
		cap noi: graph export "${folderfile}/logCDF_5pct_`llabel'.pdf", replace 
		drop lshob${gr_yr4}_hat lshob${gr_yr1}_hat
		
*---		
		
		//reg predict etc. for 1% tail	(TPP: >=0.01, core code template: <0.01)
		reg lshob${gr_yr1} lt${gr_yr1} if shob${gr_yr1} >= 0.01
		predict lshob${gr_yr1}_hat if e(sample), xb
		global slopep${gr_yr1} : di %4.2f _b[lt${gr_yr1}]
		
		reg lshob${gr_yr4} lt${gr_yr4} if shob${gr_yr4} >= 0.01
		predict lshob${gr_yr4}_hat if e(sample), xb
		global slopep${gr_yr4} : di %4.2f _b[lt${gr_yr4}]
				
		tw (line lshob${gr_yr1} lshob${gr_yr1}_hat lt${gr_yr1}   if shob${gr_yr1}>=0.01, color(red red) lwidth(thick) lpattern(solid dash)) ///
			(line  lshob${gr_yr4} lshob${gr_yr4}_hat lt${gr_yr4}   if shob${gr_yr4}>=0.01, color(blue blue)  lwidth(thick) lpattern(solid dash)) , ///
			legend(ring(0) position(2) order(1 "${gr_yr1} Level (Slope: ${slopep${gr_yr1}})" 3 "${gr_yr4} Level (Slope: ${slopep${gr_yr4}})") ///
			size(medium) cols(1) symxsize(7) region(color(none))) ///
			 xtitle("log y{sub:it}", size(${xtitlesize})) title(, color(black) size(medlarge)) ///
			 xlabel(, grid labsize(${xlabsize})) graphregion(color(white)) plotregion(lcolor(black)) ///
			 ytitle("log(1-CDF)", color(black) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) yscale(range(-4.4 -2.5))
		cap noi: graph export "${folderfile}/logCDF_1pct_`llabel'.pdf", replace 
		drop lshob${gr_yr4}_hat lshob${gr_yr1}_hat
		
	}
}

//===================================================//		
//--- This section generates the figures 3b & 11b in the Common Core section of the Guidelines
//===================================================//

if "${figcon}" == "yes"{ 
	
	// subgrp
	foreach subgp in male fem   all{
		
	if "`subgp'" == "all"{
		insheet using  "${ineqdata}${sep}L_earn_con.csv", clear			
		local tlocal = "All Sample"
	}
	if "`subgp'" == "male"{
		insheet using "${ineqdata}${sep}L_earn_con_male.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local tlocal = "Men"
	}	
	if "`subgp'" == "fem"{
		insheet using "${ineqdata}${sep}L_earn_con_male.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local tlocal = "Women"
	}
	
	
	*Normalizing data to value in ${normyear}
	local lyear = ${normyear}	// Normalization year
	foreach vv in q1share q2share q3share q4share q5share ///
				  top10share top5share top1share top05share top01share top001share ///
				  bot50share{
		
		sum  `vv' if year == `lyear', meanonly
		gen n`vv' = (`vv' - r(mean))/100
		
		}
		
	*What years 
	local rlast = ${yrlast}
	keep if year >= $yrfirst & year <= $yrlast
	
	*Recession bars 
	gen rece = inlist(year,${receyears})
	
	// colors
	local colors green black maroon red navy
	local fcolors = ""
	foreach co of local colors {
		local fcolors = "`fcolors'" + " " + "`co'*0.25"
	}	
	
*** Quintiles
		twoway  (bar rece year , c(l) color(gray*0.5) yscale(off)) ///
				(connected nq1share nq2share nq3share nq4share nq5share year, ///
				lcolor(`colors')  ///
				lpattern(solid..)  ///
				msymbol(O T D S T)		///
				mfcolor(`fcolors')  ///	Fill color
				mlcolor(`colors')  ///			Marker  line color
				yaxis(2)  yscale(alt axis(2) range(-0.018 0.033)) ///
				ytitle("Change in Income Shares Relative to $yrfirst", axis(2)) ///
				ylabel(#6, axis(2))),  /// yaxis optins
				xtitle("") xlabel(2000(3)2018, grid) ///		xaxis options
				legend(col(1) symxsize(7) position(11) order(2 "Q1" 3 "Q2" 4 "Q3" 5 "Q4" 6 "Q5"))		
		cap noi: graph export "${folderfile}/fig11B_nquintile_more_`subgp'.${formatfile}", replace

		
*** Selected Income Shares
		twoway  (bar rece year , c(l) color(gray*0.5) yscale(off)) ///
				(connected nbot50share ntop10share ntop5share /*ntop1share ntop05share ntop01share ntop001share*/ year, ///
				lcolor(`colors')  ///
				lpattern(solid..)  ///
				msymbol(O T D S T dh sh)		///
				mfcolor(`fcolors')  ///	Fill color
				mlcolor(`colors')  ///			Marker  line color
				yaxis(2)  yscale(alt axis(2) range(-0.03 0.03)) ///
				ytitle("Change in Income Shares Relative to $yrfirst", axis(2)) ///
				ylabel(#6, axis(2))),  /// yaxis optins
				xtitle("") xlabel(2000(3)2018, grid) ///		xaxis options
				legend(col(1) symxsize(7) position(11) order(2 "Bottom 50%" 3 "Top 10%" 4 "Top 5%" /*5 "Top 1%" 6 "Top 0.5%" 7 "Top 0.1%" 8 "Top 0.01%"*/))			
		cap noi: graph export "${folderfile}/fig11B_bot50share_more_`subgp'.${formatfile}", replace

		
*** Gini
		local color blue
		tw  (bar rece year , c(l) color(gray*0.5) yscale(off)) ///
				(connected gini year, ///
				lcolor(`color')  ///
				lpattern(solid..)  ///
				msymbol(O T D S T dh sh)		///
				mfcolor(`color'%25)  ///	Fill color
				mlcolor(`color')  ///			Marker  line color
				yaxis(2)  yscale(alt axis(2) range(0.3 0.4)) ///
				ytitle("Gini Coefficient", axis(2)) ///
				ylabel(#6, axis(2))),  /// yaxis optins
				xtitle("") xlabel(2000(3)2018, grid) ///		xaxis options
				legend(off)		
		cap noi: graph export "${folderfile}/fig3B_gini_`subgp'.${formatfile}", replace
	
		   
}	// END of loop over variables
} // END of section 

//===================================================//	
//--- Earnings growth Densities
//===================================================//

if "${figden}" == "yes"{ 
	
	//subgroups loop
	foreach sam in women men {
		//year loop
		foreach yy in ${gr_yr1} ${gr_yr2}{			// Which years are being plotted
			//var loop
			foreach vari in researn1F researn5F    {
			
				//Labels 
				if "`vari'" == "researn1F" local labtitle = "g{sup:1}{sub:it}"
				if "`vari'" == "researn5F" local labtitle = "g{sup:5}{sub:it}"

				//Data
				if "`sam'" == "all"{
					insheet using "${voladata}${sep}L_`vari'_sumstat.csv", case clear
					
					sum sd`vari' if year == `yy'
					global sd = r(mean) 
					
					sum skew`vari' if year == `yy'
					global skew = r(mean) 
								
					sum kurt`vari' if year == `yy'
					global kurt = r(mean) 
					
					global sdplot: di %4.2f  ${sd}
					global skplot: di %4.2f  ${skew}
					global kuplot: di %4.2f  ${kurt}
					
					insheet using "${voladata}${sep}L_`vari'_hist.csv", case clear
					local labtitle2 = "(All Sample)"
				}
				else if "`sam'" == "men"{
					insheet using "${voladata}${sep}L_`vari'_male_sumstat.csv", case clear
					
					sum sd`vari' if year == `yy' & male == 1
					global sd = r(mean) 
					
					sum skew`vari' if year == `yy' & male == 1
					global skew = r(mean) 
								
					sum kurt`vari' if year == `yy' & male == 1
					global kurt = r(mean) 
					
					global sdplot: di %4.2f  ${sd}
					global skplot: di %4.2f  ${skew}
					global kuplot: di %4.2f  ${kurt}
					
					insheet using "${voladata}${sep}L_`vari'_hist_male.csv", case clear 
					keep if male == 1
					local labtitle2 = "(Men Only)"
				}
				else if "`sam'" == "women"{
					insheet using "${voladata}${sep}L_`vari'_male_sumstat.csv", case clear
					
					sum sd`vari' if year == `yy' & male == 0
					global sd = r(mean) 
					
					sum skew`vari' if year == `yy' & male == 0
					global skew = r(mean) 
								
					sum kurt`vari' if year == `yy' & male == 0
					global kurt = r(mean) 
					
					global sdplot: di %4.2f  ${sd}
					global skplot: di %4.2f  ${skew}
					global kuplot: di %4.2f  ${kurt}
					
					insheet using "${voladata}${sep}L_`vari'_hist_male.csv", case clear							//!hw
					keep if male == 0
					local labtitle2 = "(Women Only)"
				}
				
				// Log densities
				gen lden_`vari'`yy' = log(den_`vari'`yy')
				gen lnden_`vari'`yy' = log(normalden(val_`vari'`yy',0,${sd}))

				gen nden_`vari'`yy' = (normalden(val_`vari'`yy',0,${sd}))

				// Slopes
				reg lden_`vari'`yy' val_`vari'`yy' if val_`vari'`yy' < -1 & val_`vari'`yy' > -4
				global blefttail: di %4.2f _b[val_`vari'`yy']
				predict lefttail if e(sample), xb

				reg lden_`vari'`yy' val_`vari'`yy' if val_`vari'`yy' > 1 & val_`vari'`yy' < 4
				global brighttail: di %4.2f _b[val_`vari'`yy']
				predict righttail if e(sample), xb

				// Trimming for plots
				replace lnden_`vari'`yy' = . if val_`vari'`yy' < -2
				replace lnden_`vari'`yy' = . if val_`vari'`yy' > 2

				replace lden_`vari'`yy' = . if val_`vari'`yy' < -4
				replace lden_`vari'`yy' = . if val_`vari'`yy' > 4


				replace nden_`vari'`yy' = . if val_`vari'`yy' < -4
				replace nden_`vari'`yy' = . if val_`vari'`yy' > 4

				replace den_`vari'`yy' = . if val_`vari'`yy' < -4
				replace den_`vari'`yy' = . if val_`vari'`yy' > 4

				replace lefttail = . if val_`vari'`yy' < -4
				replace lden_`vari'`yy' = . if val_`vari'`yy' > 4

				replace righttail = . if val_`vari'`yy' > 4
				replace lden_`vari'`yy' = . if val_`vari'`yy' > 4
				
				//set plot axis min & max
				local xmin = -4
				local xmax = 4
				local ymin = -10
				local ymax = 3

*** Log Density	(fig 13)
				tw line lden_`vari'`yy' lnden_`vari'`yy' lefttail righttail val_`vari'`yy' ///
						if val_`vari'`yy' != . & val_`vari'`yy' > `xmin' & val_`vari'`yy' < `xmax' & lden_`vari'`yy' > `ymin' & lden_`vari'`yy' < `ymax', ///
						lcolor(blue red black black navy forest_green)  ///
						lpattern(solid dash longdash longdash longdash dash)  ///
						lwidth(medthick..) ///
						ytitle("Log Density") ///
						ylabel(`ymin'(2)`ymax')  ///
						xtitle("One-Year Log Earnings Growth") ///
						xlabel(`xmin'/`xmax') ///
						legend(position(11) col(1) order(1 "Data Density" 2 "N(0,${sdplot}{sup:2})" 3 "Left   Slope: ${blefttail}" 4 "Right Slope: ${brighttail}")) ///
						text(2 1.8 "St. Dev.: ${sdplot}", place(e) size(${legesize})) ///
						text(1 1.8 "Skewness: ${skplot}", place(e) size(${legesize})) ///
						text(0 1.8 "Kurtosis: ${kuplot}", place(e) size(${legesize}))
				cap noi: graph export "${folderfile}/fig13_lden_`vari'_`sam'_`yy'.${formatfile}", replace

				//set plot axis min & max				
				local xmin = -2.5
				local xmax = 2.5
				local ymin = 0
				local ymax = 4				
				
*** Density	(fig 13)
				tw line den_`vari'`yy' nden_`vari'`yy' val_`vari'`yy' ///
						if val_`vari'`yy' != . & val_`vari'`yy' > `xmin' & val_`vari'`yy' < `xmax' & den_`vari'`yy' > `ymin' & den_`vari'`yy' < `ymax', ///
						lcolor(blue red black black navy forest_green)  ///
						lpattern(solid dash longdash longdash longdash dash)  ///
						lwidth(medthick..) ///
						ytitle("Density") ///
						ylabel(`ymin'(1)`ymax')  ///
						xtitle("One-Year Log Earnings Growth") ///
						xlabel(`xmin'/`xmax') ///
						legend(position(11) col(1) order(1 "Data Density" 2 "N(0,${sdplot}{sup:2})" 3 "Left   Slope: ${blefttail}" 4 "Right Slope: ${brighttail}")) ///
						text(3.0 1 "St. Dev.: ${sdplot}", place(e) size(${legesize})) ///
						text(2.5 1 "Skewness: ${skplot}", place(e) size(${legesize})) ///
						text(2.0 1 "Kurtosis: ${kuplot}", place(e) size(${legesize}))
				cap noi: graph export "${folderfile}/fig13_den_`vari'_`sam'_`yy'.${formatfile}", replace
							 				
			}	// END loop over variables	
		}	// END loop over years 
	}	// END loop over samples
} 	// END of section

*END OF THE CODE
