*! 20220525 hw
//==============================================================================
// This program generates shares of topcoded in IAB data
// GRID project
//==============================================================================

* load relevant data
use persid year male yob labor logearn permearnalt censor ///
	using"${data}\master_sample_nonimp_cens.dta", clear


//--- basic vars and restrictions ---//

* drop vars & obs if needed
drop if year<1999 | year>2018

//--- gen main variables ---//

* Age group
gen age = year-yob+1
gen agegp = .
replace agegp = 1 if age <= 34 & agegp == .
replace agegp = 2 if age <= 44 & agegp == .
replace agegp = 3 if age <= 55 & agegp == .

* Age restriction
drop if age > 55 | age < 25

* gen label vars 
gen male_lbl = ""
replace male_lbl = "male" if male==1
replace male_lbl = "female" if male==0
gen agegp_lbl = ""
replace agegp_lbl = "25-34" if agegp==1
replace agegp_lbl = "35-44" if agegp==2
replace agegp_lbl = "45-55" if agegp==3

* CS sample indicator
generate CSsample = logearn != .

* const for N after collapse
gen const_one=1

//--- gen topcoded variables ---//

* topcoded shares
xtset persid year

* different measures for topcoding (>60k annual earn, censored: tentgelt>=bbg-2 & nonmiss, tcm: main spell>=bbg of west/east)

gen topcoded_cens=(censor==1 & !missing(labor))
replace topcoded_cens=. if labor==.
 
gen topcodedPerm1_cens = censor==1 | L.censor==1 | L2.censor==1 if !missing(labor, L.labor, L2.labor) 
gen topcodedPerm2_cens = ((topcoded_cens + L.topcoded_cens + L2. topcoded_cens) > 1) if !missing(labor, L.labor, L2.labor)  

gen topcodedPerm1_vol_cens = F.topcodedPerm1_cens==1 if !missing(L.labor, labor, F.labor)
gen topcodedPerm2_vol_cens = F.topcodedPerm2_cens==1 if !missing(L.labor, labor, F.labor)

gen topcodedPerm1_mob_cens = F5.topcodedPerm1_cens==1 if !missing(F3.labor, F4.labor, F5.labor)
gen topcodedPerm2_mob_cens = F5.topcodedPerm2_cens==1 if !missing(F3.labor, F4.labor, F5.labor)

* non-missing or zero labor for t, t+1 and t+5
gen earn_non_zero=(labor>0 & labor!=.)
gen earn_non_zero_vol=(labor>0 & labor!=. & F.labor>0 & F.labor!=.)
gen earn_non_zero_mob=(labor>0 & labor!=. & F5.labor>0 & F5.labor!=.)
* non-missing or zero permearnalt for t, t+1 and t+5
gen permearnalt_non_zero=(permearnalt>0 & permearnalt!=.)
gen permearnalt_non_zero_vol=(permearnalt>0 & permearnalt!=. & F.permearnalt>0 & F.permearnalt!=.)
gen permearnalt_non_zero_mob=(permearnalt>0 & permearnalt!=. & F5.permearnalt>0 & F5.permearnalt!=.)

* get t+1 and t+5 values to t for the rank variable
gen permearnalt_vol=F.permearnalt
gen permearnalt_mob=F5.permearnalt

//--- rankings in bins and pctls (by year, gender, age (not agegp!), non-missing / zero earnings) ---//


* earn bins
gen earn_bins=.
replace earn_bins=ceil(labor/1000)
replace earn_bins=80 if earn_bins>=80 & !missing(earn_bins)
gen earn_bins_vol=.
replace earn_bins_vol=earn_bins if F.labor!=0 & F.labor>0
gen earn_bins_mob=.
replace earn_bins_mob=earn_bins if F5.labor!=0 & F5.labor>0

gen earn_bins_lbl = ""
forval bin=1/80 {
	local lb=(`bin'-1)
	replace earn_bins_lbl = "labor: `lb'k - `bin'k" if earn_bins==`bin'
}

xtset, clear

* save data
save "${data}/data_topcoded_base.dta", replace


//--- get percentiles and ranks by het groups & earnings measures ---//

foreach het in "" "age" "male" "male age" {
	
	preserve
	
	qui {
	if "`het'"=="" di "*** For group: all ***"
	noi di "*** For group: `het' ***"
	
	** loop over current, volatility & mobility and respective (sub-)samples
	foreach tt in "" "_vol" "_mob" {
		
		if "`tt'"=="" noi di "*-- Current --*"
		if "`tt'"=="_vol" noi di "*-- Volatility --*"
		if "`tt'"=="_mob" noi di "*-- Mobility --*"
		
		** earn: gen earn percentiles 
		noi di "-- earn --"
		gen earn_pctls`tt'=.
		bysort year `het' earn_non_zero`tt' (labor): replace earn_pctls`tt' = (100/40) * (floor(_N * (_n/_N) * 40 / (1+_N) )+1) if _n/_N<=0.975
		bysort year `het' earn_non_zero`tt' (labor): replace earn_pctls`tt' = 100 if (_n/_N)>0.999
		bysort year `het' earn_non_zero`tt' (labor): replace earn_pctls`tt' = 99.9 if (_n/_N)>0.99 & (_n/_N)<=0.999
		bysort year `het' earn_non_zero`tt' (labor): replace earn_pctls`tt' = 99 if (_n/_N)>0.975 & (_n/_N)<=0.99
		replace earn_pctls`tt'=. if earn_non_zero`tt'==0
		
		
		** permearnalt: topcoded version, percentiles and ranks
		noi di "-- permearnalt --"
		local em = "permearnalt"
		
		foreach suf in "cens" {
	
			noi di "- for `suf' -"
	
			* by topcoding definition
			forval def=2 {
				
				noi di "pctls for def `def'"
				
				* temporary top-coded (==.t) labor earnings
				gen temp_tc_inc=`em'
				replace temp_tc_inc=.t if topcodedPerm`def'_`suf'==1
						
				** topcoded categories for pctls
				gen `em'_pctls`tt'_`suf'`def'_v1=.
				gen `em'_pctls`tt'_`suf'`def'_v2=.

				bysort year `het' `em'_non_zero`tt' (`em'): replace `em'_pctls`tt'_`suf'`def'_v1 = (100/40) * (floor(_N * (_n/_N) * 40 / (1+_N) )+1) if _n/_N<=0.975
				bysort year `het' `em'_non_zero`tt' (`em'): replace `em'_pctls`tt'_`suf'`def'_v1 = 100 if (_n/_N)>0.999
				bysort year `het' `em'_non_zero`tt' (`em'): replace `em'_pctls`tt'_`suf'`def'_v1 = 99.9 if (_n/_N)>0.99 & (_n/_N)<=0.999
				bysort year `het' `em'_non_zero`tt' (`em'): replace `em'_pctls`tt'_`suf'`def'_v1 = 99 if (_n/_N)>0.975 & (_n/_N)<=0.99
				bysort year `het' `em'_non_zero`tt' (temp_tc_inc): replace `em'_pctls`tt'_`suf'`def'_v2 = (100/40) * (floor(_N * (_n/_N) * 40 / (1+_N) )+1) if _n/_N<=0.975
				bysort year `het' `em'_non_zero`tt' (temp_tc_inc): replace `em'_pctls`tt'_`suf'`def'_v2 = 100 if (_n/_N)>0.999
				bysort year `het' `em'_non_zero`tt' (temp_tc_inc): replace `em'_pctls`tt'_`suf'`def'_v2 = 99.9 if (_n/_N)>0.99 & (_n/_N)<=0.999
				bysort year `het' `em'_non_zero`tt' (temp_tc_inc): replace `em'_pctls`tt'_`suf'`def'_v2 = 99 if (_n/_N)>0.975 & (_n/_N)<=0.99	
				replace `em'_pctls`tt'_`suf'`def'_v1 =. if `em'_non_zero`tt'==0
				replace `em'_pctls`tt'_`suf'`def'_v2 =. if `em'_non_zero`tt'==0
				replace `em'_pctls`tt'_`suf'`def'_v1 =101 if temp_tc_inc==.t & !mi(`em'_pctls`tt'_`suf'`def'_v1)
				replace `em'_pctls`tt'_`suf'`def'_v2 =101 if temp_tc_inc==.t & !mi(`em'_pctls`tt'_`suf'`def'_v2)
				
				** cutoff
				gen temp_co=.
				bysort year `het' `em'_non_zero`tt' (temp_tc_inc): replace temp_co = 100 * (_n/_N)
				replace temp_co =. if `em'_non_zero`tt'==0
				replace temp_co=. if temp_tc_inc!=.t
				bysort year `het' `em'_non_zero`tt': egen C_cutoff_`em'`tt'_`suf'`def'=min(temp_co)
				replace C_cutoff_`em'`tt'_`suf'`def'=. if `em'_non_zero`tt'==0
				
				
				if "`suf'"=="cens" & ("`tt'"=="_vol" | "`tt'"=="_mob") {
				
				** rank vars 
				noi di "ranks for def `def'"
					
					* replace topcoded earnings by future topcoded earnings (t+X rank is needed)
					drop temp_tc_inc
					gen temp_tc_inc=`em'`tt'
					replace temp_tc_inc=.t if topcodedPerm`def'`tt'_`suf'==1
					
					* gen rank variables
					gen `em'_rank`tt'_`suf'`def'_v1=.
					gen `em'_rank`tt'_`suf'`def'_v2=.
					gen `em'_rank`tt'_`suf'`def'_v3=.
					gen `em'_rank`tt'_`suf'`def'_v4=.
					gen `em'_rank`tt'_`suf'`def'_v5=.
							
					* get v1 & v2 ranks		
					bysort year `het' `em'_non_zero`tt' (`em'`tt'): replace `em'_rank`tt'_`suf'`def'_v1 = 100 * (_n/_N)
					bysort year `het' `em'_non_zero`tt' (temp_tc_inc): replace `em'_rank`tt'_`suf'`def'_v2 = 100 * (_n/_N)
				
					replace `em'_rank`tt'_`suf'`def'_v1=. if `em'_non_zero`tt'==0
					replace `em'_rank`tt'_`suf'`def'_v2=. if `em'_non_zero`tt'==0				
				
					* get (temporary) var with value for lower bound for topcoded observations and use it to get cutoff rank
					gen temp_lb =`em'_rank`tt'_`suf'`def'_v2 
					replace temp_lb=. if temp_tc_inc!=.t
					bysort year `het' `em'_non_zero`tt': egen F_cutoff_`em'`tt'_`suf'`def'=min(temp_lb)
					replace F_cutoff_`em'`tt'_`suf'`def'=. if `em'_non_zero`tt'==0
							
					* for v2: get mean rank of topcoded values as rank for v2 [ = (100-lb)/2 ]		
					replace `em'_rank`tt'_`suf'`def'_v2 = (100 + F_cutoff_`em'`tt'_`suf'`def')/2 if temp_tc_inc==.t & !mi(`em'_rank`tt'_`suf'`def'_v2)
						
					* for v3: get 100 as rank fpr topcoded in t+X	
					replace `em'_rank`tt'_`suf'`def'_v3=`em'_rank`tt'_`suf'`def'_v2
					replace `em'_rank`tt'_`suf'`def'_v3=100 if temp_tc_inc==.t & !mi(`em'_rank`tt'_`suf'`def'_v2)
					
					* for v4: get lower bound as rank in t+X
					replace `em'_rank`tt'_`suf'`def'_v4=`em'_rank`tt'_`suf'`def'_v2
					replace `em'_rank`tt'_`suf'`def'_v4=F_cutoff_`em'`tt'_`suf'`def' if temp_tc_inc==.t & !mi(`em'_rank`tt'_`suf'`def'_v2)	
					
					* for v5: set topcoded ranks in t+X to missing
					replace `em'_rank`tt'_`suf'`def'_v5=`em'_rank`tt'_`suf'`def'_v2
					replace `em'_rank`tt'_`suf'`def'_v5=. if temp_tc_inc==.t & !mi(`em'_rank`tt'_`suf'`def'_v2)					

					drop temp_lb												
				}
				
				drop temp_tc_inc temp_co
						
			}
				
		}
		
	}	
	
	} //end qui
	
	* save
	drop if year<2001 | year>2016
	
	local h=subinstr("`het'"," ","",.)
	
	save "${data}/data_topcoded_`h'.dta", replace
	
	restore	
}

* load, check and rename "all" data
use "${data}/data_topcoded_.dta", clear
save "${data}/data_topcoded_all.dta", replace
erase "${data}/data_topcoded_.dta"
clear

********************************************************************************
