

* loop over both samples
foreach sample in siab long short {

if "`sample'"=="siab" local syear = "1985"
if "`sample'"=="long" local syear = "1993"
if "`sample'"=="short" local syear = "2001"

clear
cd "${out}\${folderdate} Upload IAB1993\"


//--- Density CSV ---//

import delimited using "Density_GER.csv", varn(1)

	* non-cross-section to missing
	foreach i of numlist 1 5 {
		foreach var in midp_bin_res_`i'yr_log_chg_distr dens_bin_res_`i'yr_log_chg_distr {
			replace `var' = .
		}
	}
	
	* over 60k real earnings in 2018 euros to missing (high probabilityof imputation)
	replace midp_bin_log_inc_distr = . if midp_bin_log_inc_distr>11
	replace dens_bin_log_inc_distr = . if midp_bin_log_inc_distr>11
	

export delimited using "Density_GER_IAB`syear'-2018.csv", replace nolab


//--- Stats CSV ---//

clear
import delimited using "Stats_GER.csv", varn(1)

	*** set stats to missing for reasons of data privacy and imputed values
	
	*drop top shares
	foreach sh in 5 1 0_5 0_1 0_01 {
		replace share_top`sh'_pct_inc=.
	}

	* variable stats
	foreach vt in log_inc  res_log_inc  log_perm_inc  res_1yr_log_chg  res_5yr_log_chg  arcpct_1yr_chg  arcpct_5yr_chg  {
		
		foreach stat in mean std kelley crows {
			replace `stat'_`vt'=. if nobs_`vt'<20
		}
		replace p50_`vt'=. if nobs_`vt'<40
		foreach pp in 25 75 {
			replace p`pp'_`vt'=. if nobs_`vt'<80
		}
		foreach pp in 12_5 37_5 62_5 87_5 {
			replace p`pp'_`vt'=. if nobs_`vt'<160
		}
		foreach pp in 10 90 9010 9050 5010 {
			replace p`pp'_`vt'=. if nobs_`vt'<200
		}
		replace p5_`vt'=. if nobs_`vt'<400
		replace p2_5_`vt'=. if nobs_`vt'<800
		replace p1_`vt'=. if nobs_`vt'<2000
		foreach pp in 90 95 97_5 99 99_9 99_99 {
			replace p`pp'_`vt'=.
		}
		cap replace p9010_`vt'=.
		cap replace p9050_`vt'=.
	}
	
	* autocorr
	forval i=1/5 {
		replace autocorr_lag`i'_res_log_inc = .
		replace autocorr_lag`i'_res_1yr_log_chg = .
	}
	
	replace pareto_tail_index_5pct = .
	replace pareto_tail_index_1pct = .

export delimited using "Stats_GER_IAB`syear'-2018.csv", replace nolab



if "`sample'"=="short" {
	
	
//--- Mobility CSV ---//	
	
	clear
	import delimited using "Mobility_GER.csv", varn(1)	
			
	replace avg_pct_year_t_1_log_inc=. if pct_year_t_log_earnings>=90	
	replace avg_pct_year_t_5_log_inc=. if pct_year_t_log_earnings>=90	
		
	export delimited using "Mobility_GER_IAB`syear'-2018.csv", replace nolab
	

//--- Rank CSV ---//
	
	clear
	import delimited using "Rank_GER.csv", varn(1)	
		
	
	
	foreach vt in res_1yr_log_chg_by_skill  res_5yr_log_chg_by_skill  arcpct_1yr_chg_by_skill  arcpct_5yr_chg_by_skill {
		
		foreach stat in mean  std  skew  kurt  kelley  crows  {
			replace `stat'_`vt'=. if rank_permanent_inc>=90
			replace `stat'_`vt'=. if nobs_`vt'<40
		}
		foreach pp in 1 2_5 5 10 12_5 25 37_5 50 62_5 75 87_5 90 95 97_5 99 99_9 99_99 9010 9050 5010 {
			replace p`pp'_`vt'=. if rank_permanent_inc>=90
		}
		replace p50_`vt'=. if nobs_`vt'<40
		replace p25_`vt'=. if nobs_`vt'<80
		replace p75_`vt'=. if nobs_`vt'<80
		foreach pp in 12_5 25 37_5 62_5 75 87_5 {
			replace p`pp'_`vt'=. if nobs_`vt'<160
		}
		foreach pp in 9010 9050 5010 {
			replace p`pp'_`vt'=. if nobs_`vt'<200
		}
		foreach pp in 5 95  {
			replace p`pp'_`vt'=. if nobs_`vt'<400
		}
		foreach pp in 2_5 10 90 97_5 {
			replace p`pp'_`vt'=. if nobs_`vt'<800
		}
		foreach pp in 1 99 {
			replace p`pp'_`vt'=. if nobs_`vt'<2000
		}
		replace p99_9_`vt'=. if nobs_`vt'<20000
		replace p99_99_`vt'=. if nobs_`vt'<200000
		
		/*
		foreach pp in 90 95 97_5 99 99_9 99_99 9010 9050 {
			replace p`pp'_`vt'=. 
		}
		*/
		
	}
			
	export delimited using "Rank_GER_IAB`syear'-2018.csv", replace nolab	
	
}

}
clear 	

