*! v20220530 hw
/*---------------------------------------------------------*/
*! Researchproject: Inequality and Inceom Dynamics in Germany (GRID project)
*! Author: Hannes Walz
/*---------------------------------------------------------*/


// =============== Preamble ================ //

{
//--- Settings ---//

* clearing
clear all
program drop _all
macro drop _all
cap log close _all
clear matrix

* set
version 16.1
set more off, perm
set varabbrev off, perm
set matsize 10000, perm
set maxiter 1000, perm
set iterlog on, perm
set linesize 255
set pagesize 100
set rmsg off, perm
set trace on
set tracedepth 2
set traceexpand off, perm
set tracesep off, perm
set traceindent off, perm
set tracenumber off, perm    

* date
global mydate: di %td_CY-N-D date("$S_DATE", "DMY")
global mydate=strltrim("$mydate")

* seed
set seed 190424


//--- paths ---//

* checks
pwd 
sysdir

* paths
global root     = "...\" 	 				// !!! change main dir path here !!!
	global do     = "${root}`c(dirsep)'do`c(dirsep)'"
	global data     = "${root}`c(dirsep)'dta`c(dirsep)'"
	global log      = "${root}`c(dirsep)'log`c(dirsep)'"
	global orig     = "${root}`c(dirsep)'orig`c(dirsep)'"
	global figs     = "${root}`c(dirsep)'figs`c(dirsep)'"
	global out      = "${root}`c(dirsep)'out`c(dirsep)'"	
foreach dir in "log" "data" "figs" "out" {
	cap mkdir "$`dir'"
}
cd "${root}"

* main log path
global mainlog "${log}${mydate}"
cap mkdir "${log}${mydate}"

* set project ado dir
adopath ++ "${do}/"

*check ado paths
adopath
}

/*===========================================================================================*/
/*                                      Main Program                                         */
/*===========================================================================================*/
capture program drop main
program define main
	set matsize 4000
	set li 120 // 200
	set trace on
	set tracesep off
	set tracedepth 1 //2
  
	local time = subinstr("`=c(current_time)'",":","",.)
	scalar d = date("`=c(current_date)'","DMY") 	// create log file including time and date in file name
	local b  _`=subinstr("`c(current_date)'"," ","",.)'_`time'
	global logfile ${mainlog}/${mydate}_GRID_Germany_IAB_CSVs.log
	log using $logfile , text replace name(IAB_CSVs_`b')
	
	
	// =====================================
    // CSV Files IAB-only
    // =====================================	
	
	* IAB sample 1985-2018
	csv_sample19852018

	* IAB sample 1993-2018
	csv_sample19932018
	
	* IAB sample 2001-2016	
	csv_sample20012016

	
	// =====================================
    // CSV mobility topcoded
    // =====================================	
	
	* mobility topcoded csv and shares topcoded sample 2001-2016
	csv_mobility_topcoded
	
	
	cap log IAB_CSVs_`b'

end // main program

/*===========================================================================================*/
/*                                   Main Programs                                           */
/*===========================================================================================*/

/*---------------------------------------------*/
/* CSVs for IAB sample 1985 - 2018   */
/*---------------------------------------------*/
capture program drop csv_sample19852018
program define csv_sample19852018

	global do   = "${root}\csv_sample19852018\"

	
	do "${do}/0_Initialize.do"

	* 1
	do "${do}/1_Gen_Base_Sample.do"

	* 3
	do "${do}/3_Inequality.do"

	* 4
	do "${do}/4_Volatility.do"

	* 5
	do "${do}/5_Mobility.do"

	* 6
	do "${do}/6_Insheeting_datasets_reduced.do"
	
	* data protection
	do "${do}/data_protect.do"

	
end // csv_sample19852018
	
/*---------------------------------------------*/
/* CSVs for IAB sample 1993 - 2018   */
/*---------------------------------------------*/
capture program drop csv_sample19932018
program define csv_sample19932018

	global do   = "${root}\csv_sample19932018\"

	
	do "${do}/0_Initialize.do"

	* 1
	do "${do}/1_Gen_Base_Sample.do"

	* 3
	do "${do}/3_Inequality.do"

	* 4
	do "${do}/4_Volatility.do"

	* 5
	do "${do}/5_Mobility.do"

	* 6
	do "${do}/6_Insheeting_datasets_reduced.do"
	
	* data protection
	do "${do}/data_protect.do"
	
end // csv_sample19932018
	
/*---------------------------------------------*/
/* CSVs for IAB sample 2001 - 2016   */
/*---------------------------------------------*/
capture program drop csv_sample20012016
program define csv_sample20012016

	global do   = "${root}\csv_sample20012016\"

	
	do "${do}/0_Initialize.do"

	* 1
	do "${do}/1_Gen_Base_Sample.do"

	* 3
	do "${do}/3_Inequality.do"

	* 4
	do "${do}/4_Volatility.do"

	* 5
	do "${do}/5_Mobility.do"

	* 6
	do "${do}/6_Insheeting_datasets_reduced.do"
	
	* data protection
	do "${do}/data_protect.do"	
	
end // csv_sample20012016

/*---------------------------------------------*/
/* CSVs for topcoded mobility and shares (sample 2001-2016)   */
/*---------------------------------------------*/
capture program drop csv_mobility_topcoded
program define csv_mobility_topcoded

	global do   = "${root}\csv_mobility_topcoded"

	
	* gen data sets
	do "${do}/_1_prep_datasets.do"

	* prep data
	do "${do}/_2_data_prep.do"

	* gen mobility csv
	do "${do}/_4_mobility_csv.do"	

	
end // csv_mobility_topcoded


/*---------------------------------------------------------*/
/* Run Main Program */
/*---------------------------------------------------------*/
main // run main program

cap log close _all
set trace off
clear
exit

/*========================================= END ==============================================*/
