*! v20220525 hw
/*---------------------------------------------------------*/
*! Researchproject: Inequality and Inceom Dynamics in Germany (GRID project)
*! Author: Johannes F. Schmieder / Stefanie Wolter / Hannes Walz
/*---------------------------------------------------------*/


// =============== Preamble ================ //

{
//--- Settings ---//

* clearing
clear all
program drop _all
macro drop _all
cap log close _all
clear matrix

* set
version 16.1
set more off, perm
set varabbrev off, perm
set matsize 10000, perm
set maxiter 1000, perm
set iterlog on, perm
set linesize 255
set pagesize 100
set rmsg off, perm
set trace on
set tracedepth 2
set traceexpand off, perm
set tracesep off, perm
set traceindent off, perm
set tracenumber off, perm    

* date
global mydate: di %td_CY-N-D date("$S_DATE", "DMY")
global mydate=strltrim("$mydate")

* seed
set seed 190424


//--- paths ---//

* checks
pwd 
sysdir

* paths
global root     = "...\" 	 				// !!! change main dir path here !!!
	global do     = "${root}`c(dirsep)'do`c(dirsep)'"
	global data     = "${root}`c(dirsep)'dta`c(dirsep)'"
	global log      = "${root}`c(dirsep)'log`c(dirsep)'"
	global orig     = "${root}`c(dirsep)'orig`c(dirsep)'"
	global figs     = "${root}`c(dirsep)'figs`c(dirsep)'"
	global out      = "${root}`c(dirsep)'out`c(dirsep)'"	
foreach dir in "log" "data" "figs" "out" {
	cap mkdir "$`dir'"
}
cd "${root}"

* main log path
global mainlog "${log}${mydate}"
cap mkdir "${log}${mydate}"

* set project ado dir
adopath ++ "${do}/"

*check ado paths
adopath
}

/*===========================================================================================*/
/*                                      Main Program                                         */
/*===========================================================================================*/
capture program drop main
program define main
	set matsize 4000
	set li 120 // 200
	set trace on
	set tracesep off
	set tracedepth 1 //2
  
	local time = subinstr("`=c(current_time)'",":","",.)
	scalar d = date("`=c(current_date)'","DMY") 	// create log file including time and date in file name
	local b  _`=subinstr("`c(current_date)'"," ","",.)'_`time'
	global logfile ${mainlog}/${mydate}_GRID_Germany_preparation_SIAB.log
	log using $logfile , text replace name(preparation_SIAB_`b')
	
	// =====================================
	// Generate Yearly Data from Spell Data
	// =====================================

	* SIAB prep for very long sample
	prep_SIAB
	
	cap log preparation_SIAB_`b'

end // main program

/*===========================================================================================*/
/*                                   Main Programs                                           */
/*===========================================================================================*/

/*---------------------------------------------*/
/* SIAB data preparation */
/*---------------------------------------------*/
cap program drop prep_SIAB
program define prep_SIAB

	prep_SIAB

	clean_yearly_siab, in(${data}SIAB_west_cleaned.dta) out(${data}clean_yearly_siab)  

end //prep_SIAB	

/*===========================================================================================*/
/*                                    Sub Programs                                           */
/*===========================================================================================*/

/*---------------------------------------------*/
/* SIAB data preparation */
/*---------------------------------------------*/
cap program drop prep_SIAB
program define prep_SIAB

	* Open SIAB and add base establishment file
	use $orig/SIAB_7519_v1.dta, clear
	gen jahr= year(begepi)
	merge m:1 betnr jahr using $orig/SIAB_7519_v1_bhp_basis_v2.dta, keepusing(ao_kreis ao_bula) nogen keep(3)

	rename jahr year

	* Restrict to BEH spells in West Germany
	keep if quelle==1
	keep if ao_bula<=10
	
	// Beitragsbemaessungsgrenze
	gen bbg=.
	replace bbg= 	47.06	if year==	1975	&  ao_bula<=10
	replace bbg= 	51.96	if year==	1976	&  ao_bula<=10
	replace bbg= 	57.15	if year==	1977	&  ao_bula<=10
	replace bbg= 	62.19	if year==	1978	&  ao_bula<=10
	replace bbg= 	67.24	if year==	1979	&  ao_bula<=10
	replace bbg= 	70.4	if year==	1980	&  ao_bula<=10
	replace bbg= 	73.96	if year==	1981	&  ao_bula<=10
	replace bbg= 	79		if year==	1982	&  ao_bula<=10
	replace bbg= 	84.04	if year==	1983	&  ao_bula<=10
	replace bbg= 	87.17	if year==	1984	&  ao_bula<=10
	replace bbg= 	90.76	if year==	1985	&  ao_bula<=10
	replace bbg= 	94.13	if year==	1986	&  ao_bula<=10
	replace bbg= 	95.81	if year==	1987	&  ao_bula<=10
	replace bbg= 	100.58	if year==	1988	&  ao_bula<=10
	replace bbg= 	102.53	if year==	1989	&  ao_bula<=10
	replace bbg= 	105.89	if year==	1990	&  ao_bula<=10
	replace bbg= 	109.26	if year==	1991	&  ao_bula<=10
	replace bbg= 	113.99	if year==	1992	&  ao_bula<=10
	replace bbg=	121.03	if year==	1993	&  ao_bula<=10
	replace bbg=	127.75	if year==	1994	&  ao_bula<=10
	replace bbg=	131.12	if year==	1995	&  ao_bula<=10
	replace bbg=	134.11	if year==	1996	&  ao_bula<=10
	replace bbg=	137.84	if year==	1997	&  ao_bula<=10
	replace bbg=	141.20	if year==	1998	&  ao_bula<=10
	replace bbg=	142.88	if year==	1999	&  ao_bula<=10
	replace bbg=	144.17	if year==	2000	&  ao_bula<=10
	replace bbg=	146.24	if year==	2001	&  ao_bula<=10
	replace bbg=	147.95	if year==	2002	&  ao_bula<=10
	replace bbg=	167.67	if year==	2003	&  ao_bula<=10
	replace bbg=	168.85	if year==	2004	&  ao_bula<=10
	replace bbg=	170.96	if year==	2005	&  ao_bula<=10
	replace bbg=	172.6	  if year==	2006	&  ao_bula<=10
	replace bbg=	172.6	  if year==	2007	&  ao_bula<=10
	replace bbg=	173.77	if year==	2008	&  ao_bula<=10
	replace bbg=	177.53	if year==	2009	&  ao_bula<=10
	replace bbg=	180.82	if year==	2010	&  ao_bula<=10
	replace bbg=	180.82	if year==	2011	&  ao_bula<=10
	replace bbg=	183.61	if year==	2012	&  ao_bula<=10
	replace bbg=	190.68	if year==	2013	&  ao_bula<=10
	replace bbg=	195.62	if year==	2014	&  ao_bula<=10
	replace bbg=	198.90	if year==	2015	&  ao_bula<=10
	replace bbg=	203.28	if year==	2016	&  ao_bula<=10
	replace bbg=	208.77	if year==	2017	&  ao_bula<=10
	replace bbg=	213.69	if year==	2018	&  ao_bula<=10


	gen censor=(tentgelt>=(bbg-2) & tentgelt<.)
	tab censor if quelle==1

	gen cpi=.
	replace cpi=   39.9418892256144   if year == 1975
	replace cpi=   41.6380739865225   if year == 1976
	replace cpi=   43.1929100173549   if year == 1977
	replace cpi=   44.3671917749067   if year == 1978
	replace cpi=   46.1612333489441   if year == 1979
	replace cpi=   48.6728915525964   if year == 1980
	replace cpi=   51.7608176557881   if year == 1981
	replace cpi=   54.4736259753174   if year == 1982
	replace cpi=   56.2676675493548   if year == 1983
	replace cpi=   57.6213534643103   if year == 1984
	replace cpi=   58.7358338360608   if year == 1986
	replace cpi=   58.8826190557548   if year == 1987
	replace cpi=   59.6328546230795   if year == 1988	
	replace cpi=	61.291	if year==	1989
	replace cpi=	62.944	if year==	1990
	replace cpi=	65.491	if year==	1991
	replace cpi=	68.803	if year==	1992
	replace cpi=	71.882	if year==	1993
	replace cpi=	73.817	if year==	1994
	replace cpi=	75.077	if year==	1995
	replace cpi=	76.165	if year==	1996
	replace cpi=	77.642	if year==	1997
	replace cpi=	78.350	if year==	1998
	replace cpi=	78.808	if year==	1999
	replace cpi=	79.944	if year==	2000
	replace cpi=	81.529	if year==	2001
	replace cpi=	82.688	if year==	2002
	replace cpi=	83.543	if year==	2003
	replace cpi=	84.935	if year==	2004
	replace cpi=	86.249	if year==	2005
	replace cpi=	87.609	if year==	2006
	replace cpi=	89.623	if year==	2007
	replace cpi=	91.978	if year==	2008
	replace cpi=	92.266	if year==	2009
	replace cpi=	93.284	if year==	2010
	replace cpi=	95.220	if year==	2011
	replace cpi=	97.133	if year==	2012
	replace cpi=	98.594	if year==	2013
	replace cpi=	99.488	if year==	2014
	replace cpi=	100.000	if year==	2015
	replace cpi=	100.492	if year==	2016
	replace cpi=	102.009	if year==	2017
	replace cpi=	103.776	if year==	2018



	label var cpi "CPI (2015=100)"

	** Restrict to BEH spells in West Germany

	*****************************************************************************
	// Additional prep from Johannes: 0_German_specific_data_prep
	******************************************************************************
		g byte german = nation==0
		drop nation

		rename begepi begindate
		rename endepi enddate
		rename tentgelt wage
		rename beruf occ
		rename persnr persid
		rename ausbildung_imp educ
		isid persid spell
		count if wage>=999
		count if wage==0

		replace wage=. if wage==0
		replace wage=. if wage>=999

		label var wage "Nominal Wage"

		g int age = year(begindate)- gebjahr 
		g int dumdate = mdy(month(gebmon),day(gebmon),year(gebjahr)+age)
		replace dumdate = mdy(month(gebmon),day(gebmon),year(gebjahr)+age)+1 if dumdate==. // Must be born on a leap day , have to adjust
			// Assume someone born on leap day turns one year older on March 1st?
		replace age = age -1 if dumdate>begindate
			// The birthday in the current year happens after the current date, therefore not yet that age!
		drop dumdate
		*g int agedays = begindate - geb_dat
		drop gebmon

		rename teilzeit parttime
		g byte gering=(erwstat==109 | erwstat==209)

		rename frau female
		replace german=1-german
		rename german nonger

	
		rename occ occ3dig

			/*---------( Generate Continuous Schooling Variable )--------*/
		replace educ = 0 if educ>=7
		bys persid (educ): replace educ=educ[_N]
		replace educ = . if educ==0
		g byte edyrs=.

		replace edyrs= 10 if educ==1  // 9-10 + 0-1 years (9.1)
		replace edyrs= 10 if educ==2  // 9-10 + 2-3 years (11.6)	label var occ "Occupation"
		replace edyrs= 13 if educ==3  // 13 years (12.9)
		replace edyrs= 15 if educ==4  // 13 + 2 years (15) --> Steffi typo korrigiert 15 statt 13?
		replace edyrs= 16 if educ==5  // 12 + 4 years (16.4)
		replace edyrs= 18 if educ==6  // 13 + 5 years (18)

		g byte exp=age-edyrs-6

		g byte fulltime =  parttime==0
		g spelllength = enddate - begindate+1

		bys persid betnr : g byte dum = _n==1
		by persid : g byte bnn = sum(dum)


		bys persid bnn (begindate): g entrydate = begindate[1]
		g entry = year(entrydate)

		// Gen Observations which will be used
		gsort persid begindate -wage
		by persid begindate: gen ieb_level_2=_n-1
		g byte touse = ieb_level_2==0 & erwstat==101  				/* Drop Azubis and Double Spells */

		// replace touse = 0 if !(age>=21 & age<=64)		 /* As in Beaudry&DiNardo */
		replace touse = 0 if educ==9|educ==0|educ==7 		/* Drop Missing/Unknown Education */

		// tenure & experience	including the current spell
		bys persid bnn (spell): gen tenure = sum(spelllength * (fulltime==1|parttime==1) * touse)

		bys persid (spell): gen experience = sum(spelllength * (fulltime==1|parttime==1) * touse)
		*bys persid isicsec (spell): gen indtenure = sum(spelllength * (fulltime==1|parttime==1) * touse)

		replace tenure = tenure / 365.25
		replace experience = experience / 365.25
		*replace indtenure = indtenure / 365.25

		rename gebjahr byear

		// Label Variables
		label var female "Female"
		label var age "Age"
		*label var uniform "Random Variable Uniform (0,1) Distribution"
		label var fulltime "Fulltime Worker"
		label var spelllength "Length of Spell in Days"
		label var nonger "Non-German"
		label var byear "Birth year"
		label var year "Year"
		label var parttime "Parttime"
		*label var occ3dig "Occupation 3 Digit"
		*label var isicsec "Industry ISIC 3 Section"
		label var edyrs "Education years"
		label var entrydate "Begin date of first spell at BNR"
		label var entry "Begin year of first spell at BNR"
		label var exp "Potential experience"
		label var experience "Actual experience, but censored 1975"
		label var tenure "Tenure with current Employer"
		*label var indtenure "Tenure in current Industry"
		format %d begindate enddate


		*g la2 = erwstat if quelle==2
		g pers_gr = erwstat if quelle==1

	gen byte west= inrange(ao_bula, 1,10)
	replace west=. if ao_bula==20
		label define west 0 "East Germany" 1 "West Germany"
		label values west west
		
	save ${data}/SIAB_before_wage_imputation.dta, replace
		
	// Imputed wages
		
	do ${do}/09_wages_imputation.do
		
	// Only observations for west Germany
	keep if west==1
		
	rename wage_imp te_imp
	keep persid year erwstat wage te_imp betnr begindate enddate spell spelllength fulltime parttime gering /// Basic spell variables
		censor cpi  gering  bbg /// More spell variables
		byear educ edyrs female nonger west  /// demographics
		
	save "${data}SIAB_west_cleaned.dta", replace

end //prep_SIAB

/*---------------------------------------------*/
/* Create Person by Year level data from SIAB*/
/*---------------------------------------------*/
cap program drop clean_yearly_siab
program define clean_yearly_siab
	syntax, in(str) out(str)

	use persid year erwstat wage te_imp betnr begindate enddate spell spelllength fulltime parttime gering /// Basic spell variables
		censor cpi gering  bbg /// More spell variables
		byear educ edyrs female nonger west  /// demographics
	    using `in' , clear

	// German mimimum wage as lowest income Min wage (2015): 8.50 * 260 in real terms

	gen min_income=2300 		//!hw old formel: ((8.84*260)*cpi)/100
	
	replace cpi=   71.8815351801058   if year == 1993
	replace cpi=   73.8173455045538   if year == 1994
	replace cpi=   75.0767883662429   if year == 1995
	replace cpi=   76.1651957775791   if year == 1996
	replace cpi=   77.6423201215354   if year == 1997
	replace cpi=   78.3497849389040   if year == 1998
	replace cpi=   78.8084709193957   if year == 1999
	replace cpi=   79.9435243626463   if year == 2000
	replace cpi=   81.5294894477363   if year == 2001
	replace cpi=   82.6878659069441   if year == 2002
	replace cpi=   83.5430431587083   if year == 2003
	replace cpi=   84.9346497774882   if year == 2004
	replace cpi=   86.2485130097440   if year == 2005
	replace cpi=   87.6090222739143   if year == 2006
	replace cpi=   89.6225759848864   if year == 2007
	replace cpi=   91.9782005965641   if year == 2008
	replace cpi=   92.2658511267030   if year == 2009
	replace cpi=   93.2842894901676    if year == 2010
	replace cpi=   95.2200998146156    if year == 2011
	replace cpi=   97.1325871231064    if year == 2012
	replace cpi=   98.5941627897579    if year == 2013
	replace cpi=   99.4882117347841    if year == 2014
	replace cpi=   100.0000000000000   if year == 2015
	replace cpi=   100.4917486247710   if year == 2016
	replace cpi=   102.0086681113520   if year == 2017
	replace cpi=   103.7756292715450   if year == 2018
	
	cap destring erwstat, force replace

	g byte employed = erwstat>=101  & erwstat<=109 & wage>0 & wage<.

	keep if employed==1

	g byte regular = !gering

	replace spelllength = enddate - begindate+1

	replace year = year(begindate)

	sort persid spell
	by persid: replace spell = _n

	g invwage = wage * -1 // just used for sorting - highest value first, infinity last

	// Drop Duplicate Notifications
	// label 2 notification from same firm as duplicate, prefer higher paying notification
	bys persid year betnr begindate enddate (invwage): g duplicate_notification = _n>1 
	
	drop if duplicate_notification ==1
	drop duplicate_notification invwage

	// Consistency Check
	assert spelllength <= 366 if employed // 	replace spelllength = 365 if spelllength > 365
	replace wage = 0 if wage==.
	
	// Fill in imputed wage with observed wage either if there is no imputed wage or
	// if the observation is not actually censored.
	rename te_imp wage_imputed
	
	replace  wage_imputed = wage if missing(wage_imputed) | censor==0

	// g rwage = nom_wage / cpi * 100
	// g nom_wage = rwage * cpi / 100

	// Generate yearly earnings	for all regular jobs
	bys persid year: egen earn_all_regular = sum(wage * spelllength * employed * regular)
	bys persid year: egen earn_full_regular = sum(wage * spelllength * fulltime * employed * regular)

	bys persid year: egen earn_all_regular_imputed = sum(wage_imputed * spelllength * employed * regular)
	bys persid year: egen earn_full_regular_imputed = sum(wage_imputed * spelllength * fulltime * employed * regular)

	// Generate yearly earnings	for all jobs (including Mini Jobs)
	bys persid year: egen earn_all = sum(wage * spelllength * employed)
	bys persid year: egen earn_full = sum(wage * spelllength * fulltime * employed)

	bys persid year: egen earn_all_imputed = sum(wage_imputed * spelllength * employed)
	bys persid year: egen earn_full_imputed = sum(wage_imputed * spelllength * fulltime * employed)

	// To do:
	// It would be helpful to have a variable for earning from main employer
	bys persid year betnr: egen earn_from_employer = sum(wage * spelllength * employed)
	bys persid year betnr: egen days_from_employer = sum(spelllength * employed)
	assert earn_from_employer<.
	bys persid year (earn_from_employer): g earn_main = earn_from_employer[_N]
	bys persid year (earn_from_employer): g days_main = days_from_employer[_N]
	bys persid year (earn_from_employer): g byte main_employer = (_n==_N) * employed
	drop earn_from_employer

	bys persid year betnr: egen earn_from_employer_imputed = sum(wage_imputed * spelllength * employed)
	assert earn_from_employer_imputed<.
	bys persid year (earn_from_employer_imputed): g earn_main_imputed = earn_from_employer_imputed[_N]
	drop earn_from_employer_imputed

	bys persid year betnr: egen earn_from_employer_regular = sum(wage * spelllength * regular * employed)
	assert earn_from_employer_regular<.
	bys persid year (earn_from_employer_regular): g earn_main_reg = earn_from_employer_regular[_N]
	drop earn_from_employer_regular

	bys persid year betnr: egen earn_from_employer_regular_imp = sum(wage_imputed * spelllength * regular * employed)
	assert earn_from_employer_regular_imp<.
	bys persid year (earn_from_employer_regular_imp): g earn_main_reg_imp = earn_from_employer_regular_imp[_N]
	drop earn_from_employer_regular_imp


	// Earnings from secondary employers
	g earn_second_employers = earn_all - earn_main
	g earn_second_employers_imputed = earn_all_imputed - earn_main_imputed

	// Employment Variables
	bys persid year: egen int days_full = sum(spelllength * fulltime *  employed)
	bys persid year: egen int days_work = sum(spelllength * employed)


	// Identify Main Employment Spell in Year
	bys persid year: gen inverse_earnings = -1 * wage * spelllength
	bys persid year (inverse_earnings) : g main_spell = _n==1
	assert main_spell==0 | main_spell==1

	order persid year earn_all inverse_earnings wage spelllength main_spell
	drop inverse_earnings

	bys persid year: egen sum_main_spell = sum(main_spell)
	tab sum_main_spell
	assert sum_main_spell==1
	drop sum_main_spell
	
	// education dummies
	
	gen school = inlist(educ, 1, 3)
	gen apprent	= inlist(educ, 2,4)
	gen university = inlist(educ, 5,6)

	label var school	"School graduation, no further training"
	label var apprent 	"Apprenticeship training degree"
	label var university	"College or university degree"

	// Keep only one observation per person and year (the one corresponding to highest earnings )
	bys persid year (main_spell): keep if _n==_N
	drop main_spell

	replace days_work = 365 if days_work>=365

	label var persid "Person ID"
	label var year "Year"
	label var betnr "Establishment ID"


	label var earn_all    "Earnings"
	label var earn_full   "Earnings from fulltime employment"
	label var earn_all_imputed    "Earnings (imputed)"
	label var earn_full_imputed   "Earnings from fulltime employment (imputed)"

	label var earn_all_regular    "Earnings (excl. Mini-Jobs)"
	label var earn_full_regular   "Earnings from fulltime employment (excl. Mini-Jobs)"
	label var earn_all_regular_imputed    "Earnings (excl. Mini-Jobs, imputed)"
	label var earn_full_regular_imputed   "Earnings from fulltime employment (excl. Mini, imputed)"

	label var earn_main "Earnings from main employer"
	label var earn_main_imputed "Earnings from main employer (imputed)"
	label var earn_main_reg "Earnings from main employer (excl. Mini-Jobs)"
	label var earn_main_reg_imp "Earnings from main employer, regular (excl. Mini, imputed)"

	label var earn_second_employers "Earnings from secondary employers"
	label var earn_second_employers_imputed "Earnings from secondary employers (imputed)"

	g share_main_emp_earnings = earn_main / earn_all
	g share_main_emp_earnings_imputed = earn_main_imputed / earn_all_imputed
	label var share_main_emp_earnings         "Ratio of main emp. to all earnings"
	label var share_main_emp_earnings_imputed "Ratio of main emp. to all earnings (imputed)"

	label var days_full "Days per year working fulltime"
	label var days_work "Days per year working"

	label var west "West Germany"
	label var byear "Birthyear"
	label var educ "Education"
	label var nonger "Non-German"
	label var regular "Regular employment (not mini)"
   	// GID code asks for "year of death" obviously we don't have this, so we set it to retirement age.
	g dyear = byear + 65
  
	// set up earnings var as in GID code
	cap drop rearn* learn* lrearn*
	
	foreach var of varlist earn* {
  
		// Covert to real values
		// Criteria d (Inflation) in CS Sample

		
		// Winsorization
		bysort year: gen temp= `var' if year-byear+1>= 25 & year- byear+1<= 55 & year< dyear  // yod=. id very big number  
		_pctile temp, p(99.999999)
		bysort year: replace `var'= r(r1) if `var'>=r(r1) & `var'!=. 
		drop temp
		
		// Any earnings that are missing inside of $begin_age and $end_age are set to zero.
		bysort year: replace `var'= 0 if `var'== . &  ///
		   year-byear+1 >= 25& year- byear+1<=55 & year< dyear

			
		// Assing missing if outside of $begin_age and $end_age
		replace `var'= . if year-byear+1 < 25 | year- byear+1>55 
		replace `var'= . if year>= dyear & dyear~=.  // (yod=. is very big number)
		
		// real earnings
		cap drop cpi_base2018
		gen cpi_base2018=(cpi/103.7756292715450)
			g r`var'=`var'/cpi_base2018	

			local lbl : variable label `var'
		label var r`var'  "Real `lbl'"
	}

	g learn_all = log(earn_all)
	g learn_all_imputed = log(earn_all_imputed)
	g learn_all_regular = log(earn_all_regular)
	g learn_all_regular_imputed = log(earn_all_regular_imputed)
	g learn_main_reg = log(earn_main_reg)
	g learn_main_reg_imp = log(earn_main_reg_imp)

	label var learn_all "Log(Earnings)"
	label var learn_all_imputed "Log(Earnings, imp)"
	label var learn_all_regular "Log(Earnings, regular)"
	label var learn_all_regular_imputed "Log(Earnings, regular, imp)"
	label var learn_main_reg "Log(Earnings, main, regular)"
	label var learn_main_reg_imp "Log(Earnings, main, regular, imp)"

	g lrearn_all = log(rearn_all)
	g lrearn_all_imputed = log(rearn_all_imputed)
	g lrearn_all_regular = log(rearn_all_regular)
	g lrearn_all_regular_imputed = log(rearn_all_regular_imputed)
	g lrearn_main_reg = log(rearn_main_reg)
	g lrearn_main_reg_imp = log(rearn_main_reg_imp)

	label var lrearn_all "Log(Real Earnings)"
	label var lrearn_all_imputed "Log(Real Earnings, imp)"
	label var lrearn_all_regular "Log(Real Earnings, regular)"
	label var lrearn_all_regular_imputed "Log(Real Earnings, regular, imp)"
	label var lrearn_main_reg "Log(Real Earnings, main, regular)"
	label var lrearn_main_reg_imp "Log(Real Earnings, main, regular, imp)"

	g male = (1-female)
	label var male "Male"
	label define male 1 "Male" 0 "Female"
	label values male male

	cap {
		label define west 0 "East Germany" 1 "West Germany"
		label values west west
	}

	tab male
	// get 2018-cpi as cpi
	gen cpi_OLD=cpi
	replace cpi=cpi_base2018

	// Add legal cutoffs
	cutoffs
  
	keep persid year betnr ///
		cpi* regular spelllength ///
		erwstat fulltime parttime gering ///
	 	byear dyear male nonger educ school apprent university edyrs   west  ///
		rearn* earn* days_full days_work days_* wage wage_imputed  ///
    share*  ///
	le* lr* ///
    minwage rminwage minicutoff rminicutoff bbg*

	order persid year betnr byear male educ west earn* wage* 
  
	// Earnings at least: Min wage (2015): 8.50 * 260 in real terms -- edit (hw): 2018: 8.84*260=2298.4 -> 2300
	drop if rearn_all<2300

	save `"`out'"', replace

end // clean_yearly_siab

/*---------------------------------------------*/
/* Legal Cutoffs  */
/*---------------------------------------------*/
capture program drop cutoffs
program define cutoffs

	// Bezugsgroesse (from Rentenversicherung) https://de.wikipedia.org/wiki/Bezugsgr%C3%B6%C3%9Fe
	g bezugsgroesse = .
	replace bezugsgroesse = 3115 if year == 2019 & west==1
	replace bezugsgroesse = 3045 if year == 2018 & west==1
	replace bezugsgroesse = 2975 if year == 2017 & west==1
	replace bezugsgroesse = 2905 if year == 2016 & west==1
	replace bezugsgroesse = 2835 if year == 2015 & west==1
	replace bezugsgroesse = 2765 if year == 2014 & west==1
	replace bezugsgroesse = 2695 if year == 2013 & west==1
	replace bezugsgroesse = 2625 if year == 2012 & west==1
	replace bezugsgroesse = 2555 if year == 2011 & west==1
	replace bezugsgroesse = 2555 if year == 2010 & west==1
	replace bezugsgroesse = 2520 if year == 2009 & west==1
	replace bezugsgroesse = 2485 if year == 2008 & west==1
	replace bezugsgroesse = 2450 if year == 2007 & west==1
	replace bezugsgroesse = 2450 if year == 2006 & west==1
	replace bezugsgroesse = 2415 if year == 2005 & west==1
	replace bezugsgroesse = 2415 if year == 2004 & west==1
	replace bezugsgroesse = 2380 if year == 2003 & west==1
	replace bezugsgroesse = 2345 if year == 2002 & west==1
	replace bezugsgroesse = 4480 if year == 2001 & west==1
	replace bezugsgroesse = 4480 if year == 2000 & west==1
	replace bezugsgroesse = 4410 if year == 1999 & west==1
	replace bezugsgroesse = 4340 if year == 1998 & west==1
	replace bezugsgroesse = 4270 if year == 1997 & west==1
	replace bezugsgroesse = 4130 if year == 1996 & west==1
	replace bezugsgroesse = 4060 if year == 1995 & west==1
	replace bezugsgroesse = 3920 if year == 1994 & west==1
	replace bezugsgroesse = 3710 if year == 1993 & west==1
	replace bezugsgroesse = 3500 if year == 1992 & west==1
	replace bezugsgroesse = 3360 if year == 1991 & west==1
	replace bezugsgroesse = 3290 if year == 1990 & west==1

	replace bezugsgroesse = 2870 if year == 2019 & west==0
	replace bezugsgroesse = 2695 if year == 2018 & west==0
	replace bezugsgroesse = 2660 if year == 2017 & west==0
	replace bezugsgroesse = 2520 if year == 2016 & west==0
	replace bezugsgroesse = 2415 if year == 2015 & west==0
	replace bezugsgroesse = 2345 if year == 2014 & west==0
	replace bezugsgroesse = 2275 if year == 2013 & west==0
	replace bezugsgroesse = 2240 if year == 2012 & west==0
	replace bezugsgroesse = 2240 if year == 2011 & west==0
	replace bezugsgroesse = 2170 if year == 2010 & west==0
	replace bezugsgroesse = 2135 if year == 2009 & west==0
	replace bezugsgroesse = 2100 if year == 2008 & west==0
	replace bezugsgroesse = 2100 if year == 2007 & west==0
	replace bezugsgroesse = 2065 if year == 2006 & west==0
	replace bezugsgroesse = 2030 if year == 2005 & west==0
	replace bezugsgroesse = 2030 if year == 2004 & west==0
	replace bezugsgroesse = 1995 if year == 2003 & west==0
	replace bezugsgroesse = 1960 if year == 2002 & west==0
	replace bezugsgroesse = 3780 if year == 2001 & west==0
	replace bezugsgroesse = 3640 if year == 2000 & west==0
	replace bezugsgroesse = 3710 if year == 1999 & west==0
	replace bezugsgroesse = 3640 if year == 1998 & west==0
	replace bezugsgroesse = 3640 if year == 1997 & west==0
	replace bezugsgroesse = 3500 if year == 1996 & west==0
	replace bezugsgroesse = 3290 if year == 1995 & west==0
	replace bezugsgroesse = 3080 if year == 1994 & west==0
	replace bezugsgroesse = 2730 if year == 1993 & west==0
	replace bezugsgroesse = 2100 if year == 1992 & west==0
	replace bezugsgroesse = 1540 if year == 1991 & west==0
	replace bezugsgroesse = 1400 if year == 1990 & west==0

	replace bezugsgroesse = bezugsgroesse / 1.95583 if year <= 2001

	// Mini Jobs Cutoff
	g minicutoff = 390 / 1.95583 if inrange(year,1982,1995)
	replace minicutoff = 1/7 * bezugsgroesse if inrange(year,1996,1998) // Technically until April 1st, 1999
	replace minicutoff = 325 if inrange(year,1999,2002)
	replace minicutoff = 400 if inrange(year,2003,2012)
	replace minicutoff = 450 if year>=2013

	// Minimum Wage
	g float minwage = 0
	replace minwage = 8.5 if inrange(year,2015,2016)
	replace minwage = 8.84 if inrange(year,2017,2018)
	replace minwage = 9.19 if inrange(year,2019,2019)
	replace minwage = 9.35 if inrange(year,2020,2020)

	g rminicutoff = minicutoff / cpi * 100
	g rminwage    = minwage    / cpi * 100

	label var bezugsgroesse "Bezugsgroesse (RV)"
	label var minicutoff    "Mini Job Cutoff"
	label var rminicutoff    "Mini Job Cutoff (real)"
	label var minwage  "Minimum Wage"
	label var rminwage "Minimum Wage (real)"

	gen float bbg_daily_west=.
	gen float bbg_daily_east=.
	replace bbg_daily_west = 47.06  if year == 1975
	replace bbg_daily_west = 51.97  if year == 1976
	replace bbg_daily_west = 57.15  if year == 1977
	replace bbg_daily_west = 62.19  if year == 1978
	replace bbg_daily_west = 67.24  if year == 1979
	replace bbg_daily_west = 70.40  if year == 1980
	replace bbg_daily_west = 73.96  if year == 1981
	replace bbg_daily_west = 79.00  if year == 1982
	replace bbg_daily_west = 84.05  if year == 1983
	replace bbg_daily_west = 87.17  if year == 1984
	replace bbg_daily_west = 90.77  if year == 1985
	replace bbg_daily_west = 94.13  if year == 1986
	replace bbg_daily_west = 95.82  if year == 1987
	replace bbg_daily_west = 100.58 if year == 1988
	replace bbg_daily_west = 102.54 if year == 1989
	replace bbg_daily_west = 105.90 if year == 1990
	replace bbg_daily_west = 109.26 if year == 1991
	replace bbg_daily_west = 113.99 if year == 1992
	replace bbg_daily_west = 121.03	if year == 1993
	replace bbg_daily_west = 127.75	if year == 1994
	replace bbg_daily_west = 131.12	if year == 1995
	replace bbg_daily_west = 134.11	if year == 1996
	replace bbg_daily_west = 137.84	if year == 1997
	replace bbg_daily_west = 141.20	if year == 1998
	replace bbg_daily_west = 142.88	if year == 1999
	replace bbg_daily_west = 144.17	if year == 2000
	replace bbg_daily_west = 146.24	if year == 2001
	replace bbg_daily_west = 147.95	if year == 2002
	replace bbg_daily_west = 167.67	if year == 2003
	replace bbg_daily_west = 168.85	if year == 2004
	replace bbg_daily_west = 170.96	if year == 2005
	replace bbg_daily_west = 172.6  if year == 2006
	replace bbg_daily_west = 172.6	if year == 2007
	replace bbg_daily_west = 173.77	if year == 2008
	replace bbg_daily_west = 177.53	if year == 2009
	replace bbg_daily_west = 180.82	if year == 2010
	replace bbg_daily_west = 180.82	if year == 2011
	replace bbg_daily_west = 183.61	if year == 2012
	replace bbg_daily_west = 190.68	if year == 2013
	replace bbg_daily_west = 195.62	if year == 2014
	replace bbg_daily_west = 198.90	if year == 2015
	replace bbg_daily_west = 203.28	if year == 2016
	replace bbg_daily_west = 208.77	if year == 2017
	replace bbg_daily_west = 213.69	if year == 2018

	*east
	replace bbg_daily_east =	45.39  if year == 1990
	replace bbg_daily_east =	50.43  if year == 1991
	replace bbg_daily_east =	80.47  if year == 1992
	replace bbg_daily_east =	89.09  if year == 1993
	replace bbg_daily_east =	99.18  if year == 1994
	replace bbg_daily_east =	107.58 if year ==	1995
	replace bbg_daily_east =	113.99 if year ==	1996
	replace bbg_daily_east =	119.35 if year ==	1997
	replace bbg_daily_east =	117.67 if year ==	1998
	replace bbg_daily_east =	121.03 if year ==	1999
	replace bbg_daily_east =	119.02 if year ==	2000
	replace bbg_daily_east =	122.71 if year ==	2001
	replace bbg_daily_east =	123.29 if year ==	2002
	replace bbg_daily_east =	139.73 if year ==	2003
	replace bbg_daily_east =	142.62 if year ==	2004
	replace bbg_daily_east =	144.66 if year ==	2005
	replace bbg_daily_east =	144.66 if year ==	2006
	replace bbg_daily_east =	149.59 if year ==	2007
	replace bbg_daily_east =	147.54 if year ==	2008
	replace bbg_daily_east =	149.59 if year ==	2009
	replace bbg_daily_east =	152.88 if year ==	2010
	replace bbg_daily_east =	157.80 if year ==	2011
	replace bbg_daily_east =	157.38 if year ==	2012
	replace bbg_daily_east =	161.10 if year ==	2013
	replace bbg_daily_east =	164.38 if year ==	2014
	replace bbg_daily_east =	170.96 if year ==	2015
	replace bbg_daily_east =	177.05 if year ==	2016
	replace bbg_daily_east =	187.40 if year ==	2017
	replace bbg_daily_east =	190.68 if year ==	2018
	label var bbg_daily_west "Top Coding Threshold - West Germany (Daily Wage)"
	label var bbg_daily_east "Top Coding Threshold - West Germany (Daily Wage)"

	gen cpi_2015=.
	replace cpi_2015=   39.9418892256144   if year == 1975
	replace cpi_2015=   41.6380739865225   if year == 1976
	replace cpi_2015=   43.1929100173549   if year == 1977
	replace cpi_2015=   44.3671917749067   if year == 1978
	replace cpi_2015=   46.1612333489441   if year == 1979
	replace cpi_2015=   48.6728915525964   if year == 1980
	replace cpi_2015=   51.7608176557881   if year == 1981
	replace cpi_2015=   54.4736259753174   if year == 1982
	replace cpi_2015=   56.2676675493548   if year == 1983
	replace cpi_2015=   57.6213534643103   if year == 1984
	replace cpi_2015=   58.8119446907169   if year == 1985
	replace cpi_2015=   58.7358338360608   if year == 1986
	replace cpi_2015=   58.8826190557548   if year == 1987
	replace cpi_2015=   59.6328546230795   if year == 1988
	replace cpi_2015=   61.2909839566595   if year == 1989
	replace cpi_2015=   62.9436768006212   if year == 1990
	replace cpi_2015=   65.4910288078316   if year == 1991
	replace cpi_2015=   68.8028970737547   if year == 1992
	replace cpi_2015=   71.8815351801058   if year == 1993
	replace cpi_2015=   73.8173455045538   if year == 1994
	replace cpi_2015=   75.0767883662429   if year == 1995
	replace cpi_2015=   76.1651957775791   if year == 1996
	replace cpi_2015=   77.6423201215354   if year == 1997
	replace cpi_2015=   78.3497849389040   if year == 1998
	replace cpi_2015=   78.8084709193957   if year == 1999
	replace cpi_2015=   79.9435243626463   if year == 2000
	replace cpi_2015=   81.5294894477363   if year == 2001
	replace cpi_2015=   82.6878659069441   if year == 2002
	replace cpi_2015=   83.5430431587083   if year == 2003
	replace cpi_2015=   84.9346497774882   if year == 2004
	replace cpi_2015=   86.2485130097440   if year == 2005
	replace cpi_2015=   87.6090222739143   if year == 2006
	replace cpi_2015=   89.6225759848864   if year == 2007
	replace cpi_2015=   91.9782005965641   if year == 2008
	replace cpi_2015=   92.2658511267030   if year == 2009
	replace cpi_2015=   93.2842894901676    if year == 2010
	replace cpi_2015=   95.2200998146156    if year == 2011
	replace cpi_2015=   97.1325871231064    if year == 2012
	replace cpi_2015=   98.5941627897579    if year == 2013
	replace cpi_2015=   99.4882117347841    if year == 2014
	replace cpi_2015=   100.0000000000000   if year == 2015
	replace cpi_2015=   100.4917486247710   if year == 2016
	replace cpi_2015=   102.0086681113520   if year == 2017
	replace cpi_2015=   103.7756292715450   if year == 2018

	label var cpi_2015 "CPI (2015=100)"

end // cutoffs


	
/*---------------------------------------------------------*/
/* Run Main Program */
/*---------------------------------------------------------*/
main // run main program

cap log close _all
set trace off
clear
exit

/*========================================= END ==============================================*/
