//=======================================================================================
// Descriptives and Dataset Comparison: TPP and IAB
//=======================================================================================

global incomevars labinc totinc totinc_noKV nonlabinc nonlabinc_noKV businc businc_noSE capinc capinc_noKV inc_kv inc_selfempl


//============================================================================================
// Figure of Earnings Bins: IAB vs TPP vs Combined Data
//============================================================================================

// Load data
import delimited using "${joint_folder}/inequality/bins_labor_male.csv", clear case(preserve)
preserve
  import delimited using "${joint_folder}/inequality/bins_labor.csv", clear case(preserve)
  generate male = 9
  tempfile popdata
  save "`popdata'", replace
restore
append using "`popdata'"

// Pre and post 2012
generate pre2012 = year < 2012
gcollapse N*, by(pre2012 male lb ub)
qui sum lb, meanonly
foreach var of varlist N* {
  replace `var' = `var' / (ub-lb) * 1000 if lb < r(max)
  replace `var' = `var' / 1e6
}
replace lb = lb / 1000
replace ub = ub / 1000
generate midpoint = (ub+lb)/2

       
local byvars pre2012 male
// Quantiles, CDF & Density
foreach source in iab tppraw imp tpp {

  bysort `byvars': gegen _Ntotal = total(N_`source')
  bysort `byvars' (lb): generate _cdf = sum(N_`source' / _Ntotal)
  drop _Ntotal
  
  qui foreach p in 5 10 25 50 75 90 95 99 {
    generate _diff = abs(100*_cdf - `p')
    bysort `byvars' (lb): gegen _mindiff = min(_diff)
    generate p`p'_`source' = N_`source' if _diff == _mindiff
    drop _diff _mindiff 
  }
  drop _cdf

}


// Graph
foreach pre in 0 1 {
foreach m in 0 1 9 {

if `pre' == 0 local presuffix = "_20122016"
else local presuffix = "_20012011"

if `m' == 0 local suffix = "_female"
else if `m' == 1 local suffix = "_male"
else if `m' == 9 local suffix = "_all"

local ub = cond(`m' != 0, 150, 100)

preserve
  keep if male == `m' & pre2012 == `pre'
  keep if lb >= 2 & lb < `ub'

  twoway  (line N_iab N_tppraw N_imp midpoint, lcolor(blue green red) lwidth(*1.5...) lpattern(solid longdash dash)) ///
          /* P10 */ ///
          (scatter p10_iab p10_tppraw p10_imp midpoint, msymbol(O...) msize(*1.5...) color(blue green red) mfcolor(%50...)) ///
          /* P50 */ ///
          (scatter p50_iab p50_tppraw p50_imp midpoint, msymbol(S...) msize(*1.5...) color(blue green red) mfcolor(%50...)) ///
          /* P90 */ ///
          (scatter p90_iab p90_tppraw p90_imp midpoint, msymbol(D...) msize(*1.5...) color(blue green red) mfcolor(%50...)) ///
          /* P99 */ ///
          (scatter p99_iab p99_tppraw p99_imp midpoint, msymbol(T...) msize(*1.5...) color(blue green red) mfcolor(%50...)) ///
          , /* Options */ ///
           legend(order(1 "IAB" 2 "TPP" 3 "IAB-TPP")) ylabel(#6) xlabel(0(25)`ub') ///
           ytitle("Number of Obs. (in Mill.)") ///
           xtitle("Annual Earnings (in 1000 Euro)")
    graph export "$figs_folder/data/bins_labor_iabtpp`presuffix'`suffix'.pdf", replace
  restore
}
}


//============================================================================================
// Table with Descriptive Statistics
//============================================================================================

cap program drop table_descriptives_core
program table_descriptives_core

//--------------------------------------------------------------------------------------------
syntax using [, sources(string) width(real 1.0) year(int 2008) colnumbers]
//--------------------------------------------------------------------------------------------
  
  if "`sources'" == ""      local sources tppfull_raw tppfull tppfull_log
  if "`width'" == ""        local width = 1
  

  // Append Data on Gender and Age Groups
  //-------------------------------------
  tempfile genderage
  clear
  qui foreach source in `sources' {

    preserve
      // load data
      if "`source'" == "joint"            local file = "${joint_folder}/inequality/sumstats_logearn_maleagegp.csv"
      if "`source'" == "iab"              local file = "${iab_folder}/$mydate 206_Distributions/inequality/sumstats_logearn_maleagegp.csv"
      if "`source'" == "tpprv"            local file = "${tpp_folder}/$mydate 206_Distributions (labor, rv)/inequality/sumstats_logearn_maleagegp.csv"
      if "`source'" == "tpprv_raw"        local file = "${tpp_folder}/$mydate 206_Distributions (labor, rv)/inequality/sumstats_hrf_logearn_maleagegp.csv"
      load_csvdata, filename("`file'")
      // use correct headcount in TPP
      if substr("`source'",1,3) == "tpp" & substr("`source'", -3, 3) != "raw" replace N = sum_weights
      // save
      keep year male agegp N 
      generate source = "`source'"
      save "`genderage'", replace
    restore

    // append
    append using "`genderage'"
    
  }
  
  // Rescale to population
  replace N = N / 0.1 if source == "iab"
  replace N = N / 0.25 if substr(source,1,3) == "tpp"
  
  // Total
  gcollapse (sum) N_total=N, by(year source male) merge
  
  // Age group shares
  qui foreach g in 1 2 3 {
    gcollapse (sum) N_agegp`g'=N if agegp == `g', by(year source male) merge
    generate share_agegp`g' = N_agegp`g' / N_total
  }
  
  // Save data
  gcollapse (firstnm) N_total share*, by(source year male)
  tempfile maindata
  save "`maindata'", replace
  
  
  // Append Data on Mean Earnings
  //-------------------------------------
  tempfile meanlabor
  qui foreach source in `sources' {
    preserve
      // load data
      if "`source'" == "joint"            local file = "${joint_folder}/inequality/sumstats_logearn_male.csv"
      if "`source'" == "iab"              local file = "${iab_folder}/$mydate 206_Distributions/inequality/sumstats_labor_male.csv"
      if "`source'" == "tpprv"            local file = "${tpp_folder}/$mydate 206_Distributions (labor, rv)/inequality/sumstats_labor_male.csv"
      if "`source'" == "tpprv_raw"        local file = "${tpp_folder}/$mydate 206_Distributions (labor, rv)/inequality/sumstats_hrf_labor_male.csv"
      load_csvdata, filename("`file'")
      // save
      keep year male meanlabor
      generate source = "`source'"
      save "`meanlabor'", replace
    restore
    // append
    merge 1:1 source year male using "`meanlabor'", nogenerate update
  }
  save "`maindata'", replace
  
  // Append Data on Education Groups
  //-------------------------------------
  
  if strpos("`sources'", "iab") > 0 /*| strpos("`sources'", "mz") > 0*/ {
    load_csvdata, filename("${iab_folder}/$mydate Descriptive_Stat - short/CS_cross_tabulation.csv")
    cap rename numobs N
    generate source = "iab"
    replace N = N / 0.1
    recode educ (.=0) (1 3 = 1) (2=2) (4=3) (5 6 = 4)
    gcollapse (sum) N, by(source year male educ)
    gcollapse (sum) N_total=N, by(year male source) merge
    foreach g of numlist 0/4 {
      gcollapse (sum) N_educ`g'=N if educ == `g', by(year source male) merge
      generate share_educ`g' = N_educ`g' / N_total
    }
    gcollapse (firstnm) share_educ*, by(source year male)
    tempfile educ
    save "`educ'", replace   
  }  

  // Append Data on Employment Types
  //-------------------------------------
  
  if strpos("`sources'", "iab") > 0 {
    load_csvdata, filename("${iab_folder}/$mydate Data ddv cohort plot/data_diff_dep_var_cohort_plot_v2.csv")
    generate source = "iab"
    replace N = N / 0.1
    gcollapse (sum) N, by(source year male jobtype)
    gcollapse (sum) N_total=N, by(year male source) merge
    foreach g of numlist 1/3 {
      gcollapse (sum) N_jobtype`g'=N if jobtype == `g', by(year source male) merge
      generate share_jobtype`g' = N_jobtype`g' / N_total
    }
    gcollapse (firstnm) share_jobtype*, by(source year male)
    tempfile jobtypes
    save "`jobtypes'", replace   
  }  
  
  // Merge Datasets
  //--------------------------------
  use "`maindata'", clear
  if strpos("`sources'", "iab") > 0 {
    merge 1:1 source year male using "`educ'", nogenerate
    merge 1:1 source year male using "`jobtypes'", nogenerate
  }

  
  keep if year == `year'

    
  // Initiate table
  //-------------------------------------
  
  local nsources: word count `sources'
  local ncols = 2 * `nsources' + 1

  
  // Initiate tex-file
  cap file close table
  file open table `using', write replace

  // Begin tabular
  file write table "\newcolumntype{Y}{>{\raggedleft\arraybackslash}X}" _n
  file write table "\begin{tabularx}{`width'\textwidth}{l*{`=`ncols'-1'}{Y}}" _n
  file write table "\toprule \toprule" _n

  
  // Column Meta Header: Gender
  local thisline = ""
  local cmidrules = ""
  local k = 1
  foreach gender in Men Women {
    local firstcol = 2 + (`k'-1)*`nsources'
    local lastcol = `firstcol' + `nsources' - 1
    local thisline = "`thisline' & \multicolumn{`nsources'}{c}{`gender'}"
    local cmidrules = "`cmidrules' \cmidrule(l){`firstcol'-`lastcol'}"
    local ++k
  }
  file write table "`thisline' \\" _n 
  file write table "`cmidrules' " _n 
  
  // Column Header: Sources
  local thisline = ""
  foreach male in 1 0 {
  foreach source in `sources' {
    if "`source'" == "joint" local sourcelabel = "Combined"
    if "`source'" == "iab" local sourcelabel = "IAB"
    if "`source'" == "tpprv" local sourcelabel = "TPP+"
    if "`source'" == "tpprv_raw" local sourcelabel = "TPP"
    local thisline = "`thisline' & \multicolumn{1}{c}{`sourcelabel'}"
  }
  }
  file write table "`thisline' \\" _n
  
  // Column Numbers
  if "`colnumbers'" != "" {
    local thisline = ""
    foreach col of numlist 1/`=`ncols'-1' {
      local thisline = "`thisline' & \multicolumn{1}{c}{(`col')}"
    }
    file write table "`thisline' \\" _n
  }


  file write table "\midrule" _n
  
  
  // Table Content
  //-------------------------------------
           
  // Number of observations
  local thisline = "Observations (in mill.) "
  foreach male in 1 0 {
  foreach source in `sources' {
    qui sum N_total if male == `male' & source == "`source'"
    local stat = strofreal(`=`r(mean)'/1e6', "%9.3f")
    local thisline = "`thisline' & `stat'"
  }
  }
  file write table "`thisline' \\ [1ex]" _n

  // Mean Total Income
  local thisline = "Mean Earnings (in 2018-Euro)"
  foreach male in 1 0 {
  foreach source in `sources' {
    qui sum meanlabor if male == `male' & source == "`source'"
    local stat = strofreal(`r(mean)', "%9.0fc")
    local thisline = "`thisline' & `stat'"
  }
  }
  file write table "`thisline' \\ [1ex]" _n

  // Age Groups
  file write table "\multicolumn{`ncols'}{l}{\emph{A. Age and Nationality}} \\" _n
  foreach g in 1 2 3 {
    if `g' == 1 local statlabel = "\hspace{12pt}Share Age 25--34"
    if `g' == 2 local statlabel = "\hspace{12pt}Share Age 35--44"
    if `g' == 3 local statlabel = "\hspace{12pt}Share Age 45--55"
  
    local thisline = "`statlabel' "
    foreach male in 1 0 {
    foreach source in `sources' {
      qui sum share_agegp`g' if male == `male' & source == "`source'"
      local stat = strofreal(`r(mean)', "%9.3f")
      local thisline = "`thisline' & `stat'"
    }
    }
    local spacing = cond(`g' == 3, "", "")
    file write table "`thisline' \\ `spacing'" _n
  }
  // German
  local thisline = "\hspace{12pt}Non-German"
  foreach male in 1 0 {
  foreach source in `sources' {
    if `male' == 1  local stat = cond("`source'" == "iab", "0.090", "--")
    else            local stat = cond("`source'" == "iab", "0.066", "--")
    local thisline = "`thisline' & `stat'"
  }
  }
  file write table "`thisline' \\ [1ex]" _n
  
  // Education Groups
  if strpos("`sources'", "iab") > 0 {
    file write table "\multicolumn{`ncols'}{l}{\emph{B. Education}} \\" _n
    foreach g of numlist 1/4 0 {
      if `g' == 1 local statlabel = "\hspace{12pt}Schooling ($\leq 10$ years)"
      if `g' == 2 local statlabel = "\hspace{12pt}Vocational training"
      if `g' == 3 local statlabel = "\hspace{12pt}Abitur (\& voc. training)"
      if `g' == 4 local statlabel = "\hspace{12pt}College Degree"
      if `g' == 0 local statlabel = "\hspace{12pt}No Education Data"

      local thisline = "`statlabel' "
      foreach male in 1 0 {
      foreach source in `sources' {
        if "`source'"  == "iab" {
          qui sum share_educ`g' if male == `male' & source == "`source'"
          local stat = strofreal(`r(mean)', "%9.3f")
        }
        else {
          local stat = "--"
        }
        local thisline = "`thisline' & `stat'"
      }
      }
      local spacing = cond(`g' == 0, "[1ex]", "")
      file write table "`thisline' \\ `spacing'" _n
    } 
  } 

  // Employment Level
  if strpos("`sources'", "iab") > 0 {
    file write table "\multicolumn{`ncols'}{l}{\emph{C. Employment Level}} \\" _n
    foreach g of numlist 1/3 {
      if `g' == 1 local statlabel = "\hspace{12pt}Full-Time"
      if `g' == 2 local statlabel = "\hspace{12pt}Part-Time"
      if `g' == 3 local statlabel = "\hspace{12pt}Mini-Job"

      local thisline = "`statlabel' "
      foreach male in 1 0 {
      foreach source in `sources' {
        if "`source'"  == "iab" {
          qui sum share_jobtype`g' if male == `male' & source == "`source'"
          local stat = strofreal(`r(mean)', "%9.3f")
        }
        else {
          local stat = "--"
        }
        local thisline = "`thisline' & `stat'"
      }
      }
      local spacing = cond(`g' == 3, "", "")
      file write table "`thisline' \\ `spacing'" _n
    } 
  } 
  // Days in Employment
  local thisline = "\hspace{12pt}Days in Employment"
  foreach male in 1 0 {
  foreach source in `sources' {
    if `male' == 1  local stat = cond("`source'" == "iab", "342.3", "--")
    else            local stat = cond("`source'" == "iab", "342.2", "--")
    local thisline = "`thisline' & `stat'"
  }
  }
  file write table "`thisline' \\ [1ex]" _n

  // End tabular
  file write table "\bottomrule" _n
  file write table "\end{tabularx}" _n

  // Close tex-file
  file close table

end

table_descriptives_core using "${figs_folder}/data/descriptives_core.tex", year(2008) ///
  sources(iab tpprv_raw) width(1.0) colnumbers
  
  
//============================================================================================
// Table with Descriptive Statistics for Total Income Analysis
//============================================================================================

cap program drop table_descriptives_specific
program table_descriptives_specific

//--------------------------------------------------------------------------------------------
syntax using [, sources(string) width(real 1.0) year(int 2008) colnumbers agegroups active negatives]
//--------------------------------------------------------------------------------------------

  if "`sources'" == ""      local sources tppfull_raw tppfull tppfull_log
  if "`width'" == ""        local width = 1
  if "`year'" == ""         local year = 2008
  
  local incvars totinc_noKV labinc nonlabinc_noKV inc_selfempl businc_noSE capinc_noKV inc_kv
  
  foreach source in `sources' {
    assert inlist("`source'", "tppfull_raw", "tppfull", "tppfull_log")
  }

  // Basic Stats: Gender, Age, Nonzeros, Negatives
  //------------------------------------------------
  tempfile maindata
  clear
  qui foreach source in `sources' {

    preserve
      // load data
      local sample = cond(strpos("`source'", "log") != 0, "_logsample", "")
      local weight = cond(strpos("`source'", "raw") != 0, "_hrf", "")
      local file = "${tpp_folder}/$mydate 106_descriptives/basicstats`sample'`weight'_maleagemainsrc4.csv"
      load_csvdata, filename("`file'")
      keep if year == `year'
      // use correct headcount
      if strpos("`source'", "raw") == 0 {
        replace N = sum_weights
        drop sum_weights
      }
      // save
      generate source = "`source'"
      save "`maindata'", replace
    restore

    // append
    append using "`maindata'"
    
  }
  
  // Rescale to population
  replace N = N / 0.25 if substr(source,1,3) == "tpp"
  
  // Number of Observations
  gcollapse (sum) N_total=N, by(year source male) merge
  
  // Age group
  recode age (25/34 = 1) (35/44 = 2) (45/55 = 3), generate(agegp)
  qui foreach g in 1 2 3 {
    gcollapse (sum) N_agegp`g'=N if agegp == `g', by(year source male) merge
    generate share_agegp`g' = N_agegp`g' / N_total
  }
  
  // Main income source
  qui foreach g of numlist 1/4 {
    gcollapse (sum) N_mainsrc`g'=N if mainsrc == `g', by(year source male) merge
    generate share_mainsrc`g' = N_mainsrc`g' / N_total
  }  
  generate share_mainsrc0 = 1 - share_mainsrc1
  
  // Collapse data
  gcollapse (firstnm) N_total share* ///
            (mean) nonzero_* neg_* ///
            (mean) `incvars' ///
            [aw=N] ///
            , by(source year male)
            
  // Income Shares
  foreach incvar in `incvars' { 
    generate share_`incvar' = `incvar' / totinc_noKV
  }
  
  tempfile maindata
  save "`maindata'", replace
  
  
  // Append Data on Total Income (Mean and Percentiles)
  //--------------------------------------------------
  qui foreach source in `sources' {  
    preserve
      // load data
      local sample = cond(strpos("`source'", "log") != 0, "_logsample", "")
      local weight = cond(strpos("`source'", "raw") != 0, "_hrf", "")
      local file = "${tpp_folder}/$mydate 106_descriptives/sumstats`sample'`weight'_totinc_nokv_male.csv"
      load_csvdata, filename("`file'")
      keep year male meantotinc_noKV p50totinc_noKV p75totinc_noKV p90totinc_noKV p95totinc_noKV p99totinc_noKV p99_9totinc_noKV p99_99totinc_noKV
      keep if year == `year'
      generate source = "`source'"
      tempfile thissource
      save "`thissource'", replace      
    restore    
    merge 1:1 source year male using "`thissource'", nogenerate update
  }
    
    
  // Initiate table
  //-------------------------------------
  
  local nsources: word count `sources'
  local ncols = 2 * `nsources' + 1
  local letters A B C D E F G
  local iletter = 1

  
  // Initiate tex-file
  cap file close table
  file open table `using', write replace

  // Begin tabular
  file write table "\newcolumntype{Y}{>{\raggedleft\arraybackslash}X}" _n
  file write table "\begin{tabularx}{`width'\textwidth}{l*{`=`ncols'-1'}{Y}}" _n
  file write table "\toprule \toprule" _n

  
  // Column Header: Gender
  local thisline = ""
  foreach gender in Men Women {
    local thisline = "`thisline' & \multicolumn{`nsources'}{c}{`gender'}" 
  }
  file write table "`thisline' \\" _n 

  // Column Header: Sources
  if `: word count `sources'' > 1 {

    // Column mid-rules
    local cmidrules = ""
    local k = 1
    foreach gender in Men Women { 
      local firstcol = 2 + (`k'-1)*`nsources'
      local lastcol = `firstcol' + `nsources' - 1
      local cmidrules = "`cmidrules' \cmidrule(l){`firstcol'-`lastcol'}"
      local ++k
    }
    file write table "`cmidrules' " _n 

    // Source labels
    local thisline = ""
    foreach male in 1 0 {
    foreach source in `sources' {
      local sourcelabel = cond(strpos("`source'", "raw") != 0, "TPP", "IAB-TPP")
      local thisline = "`thisline' & \multicolumn{1}{c}{`sourcelabel'}"
    }
    }
    file write table "`thisline' \\" _n
  
    // Column Sub-Header: Log-Sample
    local thisline = ""
    foreach male in 1 0 {
    foreach source in `sources' {
      local sample = cond(strpos("`source'", "log") != 0, "(analysis)", "")
      local thisline = "`thisline' & \multicolumn{1}{c}{`sample'}"
    }
    }
    if strpos("`sources'", "log") != 0 file write table "`thisline' \\" _n
    
  }
  
  // Column Numbers
  if "`colnumbers'" != "" {
    local thisline = ""
    foreach col of numlist 1/`=`ncols'-1' {
      local thisline = "`thisline' & \multicolumn{1}{c}{(`col')}"
    }
    file write table "`thisline' \\" _n
  }
    

  file write table "\midrule" _n
  
  
  // Table Content
  //-------------------------------------
           
  // Number of observations
  local thisline = "Observations (in mill.) "
  foreach male in 1 0 {
  foreach source in `sources' {
    qui sum N_total if male == `male' & source == "`source'"
    local stat = strofreal(`=`r(mean)'/1e6', "%9.3f")
    local thisline = "`thisline' & `stat'"
  }
  }
  file write table "`thisline' \\ [1ex]" _n

  // Mean and Percentiles of Total Income
  local letter: word `iletter' of `letters'
  local ++iletter
  file write table "\multicolumn{`ncols'}{l}{\emph{`letter'. Income Distribution}} \\" _n
  foreach g in mean p50 p90 p99_9 p99_99 {
    local statlabel = cond("`g'" == "mean", "Mean", subinstr(subinstr("`g'", "p", "P", 1), "_", ".", 1))
    local thisline = "\hspace{12pt}`statlabel'"
    foreach male in 1 0 {
    foreach source in `sources' {
      qui sum `g'totinc_noKV if male == `male' & source == "`source'"
      local stat = strofreal(`r(mean)', "%9.0fc")
      local thisline = "`thisline' & `stat'"
    }
    }
    local spacing = cond("`g'" == "p99_99", "[1ex]", "")
    file write table "`thisline' \\ `spacing'" _n
  }
  
  // Age Groups
  if "`agegroups'" != "" {
    local letter: word `iletter' of `letters'
    local ++iletter
    file write table "\multicolumn{`ncols'}{l}{\emph{`letter'. Age}} \\" _n
    foreach g in 1 2 3 {
      if `g' == 1 local statlabel = "\hspace{12pt}Share Age 25--34"
      if `g' == 2 local statlabel = "\hspace{12pt}Share Age 35--44"
      if `g' == 3 local statlabel = "\hspace{12pt}Share Age 45--55"
    
      local thisline = "`statlabel' "
      foreach male in 1 0 {
      foreach source in `sources' {
        qui sum share_agegp`g' if male == `male' & source == "`source'"
        local stat = strofreal(`r(mean)', "%9.3f")
        local thisline = "`thisline' & `stat'"
      }
      }
      local spacing = cond(`g' == 3, "[1ex]", "")
      file write table "`thisline' \\ `spacing'" _n
    }
  }

  // Income Shares
  local letter: word `iletter' of `letters'
  local ++iletter
  file write table "\multicolumn{`ncols'}{l}{\emph{`letter'. Share of Total Income}} \\" _n
  foreach incvar in labinc nonlabinc_noKV inc_selfempl businc_noSE capinc_noKV inc_kv {
    if "`incvar'" == "labinc" local statlabel = "\hspace{12pt}Labor"    
    if "`incvar'" == "nonlabinc_noKV" local statlabel = "\hspace{12pt}Non-Labor"
    if "`incvar'" == "inc_selfempl" local statlabel = "\hspace{24pt}Self-Empl."
    if "`incvar'" == "businc_noSE" local statlabel = "\hspace{24pt}Business"
    if "`incvar'" == "capinc_noKV" local statlabel = "\hspace{24pt}Rental"
    if "`incvar'" == "inc_kv" local statlabel = "\hspace{24pt}Capital$^*$"
    
    local thisline = "`statlabel' "
    foreach male in 1 0 {
    foreach source in `sources' {
      qui sum share_`incvar' if male == `male' & source == "`source'"
      local stat = strofreal(`r(mean)', "%9.3f")
      local thisline = "`thisline' & `stat'"
    }
    }
    local spacing = cond("`incvar'" == "inc_kv", "[1ex]", "")
    file write table "`thisline' \\ `spacing'" _n
  }
  
  // Main Income Source (Labor vs. Non-Labor)
  local letter: word `iletter' of `letters'
  local ++iletter
  file write table "\multicolumn{`ncols'}{l}{\emph{`letter'. Main Income Source}} \\" _n
  foreach g in 1 0 2 3 4 {
    if `g' == 1 local statlabel = "\hspace{12pt}Workers"
    if `g' == 0 local statlabel = "\hspace{12pt}Entrepreneurs"
    if `g' == 2 local statlabel = "\hspace{24pt}Self-Employed"
    if `g' == 3 local statlabel = "\hspace{24pt}Business Owners"
    if `g' == 4 local statlabel = "\hspace{24pt}Landlords"
    local thisline = "`statlabel' "
    foreach male in 1 0 {
    foreach source in `sources' {
      qui sum share_mainsrc`g' if male == `male' & source == "`source'"
      local stat = strofreal(`r(mean)', "%9.3f")
      local thisline = "`thisline' & `stat'"
    }
    }
    local spacing = cond(`g' == 4, "[1ex]", "")
    file write table "`thisline' \\ `spacing'" _n
  }
  
  // Non-Zero Income
  if "`active'" != "" {
    local letter: word `iletter' of `letters'
    local ++iletter
    file write table "\multicolumn{`ncols'}{l}{\emph{`letter'. Non-Zero Income}} \\" _n
    foreach incvar in labinc nonlabinc_noKV inc_selfempl businc_noSE capinc_noKV inc_kv {
      if "`incvar'" == "labinc" local statlabel = "\hspace{12pt}Labor"    
      if "`incvar'" == "nonlabinc_noKV" local statlabel = "\hspace{12pt}Non-Labor"
      if "`incvar'" == "inc_selfempl" local statlabel = "\hspace{12pt}Self-Empl."
      if "`incvar'" == "businc_noSE" local statlabel = "\hspace{12pt}Business"
      if "`incvar'" == "capinc_noKV" local statlabel = "\hspace{12pt}Rental"
      if "`incvar'" == "inc_kv" local statlabel = "\hspace{12pt}Capital$^*$"
      
      local thisline = "`statlabel' "
      foreach male in 1 0 {
      foreach source in `sources' {
        qui sum nonzero_`incvar' if male == `male' & source == "`source'"
        local stat = strofreal(`r(mean)', "%9.3f")
        local thisline = "`thisline' & `stat'"
      }
      }
      local spacing = cond("`incvar'" == "inc_kv", "[1ex]", "")
      file write table "`thisline' \\ `spacing'" _n
    }
  }

  // Negative Income
  if "`negatives'" != "" {
    local letter: word `iletter' of `letters'
    local ++iletter
    file write table "\multicolumn{`ncols'}{l}{\emph{`letter'. Negative Income (if $\neq 0$)}} \\" _n
    foreach incvar in totinc_noKV nonlabinc_noKV inc_selfempl businc_noSE capinc_noKV inc_kv {
      if "`incvar'" == "totinc_noKV" local statlabel = "\hspace{12pt}Total"    
      if "`incvar'" == "nonlabinc_noKV" local statlabel = "\hspace{12pt}Non-Labor"
      if "`incvar'" == "inc_selfempl" local statlabel = "\hspace{12pt}Self-Empl."
      if "`incvar'" == "businc_noSE" local statlabel = "\hspace{12pt}Business"
      if "`incvar'" == "capinc_noKV" local statlabel = "\hspace{12pt}Rental"
      if "`incvar'" == "inc_kv" local statlabel = "\hspace{12pt}Capital$^*$"
      
      local thisline = "`statlabel' "
      foreach male in 1 0 {
      foreach source in `sources' {
        qui sum neg_`incvar' if male == `male' & source == "`source'"
        local stat = strofreal(`r(mean)', "%9.3f")
        local thisline = "`thisline' & `stat'"
      }
      }
      local spacing = cond("`incvar'" == "inc_kv", "[1ex]", "")
      file write table "`thisline' \\ `spacing'" _n
    }
  }
  
  // End tabular
  file write table "\bottomrule" _n
  file write table "\end{tabularx}" _n

  // Close tex-file
  file close table

end

table_descriptives_specific using "${figs_folder}/data/descriptives_specific.tex", year(2008) ///
  sources(tppfull_raw tppfull tppfull_log) width(1.0) colnumbers negatives active
table_descriptives_specific using "${figs_folder}/data/descriptives_specific_analysisonly.tex", year(2008) ///
  sources(tppfull_log) width(0.66) active 
  

//============================================================================================
// Compact Table of Earnings Percentiles (only one  data set, by gender)
//============================================================================================

cap program drop tables_earnings_pctiles
program tables_earnings_pctiles

//--------------------------------------------------------------------------------------------
syntax using [, source(string) years(numlist ascending int) percentiles(numlist ascending) kFsample(int 0)]
//--------------------------------------------------------------------------------------------
  
  if "`source'" == ""       local source joint
  if "`years'" == ""        local years 2001 2005 2010 2015
  if "`percentiles'" == ""  local percentiles 5 10 25 50 75 90 95 99 99.9 99.99
  
  assert inlist(`kFsample', 0, 1, 5)
  assert `kFsample' == 0 | strpos("`source'", "raw") == 0

  // Load data
  if `kFsample' == 0 {
    if "`source'" == "joint" local file = "${joint_folder}/inequality/sumstats_labor_male.csv"
    if "`source'" == "iab" local file = "${iab_folder}/$mydate 206_Distributions/inequality/sumstats_labor_male.csv"
    if "`source'" == "tpp" local file = "${tpp_folder}/$mydate 206_Distributions (labor, rv)/inequality/sumstats_labor_male.csv"
    if "`source'" == "tppraw" local file = "${tpp_folder}/$mydate 206_Distributions (labor, rv)/inequality/sumstats_hrf_labor_male.csv"
    load_csvdata, filename("`file'") dropsuffix(logearn)
  }
  else {
    if "`source'" == "joint" local file = "${joint_folder}/volatility/sumstats_researn`kFsample'Fsample_labor_male.csv"
    if "`source'" == "iab" local file = "${iab_folder}/2021-04-19 Distributions/volatility/sumstats_researn`kFsample'Fsample_labor_male.csv"
    if "`source'" == "tpp" local file = "${tpp_folder}/$mydate 206_Distributions (labor, rv)/volatility/sumstats_researn`kFsample'Fsample_labor_male.csv"
    load_csvdata, filename("`file'") dropsuffix(labor)
  }  
  
  // Rescale to population
  replace N = N  if "`source'" == "joint" 
  replace N = N / 0.1 if "`source'" == "iab" 
  replace N = N / 0.25 if "`source'" == "tpp" | "`source'" == "tppraw"

  
  // Initiate tex-file
  cap file close table
  file open table `using', write replace

  // Number of columns
  local ncols = 3
  local alignchar = "lrr"
  foreach p of numlist `percentiles' {
    local ++ncols
    local alignchar = "`alignchar'r"
  }  
  
  // Begin tabular
  file write table "\begin{tabular}{`alignchar'}" _n
  file write table "\toprule \toprule" _n

  // Header
  local coltitles = "Year & \multicolumn{1}{c}{N} & \multicolumn{1}{c}{Mean}"
  foreach p of numlist `percentiles' {
    local coltitles = "`coltitles' & \multicolumn{1}{c}{P`p'}"
  }
  file write table "`coltitles' \\" _n
  file write table "\midrule" _n

  // Content
  local isource = 1
  qui foreach m in 1 0 {

    if `m' == 0 local gender = "Women"
    if `m' == 1 local gender = "Men"
    
    file write table "\multicolumn{`ncols'}{@{}l}{\textbf{`gender'}} \\" _n
    
    // loop over years
    qui foreach year of numlist `years' {
      
      local thisline = "`year'"
      
      // Number of observations
      sum N if year == `year' & male == `m', meanonly
      local p = strofreal(`=`r(mean)'/1e6', "%9.3f")
      local thisline = "`thisline' & `p'"
      
      // Mean
      sum mean if year == `year' & male == `m', meanonly
      local p = strofreal(`r(mean)', "%9.0fc")
      local thisline = "`thisline' & `p'"

      // Percentiles
      foreach p of numlist `percentiles' {
        local var = "p" + subinstr("`p'", ".", "_", .)
        sum `var' if year == `year' & male == `m', meanonly
        //if `kFsample' == 0 local value = strofreal(`=exp(`r(mean)')', "%9.0fc")
        //else 
        local value = strofreal(`r(mean)', "%9.0fc")
        local thisline = "`thisline' & `value'"
      }

      file write table "`thisline' \\" _n

    }
    
    if `isource' < 2 file write table "\midrule" _n
    local ++isource
  }

  // End tabular
  file write table "\bottomrule" _n
  file write table "\end{tabular}" _n

  // Close tex-file
  file close table
  
end

// CS sample
tables_earnings_pctiles using "${figs_folder}/data/earnings_pctiles_maindata_gender.tex", source(joint) years(2001 2004 2008 2012 2016)
// LS sample
tables_earnings_pctiles using "${figs_folder}/data/earnings_pctiles_maindata_1Fsample_gender.tex", source(joint) kFsample(1) years(2001 2005 2010)
tables_earnings_pctiles using "${figs_folder}/data/earnings_pctiles_maindata_5Fsample_gender.tex", source(joint) kFsample(5) years(2001 2005 2010)



//============================================================================================
// Detailed Table of Earnings Percentiles (all data sets, one table per gender)
//============================================================================================

cap program drop tables_earnings_pctiles_detailed
program tables_earnings_pctiles_detailed

//--------------------------------------------------------------------------------------------
syntax using , gender(string) ///
               [sources(string) years(numlist ascending int) percentiles(numlist ascending)]
//--------------------------------------------------------------------------------------------
  
  if "`sources'" == ""      local sources joint iab tppraw
  if "`years'" == ""        local years 2001 2005 2010 2015
  if "`percentiles'" == ""  local percentiles 5 10 25 50 75 90 95 99 99.9 99.99
  
  assert inlist("`gender'", "male", "female", "all")
  local gendersuf = cond("`gender'" == "all", "", "_male")

  // Append data
  clear
  tempfile sourcedata
  foreach source in `sources' {
    if "`source'" == "joint" local file = "${joint_folder}/inequality/sumstats_labor`gendersuf'.csv"
    if "`source'" == "iab" local file = "${iab_folder}/$mydate 206_Distributions/inequality/sumstats_labor`gendersuf'.csv"
    if "`source'" == "tpp" local file = "${tpp_folder}/$mydate 206_Distributions (labor, rv)/inequality/sumstats_labor`gendersuf'.csv"
    if "`source'" == "tppraw" local file = "${tpp_folder}/$mydate 206_Distributions (labor, rv)/inequality/sumstats_hrf_labor`gendersuf'.csv"
    preserve
      load_csvdata, filename("`file'") dropsuffix(labor)
      generate source = "`source'"
      save "`sourcedata'", replace
    restore
    append using "`sourcedata'"    
  }

  // Rescale to population
  replace N = N  if source == "joint" 
  replace N = N / 0.1 if source == "iab" 
  replace N = N / 0.25 if source == "tpp" | source == "tppraw"


  // Keep subpopulation
  if "`gender'" == "male"         keep if male == 1
  else if "`gender'" == "female"  keep if male == 0

  // Initiate tex-file
  local sourcesclean = subinstr("`sources'", " ", "_", .)
  cap file close table
  file open table `using', write replace

  // Number of columns
  local ncols = 3
  local alignchar = "lrr"
  foreach p of numlist `percentiles' {
    local ++ncols
    local alignchar = "`alignchar'r"
  }
  
  // Number of panels
  local nsources: word count `sources'
  
  
  // Begin tabular
  file write table "\begin{tabular}{`alignchar'}" _n
  file write table "\toprule \toprule" _n

  // Header
  local coltitles = "Year & \multicolumn{1}{c}{N} & \multicolumn{1}{c}{Mean}"
  foreach p of numlist `percentiles' {
    local coltitles = "`coltitles' & \multicolumn{1}{c}{P`p'}"
  }
  file write table "`coltitles' \\" _n
  file write table "\midrule" _n

  // Content
  local isource = 1
  qui foreach source in `sources' {

    if "`source'" == "joint" local sourcelabel = "IAB-TPP Data"
    if "`source'" == "iab" local sourcelabel = "IAB Data"
    if "`source'" == "tppraw" local sourcelabel = "TPP Data"
    if "`source'" == "tpp" local sourcelabel = "TPP Data (IAB-Weighted)"
    file write table "\multicolumn{`ncols'}{@{}l}{\textbf{`sourcelabel'}} \\" _n
    
    // loop over years
    qui foreach year of numlist `years' {
      
      local thisline = "`year'"
      
      // Number of observations
      sum N if year == `year' & source == "`source'", meanonly
      local p = strofreal(`=`r(mean)'/1e6', "%9.3f")
      local thisline = "`thisline' & `p'"
      
      // Mean Earnings
      sum mean if year == `year' & source == "`source'", meanonly
      local p = strofreal(`r(mean)', "%9.0fc")
      local thisline = "`thisline' & `p'"

      // Percentiles
      foreach p of numlist `percentiles' {
        local var = "p" + subinstr("`p'", ".", "_", .)
        sum `var' if year == `year' & source == "`source'", meanonly
        local value = strofreal(`r(mean)', "%9.0fc")
        local thisline = "`thisline' & `value'"
      }

      file write table "`thisline' \\" _n

    }
    
    if `isource' < `nsources' file write table "\midrule" _n
    local ++isource
  }

  // End tabular
  file write table "\bottomrule" _n
  file write table "\end{tabular}" _n

  // Close tex-file
  file close table
  
end


tables_earnings_pctiles_detailed using "${figs_folder}/data/earnings_pctiles_detailed_male.tex", gender(male) years(2001/2016)
tables_earnings_pctiles_detailed using "${figs_folder}/data/earnings_pctiles_detailed_female.tex", gender(female) years(2001/2016)
tables_earnings_pctiles_detailed using "${figs_folder}/data/earnings_pctiles_detailed_all.tex", gender(all) years(2001/2016)


//============================================================================================
// Detailed Table of Earnings Growth Percentiles (all data sets, one table per gender)
//============================================================================================

cap program drop tables_growth_pctiles_detailed
program tables_growth_pctiles_detailed

//--------------------------------------------------------------------------------------------
syntax using , gender(string) ///
               [sources(string) years(numlist ascending int) percentiles(numlist ascending) k(int 1)]
//--------------------------------------------------------------------------------------------

  *local k 1
  *local gender male
  if "`sources'" == ""      local sources joint iab tpp
  if "`years'" == ""        local years 2001 2005 2010 2015
  if "`percentiles'" == ""  local percentiles 1 2.5 10 25 50 75 90 95 97.5 99
  
  assert inlist("`gender'", "male", "female", "all")
  local gendersuf = cond("`gender'" == "all", "", "_male")

  // Append data
  clear
  tempfile sourcedata
  foreach source in `sources' {
    if "`source'" == "joint" local file = "${joint_folder}/volatility/sumstats_researn`k'F`gendersuf'.csv"
    if "`source'" == "iab" local file = "${iab_folder}/$mydate Volatility - short/L_researn`k'F`gendersuf'_sumstat.csv"
    if "`source'" == "tpp" local file = "${tpp_folder}/$mydate 206_Distributions (labor, rv)/volatility/sumstats_researn`k'F`gendersuf'.csv"
    preserve
      load_csvdata, filename("`file'") dropsuffix(researn`k'F)
      generate source = "`source'"
      save "`sourcedata'", replace
    restore
    append using "`sourcedata'"    
  }

  // Rescale to population
  replace N = N  if source == "joint" 
  replace N = N / 0.1 if source == "iab" 
  replace N = N / 0.25 if source == "tpp" | source == "tppraw"


  // Keep subpopulation
  if "`gender'" == "male"         keep if male == 1
  else if "`gender'" == "female"  keep if male == 0

  // Initiate tex-file
  local sourcesclean = subinstr("`sources'", " ", "_", .)
  cap file close table
  file open table `using', write replace

  // Number of columns
  local ncols = 2
  local alignchar = "lr"
  foreach p of numlist `percentiles' {
    local ++ncols
    local alignchar = "`alignchar'r"
  }
  
  // Number of panels
  local nsources: word count `sources'
  
  // Begin tabular
  file write table "\begin{tabular}{`alignchar'}" _n
  file write table "\toprule \toprule" _n

  // Header
  local coltitles = "Year & \multicolumn{1}{c}{N}"
  foreach p of numlist `percentiles' {
    local coltitles = "`coltitles' & \multicolumn{1}{c}{P`p'}"
  }
  file write table "`coltitles' \\" _n
  file write table "\midrule" _n

  // Content
  local isource = 1
  qui foreach source in `sources' {

    if "`source'" == "joint" local sourcelabel = "IAB-TPP Data"
    if "`source'" == "iab" local sourcelabel = "IAB Data"
    if "`source'" == "tpp" local sourcelabel = "TPP+ Data"
    file write table "\multicolumn{`ncols'}{@{}l}{\textbf{`sourcelabel'}} \\" _n
    
    // loop over years
    qui foreach year of numlist `years' {
      
      local thisline = "`year'"
      
      // Number of observations
      local ss = cond("`source'" == "joint", "iab", "`source'")
      sum N if year == `year' & source == "`ss'", meanonly
      local p = strofreal(`=`r(mean)'/1e6', "%9.3f")
      local thisline = "`thisline' & `p'"
      
      // Percentiles
      foreach p of numlist `percentiles' {
        local var = "p" + subinstr("`p'", ".", "_", .)
        sum `var' if year == `year' & source == "`source'", meanonly
        local value = strofreal(`r(mean)', "%9.3fc")
        local thisline = "`thisline' & `value'"
      }

      file write table "`thisline' \\" _n
    }
    
    if `isource' < `nsources' file write table "\midrule" _n
    local ++isource
  }

  // End tabular
  file write table "\bottomrule" _n
  file write table "\end{tabular}" _n

  // Close tex-file
  file close table
  
end


tables_growth_pctiles_detailed using "${figs_folder}/data/researn1F_pctiles_detailed_male.tex", gender(male) years(2001 2005 2010) k(1)
tables_growth_pctiles_detailed using "${figs_folder}/data/researn1F_pctiles_detailed_female.tex", gender(female) years(2001 2005 2010) k(1)
tables_growth_pctiles_detailed using "${figs_folder}/data/researn5F_pctiles_detailed_male.tex", gender(male) years(2001 2005 2010) k(5)
tables_growth_pctiles_detailed using "${figs_folder}/data/researn5F_pctiles_detailed_female.tex", gender(female) years(2001 2005 2010) k(5)



//============================================================================================
// Table of Total Income Percentiles (only one  data set, by gender)
//============================================================================================

cap program drop tables_income_pctiles
program tables_income_pctiles

//--------------------------------------------------------------------------------------------
syntax using [, source(string) years(numlist ascending int) percentiles(numlist ascending) addpop]
//--------------------------------------------------------------------------------------------
  
  if "`source'" == ""       local source tppfull_log
  if "`years'" == ""        local years 2001 2005 2010 2015
  if "`percentiles'" == ""  local percentiles 5 10 25 50 75 90 95 99 99.9 99.99
  

  // Load data
  local file = "${tpp_folder}/$mydate 406_distributions (totinc_nokv)/inequality/sumstats_income_male.csv"
  load_csvdata, filename("`file'") dropsuffix(income)
  
  // Add population data
  if "`addpop'" != "" {
    preserve
      local popfile = subinstr("`file'", "_male", "", .)
      load_csvdata, filename("`popfile'") dropsuffix(income)
      generate male = 9
      tempfile popdata
      save "`popdata'", replace
    restore
    append using "`popdata'"
  }

  // Rescale to population
  replace N = sum_weights
  replace N = N / 0.25

  // Initiate tex-file
  cap file close table
  file open table `using', write replace

  // Number of columns
  local ncols = 3
  local alignchar = "lrr"
  foreach p of numlist `percentiles' {
    local ++ncols
    local alignchar = "`alignchar'r"
  }  

  // Begin tabular
  file write table "\begin{tabular}{`alignchar'}" _n
  file write table "\toprule \toprule" _n

  // Header
  local coltitles = "Year & \multicolumn{1}{c}{N} & \multicolumn{1}{c}{Mean}"
  foreach p of numlist `percentiles' {
    local coltitles = "`coltitles' & \multicolumn{1}{c}{P`p'}"
  }
  file write table "`coltitles' \\" _n
  file write table "\midrule" _n

  // Content
  local mvals = cond("`addpop'" == "", "1 0", "1 0 9")
  local nmvals: word count `mvals'
  local isource = 1
  qui foreach m in `mvals' {

    if `m' == 0 local gender = "Women"
    if `m' == 1 local gender = "Men"
    if `m' == 9 local gender = "Population"
    
    file write table "\multicolumn{`ncols'}{@{}l}{\textbf{`gender'}} \\" _n
    
    // loop over years
    qui foreach year of numlist `years' {
      
      local thisline = "`year'"
      
      // Number of observations
      sum N if year == `year' & male == `m', meanonly
      local p = strofreal(`=`r(mean)'/1e6', "%9.3f")
      local thisline = "`thisline' & `p'"
      
      // Mean
      sum mean if year == `year' & male == `m', meanonly
      local p = strofreal(`r(mean)', "%9.0fc")
      local thisline = "`thisline' & `p'"

      // Percentiles
      foreach p of numlist `percentiles' {
        local var = "p" + subinstr("`p'", ".", "_", .)
        sum `var' if year == `year' & male == `m', meanonly
        local value = strofreal(`r(mean)', "%9.0fc")
        local thisline = "`thisline' & `value'"
      }

      file write table "`thisline' \\" _n

    }
    
    if `isource' < `nmvals' file write table "\midrule" _n
    local ++isource
  }

  // End tabular
  file write table "\bottomrule" _n
  file write table "\end{tabular}" _n

  // Close tex-file
  file close table
  
end

tables_income_pctiles using "${figs_folder}/data/income_logsample_pctiles_gender.tex", source(tppfull_log) years(2001 2004 2008 2012 2016)
tables_income_pctiles using "${figs_folder}/data/income_logsample_pctiles_detailed.tex", source(tppfull_log) addpop years(2001/2016)


//============================================================================================
// Table of Income Percentiles (different income variables)
//============================================================================================

cap program drop tables_incomesource_pctiles
program tables_incomesource_pctiles

//--------------------------------------------------------------------------------------------
syntax using [, source(string) years(numlist ascending int) percentiles(numlist ascending) addpop]
//--------------------------------------------------------------------------------------------
  
  if "`source'" == ""       local source tppfull_log
  if "`years'" == ""        local years 2001 2005 2010 2015
  if "`percentiles'" == ""  local percentiles 5 10 25 50 75 90 95 99 99.9 99.99
  

  // Load data
  local file = "${tpp_folder}/$mydate 406_distributions (totinc_nokv)/inequality/sumstats_income_logsample_male.csv"
  load_csvdata, filename("`file'") dropsuffix(income)
  
  // Add population data
  if "`addpop'" != "" {
    preserve
      local popfile = subinstr("`file'", "_male", "", .)
      load_csvdata, filename("`popfile'") dropsuffix(income)
      generate male = 9
      tempfile popdata
      save "`popdata'", replace
    restore
    append using "`popdata'"
  }

  // Rescale to population
  replace N = sum_weights
  replace N = N / 0.25

  // Initiate tex-file
  cap file close table
  file open table `using', write replace

  // Number of columns
  local ncols = 3
  local alignchar = "lrr"
  foreach p of numlist `percentiles' {
    local ++ncols
    local alignchar = "`alignchar'r"
  }  

  // Begin tabular
  file write table "\begin{tabular}{`alignchar'}" _n
  file write table "\toprule \toprule" _n

  // Header
  local coltitles = "Year & \multicolumn{1}{c}{N} & \multicolumn{1}{c}{Mean}"
  foreach p of numlist `percentiles' {
    local coltitles = "`coltitles' & \multicolumn{1}{c}{P`p'}"
  }
  file write table "`coltitles' \\" _n
  file write table "\midrule" _n

  // Content
  local mvals = cond("`addpop'" == "", "1 0", "1 0 9")
  local nmvals: word count `mvals'
  local isource = 1
  qui foreach m in `mvals' {

    if `m' == 0 local gender = "Women"
    if `m' == 1 local gender = "Men"
    if `m' == 9 local gender = "Population"
    
    file write table "\multicolumn{`ncols'}{@{}l}{\textbf{`gender'}} \\" _n
    
    // loop over years
    qui foreach year of numlist `years' {
      
      local thisline = "`year'"
      
      // Number of observations
      sum N if year == `year' & male == `m', meanonly
      local p = strofreal(`=`r(mean)'/1e6', "%9.3f")
      local thisline = "`thisline' & `p'"
      
      // Mean
      sum mean if year == `year' & male == `m', meanonly
      local p = strofreal(`r(mean)', "%9.0fc")
      local thisline = "`thisline' & `p'"

      // Percentiles
      foreach p of numlist `percentiles' {
        local var = "p" + subinstr("`p'", ".", "_", .)
        sum `var' if year == `year' & male == `m', meanonly
        local value = strofreal(`r(mean)', "%9.0fc")
        local thisline = "`thisline' & `value'"
      }

      file write table "`thisline' \\" _n

    }
    
    if `isource' < `nmvals' file write table "\midrule" _n
    local ++isource
  }

  // End tabular
  file write table "\bottomrule" _n
  file write table "\end{tabular}" _n

  // Close tex-file
  file close table
  
end

tables_income_pctiles using "${figs_folder}/data/income_logsample_pctiles_gender.tex", source(tppfull_log) years(2001 2004 2008 2012 2016)
tables_income_pctiles using "${figs_folder}/data/income_logsample_pctiles_detailed.tex", source(tppfull_log) addpop years(2001/2016)



//============================================================================================
// IAB vs TPP+ vs Combined Data in Longitudinal Sample
//============================================================================================

foreach k in 1 5 {

  import delimited using "$joint_folder/volatility/bins_`k'Fsample_labor_male.csv", clear case(preserve)
  generate midpoint = (ub + lb) / 2
  foreach var of varlist N_* {
    replace `var' = `var' / 1e6
  }
  replace midpoint = midpoint / 1000

  gcollapse (mean) N_*, by(male midpoint)

  foreach m in 0 1 {
  
    if `m' == 0 local suffix = "_female"
    else local suffix = "_male"

    twoway  (line N_iab N_tpp N_imp midpoint if male == `m' & midpoint < 100, lcolor(blue green red) lwidth(*1.5...) lpattern(solid longdash dash)) ///
            , /* Options */ ///
             legend(order(1 "IAB" 2 "TPP+" 3 "IAB-TPP")) ylabel(#6) xlabel(#10) ///
             ytitle("Number of Obs. (in Mill.)") ///
             xtitle("Annual Earnings (in 1000 Euro)")
    graph export "$figs_folder/data/bins_labor_`k'Fsample_iabtpp`suffix'.pdf", replace
  }

}