//==============================================================================
// Imputation of Social-Security Indicator
//==============================================================================


import delimited using "$tpp_folder/$mydate 102_imputecivilservants/civilservant_shares_transitions_predicted.csv", clear case(preserve)
				
bysort G: egen range_c = min(max_c - min_c)
order c_imp c c_star mu_c sigma_c max_c min_c range_c, after(G)

replace c_imp = c if year >= 2010
generate n_cs = c * Nw
generate n_cs_imp = c_imp * Nw
generate n_cs_star = c_star * Nw


// CS share by gender
preserve
	collapse (sum) Nw (sum) n_cs_imp (sum) n_cs, by(year male)

	gen c = n_cs / Nw
	gen c_imp = n_cs_imp / Nw

	twoway 	(connect c c_imp year if male == 0, lpat(dash solid dot) col(red red) msymbol(Dh D) mfcolor(%50...)) ///
          (connect c c_imp year if male == 1, lpat(dash solid dot) color(blue blue) msymbol(Oh O) mfcolor(%50...)) ///
					, legend(pos(2) order(1 "Raw (Women)" 2 "Imputed (Women)" 3 "Raw (Men)" 4 "Imputed (Men)")) ///
          xlabel(2000(2)2016) xtitle("") ytitle("Share of Non-Social-Security Workers")								 
restore 
graph export "$figs_folder/data/imputation_number_nonsocsecworkers_gender.pdf"


// CS share by labinc
preserve
	/* for men (not for women), there is a time shift: curve shifts to the right */
	keep if bin_age == 10 & male == 1
	collapse (sum) Nw (sum) n_cs_imp (sum) n_cs, by(year lb_rlabinc)
	gen c = n_cs / Nw
	gen c_imp = n_cs_imp / Nw

	keep if lb_rlabinc < 80000
	twoway 	(line c lb_rlabinc if year == 2010, lcolor(blue)) ///
					(line c lb_rlabinc if year == 2011, lcolor(red)) ///
					(line c lb_rlabinc if year == 2012, lcolor(green)) ///
					(line c lb_rlabinc if year == 2013, lcolor(yellow)) ///
					(line c lb_rlabinc if year == 2014, lcolor(purple)) ///
					(line c lb_rlabinc if year == 2015, lcolor(pink)) ///
					(line c lb_rlabinc if year == 2016, lcolor(brown)) ///
					, legend(order(1 "2010" 2 "2011" 3 "2012" 4 "2013" 5 "2014" 6 "2015" 7 "2016") row(1))
restore	
graph export "$figs_folder/data/nonrv_imputation_share_gender.pdf", replace



// =============================================================================
// Share of non-RV workers
// =============================================================================

// Share of non-RV workers by Labor
load_csvdata, filename("$tpp_folder/$mydate 105_overviewdata/headcounts_labor.csv")
keep if lb_labor < 100000 & lb_labor >= 2000
replace lb_labor = lb_labor / 1000
generate nonrv = 1 - rentenvers
generate nonrv_imp = 1 - rentenvers_imp

foreach var in rentenvers_imp rentenvers {
  twoway 	(line `var' lb_labor if year == 2001, lcolor(blue%50)) ///
          (line `var' lb_labor if year == 2002, lcolor(blue%50)) ///
          (line `var' lb_labor if year == 2003, lcolor(blue%50)) ///
          (line `var' lb_labor if year == 2004, lcolor(blue%50)) ///
          (line `var' lb_labor if year == 2005, lcolor(blue%50)) ///
          (line `var' lb_labor if year == 2006, lcolor(blue%50)) ///
          (line `var' lb_labor if year == 2007, lcolor(blue%50)) ///
          (line `var' lb_labor if year == 2008, lcolor(blue%50)) ///
          (line `var' lb_labor if year == 2009, lcolor(blue%50)) ///
          (line `var' lb_labor if year == 2010, lcolor(red%50) lwidth(*2)) ///
          (line `var' lb_labor if year == 2011, lcolor(green%50)) ///
          (line `var' lb_labor if year == 2012, lcolor(green%50)) ///
          (line `var' lb_labor if year == 2013, lcolor(green%50)) ///
          (line `var' lb_labor if year == 2014, lcolor(green%50)) ///
          (line `var' lb_labor if year == 2015, lcolor(green%50)) ///
          (line `var' lb_labor if year == 2016, lcolor(green%50)) ///
          , legend(pos(2) order(1 "2001-2009" 10 "2010" 11 "2011-2016")) ylabel(0.8(0.05)1) ///
          xtitle("Annual Earnings (in 1000€)") ytitle("Share of Social-Security Workers")
  graph export "$figs_folder/data/`var'_share_by_labor.pdf", replace
}
		
// Share over Time
load_csvdata, filename("$tpp_folder/$mydate 105_overviewdata/headcounts_male_labor.csv")
gcollapse (mean) rentenvers_imp rentenvers [aw=N_weight], by(year male)

gen nonrv = 1 - rentenvers
gen nonrv_imp = 1 - rentenvers_imp

twoway 	(connect rentenvers rentenvers_imp year if male == 0, lpat(dash solid) col(red red) msymbol(Dh D) mfcolor(%50...)) ///
        (connect rentenvers rentenvers_imp year if male == 1, lpat(dash solid) color(blue blue) msymbol(Oh O) mfcolor(%50...)) ///
        , legend(pos(5) order(1 "Raw (Women)" 2 "Imputed (Women)" 3 "Raw (Men)" 4 "Imputed (Men)")) ///
        xlabel(2000(2)2016) xtitle("") ytitle("Share of Social-Security Workers")								 
graph export "$figs_folder/data/rentenvers_rawimp_by_gender.pdf", replace
