//=======================================================================================
// Volatility
//=======================================================================================



global ycut_H1 = 45000
global ycut_H5 = 40000

global logycut_H1 = log($ycut_H1)
global logycut_H5 = log($ycut_H5)



//=======================================================================================
// Overall
//=======================================================================================

cd "$joint_folder"

foreach k in 1 5 {

  // Load data by gender  
  load_csvdata, filename("$joint_folder/volatility/sumstats_researn`k'F_male.csv") dropsuffix(researn`k'F)
  preserve
    load_csvdata, filename("$joint_folder/volatility/sumstats_researn`k'F.csv") dropsuffix(researn`k'F)
    generate male = 9
    tempfile aggdata
    save "`aggdata'", replace
  restore
  append using "`aggdata'"

  // Additional statistics
  add_statistics
  
  // Decompose CS Kurtosis
  generate p75p25_2001 = p75p25 if year == 2001
  bysort male (year): ereplace p75p25_2001 = min(p75p25_2001)
  generate fixden_kurtcs = p97_5p2_5 / p75p25_2001 - 2.91
  
  generate p97_5p2_5_2001 = p97_5p2_5 if year == 2001
  bysort male (year): ereplace p97_5p2_5_2001 = min(p97_5p2_5_2001)
  generate fixnum_kurtcs = p97_5p2_5_2001 / p75p25 - 2.91
  
  // Shift year to center changes
  local shiftyear = `k'/2 - 0.5
  local xlabel = cond(`k' == 1, "xlabel(2000(2)2016)", "xlabel(2000(2)2016)")

  
  foreach subgp in all /*male female*/ {
    if "`subgp'" == "all"    local ifcond = "if male == 9"
    if "`subgp'" == "male"    local ifcond = "if male == 1"
    if "`subgp'" == "female"  local ifcond = "if male == 0"
    

    // Core percentiles
    local ylabel = cond(`k' == 1, "ylabel(-0.3(0.1)0.4)", "")
    plot_timeseries p90 p75 p50 p25 p10 `ifcond', shiftyear(`shiftyear') ///
                    legend(order(2 "P90" 3 "P75" 4 "P50" 5 "P25" 6 "P10")) ///
                    ytitle("Percentiles of g{sup:`k'}{sub:it}") `ylabel' `xlabel'
    graph export "$figs_folder/core/researn`k'F_percentiles_`subgp'.pdf", replace 

    // Core percentiles indexed
    plot_timeseries p90 p75 p50 p25 p10 `ifcond', index shiftyear(`shiftyear') ///
                    legend(order(2 "P90" 3 "P75" 4 "P50" 5 "P25" 6 "P10")) ///
                    ytitle("Percentiles of g{sup:`k'}{sub:it} Relative to $yrfirst")  `xlabel'
    graph export "$figs_folder/core/researn`k'F_percentiles_index_`subgp'.pdf", replace    

    // Lower and upper tail: P50-P10 and P90-P50
    local ylabel = cond(`k' == 1, "ylabel(0.15(0.05)0.45)", "")
    plot_timeseries p90p50 p50p10 `ifcond', shiftyear(`shiftyear') ///
                    colors(blue red) msymbol(O S) ///
                    legend(order(2 "P90-P50" 3 "P50-P10")) ///
                    ytitle("Dispersion of g{sup:`k'}{sub:it}") `ylabel' `xlabel'
    graph export "$figs_folder/core/researn`k'F_p90p50_p50p10_`subgp'.pdf", replace    

    // Decomposition of Excess Crow-Siddiqui Kurtosis
    plot_timeseries kurtcs fixnum_kurtcs fixden_kurtcs `ifcond', shiftyear(`shiftyear') ///
                    colors(blue red green) msymbol(S Sh Dh) lpattern(solid longdash dash) ///
                    legend(order(2 "Baseline" 3 "Only P75-P25" 4 "Only P97.5-P2.5")) ///
                    ytitle("Excess Crow-Siddiqui Kurtosis of g{sup:`k'}{sub:it}") `xlabel'
    graph export "$figs_folder/core/researn`k'F_decomp_kurtcs_`subgp'.pdf", replace    

  }

  // Reshape wide by gender
  keep year male sd p90p10 skew skewk kurt kurtcs p75p25 p97_5p2_5 fixden_kurtcs fixnum_kurtcs
  greshape wide sd p90p10 skew skewk kurt kurtcs p75p25 p97_5p2_5 fixden_kurtcs fixnum_kurtcs, by(year) keys(male)
 
  // Standard Deviation
  plot_timeseries sd1 sd0, shiftyear(`shiftyear') ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(3 "Women" 2 "Men")) ///
                  ytitle("Std. Dev. of g{sup:`k'}{sub:it}") `xlabel'
  graph export "$figs_folder/core/researn`k'F_sd_gender.pdf", replace    
  plot_timeseries sd9, shiftyear(`shiftyear') ///
                  colors(blue red) msymbol(S O) lpattern(solid) ///
                  legend(off) ///
                  ytitle("Std. Dev. of g{sup:`k'}{sub:it}") `xlabel'
  graph export "$figs_folder/core/researn`k'F_sd_all.pdf", replace    
  
  // P90-P10
  plot_timeseries p90p101 p90p100, shiftyear(`shiftyear') ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(3 "Women" 2 "Men")) ///
                  ytitle("P90-P10 Differential of g{sup:`k'}{sub:it}") `xlabel'
  graph export "$figs_folder/core/researn`k'F_p90p10_gender.pdf", replace    
  plot_timeseries p90p109, shiftyear(`shiftyear') ///
                  colors(blue red) msymbol(S O) lpattern(solid) ///
                  legend(off) ///
                  ytitle("P90-P10 Differential of g{sup:`k'}{sub:it}") `xlabel'
  graph export "$figs_folder/core/researn`k'F_p90p10_all.pdf", replace    

  // Kelley Skewness
  plot_timeseries skewk1 skewk0, shiftyear(`shiftyear') ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(3 "Women" 2 "Men")) ///
                  ytitle("Kelley Skewness of g{sup:`k'}{sub:it}") `xlabel'
  graph export "$figs_folder/core/researn`k'F_skewk_gender.pdf", replace    
  plot_timeseries skewk9, shiftyear(`shiftyear') ///
                  colors(blue red) msymbol(S O) lpattern(solid) ///
                  legend(off) ///
                  ytitle("Kelley Skewness of g{sup:`k'}{sub:it}") `xlabel'
  graph export "$figs_folder/core/researn`k'F_skewk_all.pdf", replace    

  // Excess Crow-Siddiqui Kurtosis
  plot_timeseries kurtcs1 kurtcs0, shiftyear(`shiftyear') ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(3 "Women" 2 "Men")) ///
                  ytitle("Excess Crow-Siddiqui Kurtosis of g{sup:`k'}{sub:it}") `xlabel'
  graph export "$figs_folder/core/researn`k'F_kurtcs_gender.pdf", replace    
  plot_timeseries kurtcs9, shiftyear(`shiftyear') ///
                  colors(blue red) msymbol(S O) lpattern(solid) ///
                  legend(off) ///
                  ytitle("Excess Crow-Siddiqui Kurtosis of g{sup:`k'}{sub:it}") `xlabel'
  graph export "$figs_folder/core/researn`k'F_kurtcs_all.pdf", replace    

  // Numerator of Excess Crow-Siddiqui Kurtosis: P97.5-P2.5
  plot_timeseries p97_5p2_51 p97_5p2_50, shiftyear(`shiftyear') ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(3 "Women" 2 "Men")) ///
                  ytitle("P97.5 - P2.5 of g{sup:`k'}{sub:it}") `xlabel'
  graph export "$figs_folder/core/researn`k'F_p97_5p2_5_gender.pdf", replace    
  
  // Denominator of Excess Crow Siddiqui Kurtosis: P75-P25
  plot_timeseries p75p251 p75p250, shiftyear(`shiftyear') ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(3 "Women" 2 "Men")) ///
                  ytitle("P75-P25 Differential of g{sup:`k'}{sub:it}") `xlabel'
  graph export "$figs_folder/core/researn`k'F_p75p25_gender.pdf", replace    
  
  // Skewness (3rd Stand. Moment)
  plot_timeseries skew1 skew0, shiftyear(`shiftyear') ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(3 "Women" 2 "Men")) ///
                  ytitle("Skewness of g{sup:`k'}{sub:it}") `xlabel'
  graph export "$figs_folder/core/researn`k'F_skew_gender.pdf", replace    

  // Excess Kurtosis (4th Stand. Moment)
  plot_timeseries kurt1 kurt0, shiftyear(`shiftyear') ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(3 "Women" 2 "Men")) ///
                  ytitle("Excess Kurtosis of g{sup:`k'}{sub:it}") `xlabel'  
  graph export "$figs_folder/core/researn`k'F_kurt_gender.pdf", replace    

} // k




//=======================================================================================
// Appendix: Transitions between job types
//=======================================================================================

load_csvdata, filename("$iab_folder/$mydate Transition probs jt1/transition_probabilities_jobtype1.csv")
keep if jobtype != 9
drop F_No
foreach var in F_FT F_PT F_MJ {
  replace `var' = `var' / (F_FT + F_PT + F_MJ)
}
generate F_FTPT = F_FT + F_PT

foreach subgp in male female {
preserve
  if "`subgp'" == "male" keep if male == 1
  if "`subgp'" == "female" keep if male == 0
  
  // Transitions out of mini-jobs
  plot_timeseries F_FT F_PT if jobtype == 3, ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(2 "switch to full-time" 3 "switch to part-time")) ///
                  ytitle("Share of Mini-Job Workers")
  graph export "$figs_folder/core/transitions_jobtype_from_mj_`subgp'.pdf", replace    

  // Transitions out of part-time
  plot_timeseries F_FT F_MJ if jobtype == 2, ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(2 "switch to full-time" 3 "switch to mini-job")) ///
                  ytitle("Share of Part-Time Workers")
  graph export "$figs_folder/core/transitions_jobtype_from_pt_`subgp'.pdf", replace    

  // Transitions out of full-time
  plot_timeseries F_PT F_MJ if jobtype == 1, ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(2 "switch to part-time" 3 "switch to mini-job")) ///
                  ytitle("Share of Full-Time Workers")
  graph export "$figs_folder/core/transitions_jobtype_from_ft_`subgp'.pdf", replace    
restore
}
                
//=======================================================================================
// Densities
//=======================================================================================


foreach subgp in male female {
foreach yy in 2005 2010 {
foreach k in 1 5 {

      
    if "`subgp'" == "male"    local ifcond = "if male == 1"
    if "`subgp'" == "female"  local ifcond = "if male == 0"

    // Moments
    load_csvdata, filename("$joint_folder/volatility/sumstats_researn`k'F_male.csv") dropsuffix(researn1F)
    keep if year == `yy'
    keep `ifcond'
    
    sum sd, meanonly
    local sd = r(mean)
    local sdplot: di %4.2f  `sd'
    
    sum skew, meanonly
    local skew = r(mean)
    local skewplot: di %4.2f `skew'

    sum kurt, meanonly
    local kurt = r(mean)
    local kurtplot: di %4.2f `kurt'

    // Density
    load_csvdata, filename("$joint_folder/volatility/discrete_distribution_researn`k'F_male.csv")
    keep if year == `yy'
    keep `ifcond'
    generate mid = (ub_y + lb_y) / 2
          
    // Same number of points as in other papers
    kdensity mid [aw=pmf_y], n(400) generate(_x _y)
    keep _x _y
    rename _x mid
    rename _y pdf_y
    
    keep mid pdf_y

    // More (log) densities
    gen log_pdf_y = log(pdf_y)
    gen pdf_normal = normalden(mid, 0, `sd')
    gen log_pdf_normal = log(pdf_normal)

    // Slopes
    qui regress log_pdf_y mid if mid < -1 & mid > -4
    local blefttail: di %4.2f _b[mid]
    predict lefttail if e(sample), xb

    reg log_pdf_y mid if mid > 1 & mid < 4
    local brighttail: di %4.2f _b[mid]
    predict righttail if e(sample), xb

    // Trimming for plots
    drop if abs(mid) > 4
    replace log_pdf_normal = . if log_pdf_normal < -12
    replace log_pdf_y = . if log_pdf_y < -12
      

    // Figure: Log Density
    twoway line log_pdf_y log_pdf_normal lefttail righttail mid, ///
            lcolor(blue red black black navy forest_green)  ///
            lpattern(solid dash longdash longdash longdash dash)  ///
            lwidth(medthick..) ///
            ytitle("Log Density") ///
            ylabel(-12(2)3)  ///
            xtitle("One-Year Log Earnings Growth") ///
            xlabel(-4/4) ///
            legend(position(11) col(1) order(1 "Data Density" 2 "N(0,`sdplot'{sup:2})" 3 "Left   Slope: `blefttail'" 4 "Right Slope: `brighttail'")) ///
              text(`=cond(`k'==1, 2, 2)' 1.8 "St. Dev.: `sdplot'", place(e) size(${legesize})) ///
              text(`=cond(`k'==1, 1, 1)' 1.8 "Skewness: `skewplot'", place(e) size(${legesize})) ///
              text(`=cond(`k'==1, 0, 0)' 1.8 "Kurtosis: `kurtplot'", place(e) size(${legesize}))
    graph export "${figs_folder}/core/logdensity_researn`k'F_`yy'_`subgp'.pdf", replace

    // Figure: Density
    twoway line pdf_y pdf_normal mid if abs(mid) <= 2.5, ///
              lcolor(blue red black black navy forest_green)  ///
              lpattern(solid dash longdash longdash longdash dash)  ///
              lwidth(medthick..) ///
              ytitle("Density") ///
              ylabel(0/6)  ///
              xtitle("One-Year Log Earnings Growth") ///
              xlabel(-2.5(1)2.5) ///
              legend(position(11) col(1) order(1 "Data Density" 2 "N(0,`sdplot'{sup:2})")) ///
              text(5.5 1 "St. Dev.: `sdplot'", place(e) size(${legesize})) ///
              text(5.0 1 "Skewness: `skewplot'", place(e) size(${legesize})) ///
              text(4.5 1 "Kurtosis: `kurtplot'", place(e) size(${legesize}))
      graph export "${figs_folder}/core/density_researn`k'F_`yy'_`subgp'.pdf", replace


    }	// k
  }	// years
}	// subgp


//=======================================================================================
// Appendix: Densities in IAB and TPP Data
//=======================================================================================


foreach subgp in male female {
foreach yy in 2005 2010 {
foreach k in 1 5 {
  if "`subgp'" == "male"    local male = 1
  if "`subgp'" == "female"  local male = 0
  
  // Density
  load_csvdata, filename("$tpp_folder/$mydate 206_Distributions (labor, rv)/volatility/density_researn`k'f_male.csv")
  generate source = "tpp"
  preserve
    load_csvdata, filename("$iab_folder/$mydate Volatility - short/L_researn`k'F_hist_male.csv")
    greshape long val_researn`k'F den_researn`k'F, by(index male) keys(year)
    rename val_researn`k'F value_researn`k'F
    rename den_researn`k'F density_researn`k'F
    generate source = "iab"
    tempfile iabdata
    save "`iabdata'", replace
  restore
  append using "`iabdata'"
  keep if year == `yy' & male == `male'
  
  rename value_ mid
  rename density_ pdf_y    
  keep mid pdf_y source

  // More (log) densities
  gen log_pdf_y = log(pdf_y)

  // Trimming for plots
  drop if abs(mid) > 4
  replace log_pdf_y = . if log_pdf_y < -12
  
  // Figure: Log Density
  twoway  (line log_pdf_y mid if source == "iab", lcolor(blue) lpattern(solid)) ///
          (line log_pdf_y mid if source == "tpp", lcolor(red) lpattern(dash)) , ///
          ytitle("Log Density") ///
          ylabel(-10(2)2)  ///
          xtitle("One-Year Log Income Growth") ///
          xlabel(-4/4) ///
          legend(position(11) col(1) order(1 "IAB" 2 "TPP"))
  graph export "${figs_folder}/app-tppiab/logdensity_researn`k'F_`yy'_tppiab_`subgp'.pdf", replace

}	// k
}	// years
}	// subgp




//=======================================================================================
// Heterogeneity by Permanent Income
//=======================================================================================

foreach k in 1 5  {

  // Append TPP and IAB results
  load_csvdata, filename("$joint_folder/volatility/sumstats_researn`k'F_by_permearn_maleagegp.csv") dropsuffix(researn`k'F)

  // Add statistics
  add_statistics

  // Average over Years
  gcollapse p10 p50 p90 p90p10 skewk kurtcs p75p25 p97_5p2_5 sd skew kurt mean_permearn mean_avg_pastearn, by(male agegp rank_permearn)
  gen log_mean_avg = log(mean_avg)

  
  foreach subgp in male female {
    if "`subgp'" == "male"    local male = 1
    if "`subgp'" == "female"  local male = 0
 
    // growth rate stats
    qui sum rank_permearn if mean_permearn < ${logycut_H`k'} & male == `male'
    local rankcut = r(max)
    foreach var in /*p10 p50 p90*/ p90p10 skewk kurtcs /*sd skew kurt p75p25 p97_5p2_5*/ {
    
      if "`var'" == "p90p10" local ytitle = "P90-P10 of g{sup:`k'}{sub:it}"
      else if "`var'" == "p75p25" local ytitle = "P75-P25 of g{sup:`k'}{sub:it}"
      else if "`var'" == "p97_5p2_5" local ytitle = "P97.5-P2.5 of g{sup:`k'}{sub:it}"
      else if "`var'" == "skewk" local ytitle = "Kelley Skewness of g{sup:`k'}{sub:it}"
      else if "`var'" == "skewk" local ytitle = "Kelley Skewness of g{sup:`k'}{sub:it}"
      else if "`var'" == "kurtcs" local ytitle = "Excess Crow-Siddiqui Kurtosis of g{sup:`k'}{sub:it}"
      else local ytitle = subinstr("`var'", "p", "P", 1) + " of g{sup:`k'}{sub:it}"
      
      if "`var'" == "p90p10" local ylabel = cond(`k' == 1, "ylabel(0(0.25)1.5)", "")
      else if "`var'" == "skewk" local ylabel = cond(`k' == 1, "ylabel(-0.6(0.2)0.6)", "")
      else if "`var'" == "kurtcs" local ylabel = cond(`k' == 1, "ylabel(0(5)20)", "")
      else local ylabel = ""
      
      auto_legend_position `var' rank_permearn if male == `male', `ylabel'
      local legpos = r(position)
      twoway  (line `var' rank_permearn if agegp == 1 & male == `male', lcolor(red) lwidth(*2)) ///
              (line `var' rank_permearn if agegp == 2 & male == `male', lcolor(blue) lwidth(*2) lpat(dash)) ///
              (line `var' rank_permearn if agegp == 3 & male == `male', lcolor(green) lwidth(*2) lpat(longdash)) ///
              , legend(position(`legpos') order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]")) xlabel(#6) `ylabel' ///
              xline(`rankcut', lpat(dash) lcol(gs5)) ///
              xtitle("Quantiles of Residualized Log Permanent Earnings") ytitle("`ytitle'") name(`var'_`subgp', replace)
      graph export "$figs_folder/core/researn`k'F_`var'_by_permearn_`subgp'.pdf", replace

    }

}
}


// APPENDIX: Comparisons IAB vs TPP
//--------------------------------------------------------

foreach k in 1 5  {

  // Append TPP and IAB results
  load_csvdata, filename("$tpp_folder/$mydate 206_Distributions (labor, rv)/volatility/sumstats_researn`k'F_by_permearn_male.csv") dropsuffix(researn`k'F)
  generate source = "TPP"
  drop N
  rename sum_weights N
  replace N = N / 0.25
  tempfile tppdata
  save "`tppdata'", replace
  load_csvdata, filename("$iab_folder/$mydate 206_Distributions/volatility/sumstats_researn`k'F_by_permearn_male.csv") dropsuffix(researn`k'F)
  generate source = "IAB"
  replace N = N / 0.1
  append using "`tppdata'"

  // Add statistics
  add_statistics

  // Average over Years
  gcollapse N kurtcs skewk sd p10 p50 p90 p90p10 mean_permearn mean_avg_pastearn, by(male source rank_permearn)
  gen log_mean_avg = log(mean_avg)
    
  foreach subgp in male female {
    if "`subgp'" == "male"    local male = 1
    if "`subgp'" == "female"  local male = 0
 
    // log avg. past earnings (residualized looks almost identical)
    twoway  (line log_mean_avg rank_permearn if male == `male' & source == "IAB", lcolor(blue) lwidth(*2) lpat(solid)) ///
            (line log_mean_avg rank_permearn if male == `male' & source == "TPP", lcolor(red) lwidth(*2) lpat(dash)) ///
            , xlabel(#6) ///
            yline(${logycut_H`k'}, lpat(dash) lcol(gs5)) legend(pos(11) order(1 "IAB" 2 "TPP+")) ///
            ytitle("Log Average Past Earnings") xtitle("Quantiles of Residualized Log Permanent Earnings") name(permearn`male', replace)
    graph export "$figs_folder/app-tppiab/logavgpastearn_by_rank_permearn_`k'Fsample_`subgp'.pdf", replace

    // (residualized) permearn
    twoway  (line mean_permearn rank_permearn if male == `male' & source == "IAB", color(blue) lwidth(*2) lpat(solid)) ///
            (line mean_permearn rank_permearn if male == `male' & source == "TPP", color(red) lwidth(*2) lpat(dash)) ///
            , xlabel(#6) ///
            yline(${logycut_H`k'}, lpat(dash) lcol(gs5)) legend(pos(11) order(1 "IAB" 2 "TPP+")) ///
            ytitle("Log Permanent Earnings (Residualized)") xtitle("Quantiles of Residualized Log Permanent Earnings") name(respermearn`male', replace)
    graph export "$figs_folder/app-tppiab/permearn_by_rank_permearn_`k'Fsample_`subgp'.pdf", replace

    // growth rate stats
    qui sum rank_permearn if source == "IAB" & mean_permearn < ${logycut_H`k'} & male == `male'
    local rankcut = r(max)
    foreach var in N p90p10 sd skewk kurtcs {
    
      if "`var'" == "N" local ytitle = "Number of Observations"
      if "`var'" == "p90p10" local ytitle = "P90-P10 of g{sup:`k'}{sub:it}"
      if "`var'" == "sd" local ytitle = "Standard Deviation of g{sup:`k'}{sub:it}"
      if "`var'" == "skewk" local ytitle = "Kelley Skewness of g{sup:`k'}{sub:it}"
      if "`var'" == "kurtcs" local ytitle = "Excess Crow-Siddiqui Kurtosis of g{sup:`k'}{sub:it}"
     
      auto_legend_position `var' rank_permearn if male == `male'
      twoway  (line `var' rank_permearn if male == `male' & source == "IAB", lcolor(blue) lwidth(*2)) ///
              (line `var' rank_permearn if male == `male' & source == "TPP", lcolor(red) lwidth(*2) lpat(dash)) ///
              , legend(position(`r(position)') order(1 "IAB" 2 "TPP+")) xlabel(#6) ///
              xline(`rankcut', lpat(dash) lcol(gs5)) ///
              xtitle("Quantiles of Residualized Log Permanent Earnings") ytitle("`ytitle'")
      graph export "$figs_folder/app-tppiab/researn`k'F_`var'_by_permearn_`subgp'.pdf", replace
    }

  }
}

// By age group
//--------------------------------------------------------

foreach k in 1 5  {
  // Append TPP and IAB results
  load_csvdata, filename("$tpp_folder/$mydate 206_Distributions (labor, rv)/volatility/sumstats_researn`k'F_by_permearn_maleagegp.csv") dropsuffix(researn`k'F)
  generate source = "TPP"
  drop N
  rename sum_weights N
  replace N = N / 0.25
  tempfile tppdata
  save "`tppdata'", replace
  load_csvdata, filename("$iab_folder/$mydate 206_Distributions/volatility/sumstats_researn`k'F_by_permearn_maleagegp.csv") dropsuffix(researn`k'F)
  generate source = "IAB"
  replace N = N / 0.1
  append using "`tppdata'"
  
  // Add statistics
  add_statistics

  // Average over Years
  gcollapse N kurtcs skewk sd p10 p50 p90 p90p10 mean_permearn mean_avg_pastearn, by(male agegp source rank_permearn)
  gen log_mean_avg = log(mean_avg)
    
  foreach a in 1 2 3 {
  foreach subgp in male female {
    if "`subgp'" == "male"    local male = 1
    if "`subgp'" == "female"  local male = 0
 

    // log avg. past earnings (residualized looks almost identical)
    twoway  (line log_mean_avg rank_permearn if male == `male' & agegp == `a' & source == "IAB", lcolor(blue) lwidth(*2) lpat(solid)) ///
            (line log_mean_avg rank_permearn if male == `male' & agegp == `a' & source == "TPP", lcolor(green) lwidth(*2) lpat(longdash)) ///
            , xlabel(#6) ///
            yline(${logycut_H`k'}, lpat(dash) lcol(gs5)) legend(pos(11) order(1 "IAB" 2 "TPP+")) ///
            ytitle("Log Average Past Earnings") xtitle("Quantiles of Residualized Log Permanent Earnings") name(permearn`male', replace)
    graph export "$figs_folder/app-tppiab/logavgpastearn_by_rank_permearn_`k'Fsample_`subgp'_agegp`a'.pdf", replace

    // (residualized) permearn
    twoway  (line mean_permearn rank_permearn if male == `male' & agegp == `a' & source == "IAB", color(blue) lwidth(*2) lpat(solid)) ///
            (line mean_permearn rank_permearn if male == `male' & agegp == `a' & source == "TPP", color(green) lwidth(*2) lpat(longdash)) ///
            , xlabel(#6) ///
            yline(${logycut_H`k'}, lpat(dash) lcol(gs5)) legend(pos(11) order(1 "IAB" 2 "TPP+")) ///
            ytitle("Log Permanent Earnings (Residualized)") xtitle("Quantiles of Residualized Log Permanent Earnings") name(respermearn`male', replace)
    graph export "$figs_folder/app-tppiab/permearn_by_rank_permearn_`k'Fsample_`subgp'_agegp`a'.pdf", replace

    // growth rate stats
    qui sum rank_permearn if source == "IAB" & mean_permearn < ${logycut_H`k'} & male == `male' & agegp == `a'
    local rankcut1 = r(max)
    qui sum rank_permearn if source == "IAB" & mean_permearn >= ${logycut_H`k'} & male == `male' & agegp == `a'    
    local rankcut2 = r(min)
    local rankcut = (`rankcut1' + `rankcut2') / 2
    foreach var in p90p10 skewk kurtcs {
    
      if "`var'" == "N" local ytitle = "Number of Observations"
      if "`var'" == "p90p10" local ytitle = "P90-P10 of g{sup:`k'}{sub:it}"
      if "`var'" == "sd" local ytitle = "Standard Deviation of g{sup:`k'}{sub:it}"
      if "`var'" == "skewk" local ytitle = "Kelley Skewness of g{sup:`k'}{sub:it}"
      if "`var'" == "kurtcs" local ytitle = "Excess Crow-Siddiqui Kurtosis of g{sup:`k'}{sub:it}"
     
      auto_legend_position `var' rank_permearn if male == `male' & agegp == `a'
      twoway  (line `var' rank_permearn if male == `male' & agegp == `a' & source == "IAB", lcolor(blue) lwidth(*2)) ///
              (line `var' rank_permearn if male == `male' & agegp == `a' & source == "TPP", lcolor(green) lwidth(*2) lpat(longdash)) ///
              , legend(position(`r(position)') order(1 "IAB" 2 "TPP+")) xlabel(#6) ///
              xline(`rankcut', lpat(dash) lcol(gs5)) ///
              xtitle("Quantiles of Residualized Log Permanent Earnings") ytitle("`ytitle'")
      graph export "$figs_folder/app-tppiab/researn`k'F_`var'_by_permearn_`subgp'_agegp`a'.pdf", replace
    }

  }
}
}

  
//=======================================================================================
// Heterogeneity by Current Income
//=======================================================================================

// Share affected by top-coding in IAB
//----------------------------------------------------------------------
foreach k in 1 5 {
  load_csvdata, filename("$iab_folder/$mydate 206_Distributions/volatility/sumstats_researn`k'F_by_labor_male.csv") delim(",") dropsuffix(researn`k'F)
  generate source = "IAB"

  gcollapse (mean) mean_topcoded`k'F mean_labor, by(male lb ub)
  
  replace mean_labor = mean_labor / 1000
  sort male lb ub

  twoway (line mean_topcoded`k'F mean_labor if mean_labor < 80 & lb >= 2.3 & male == 0, lcolor(red) lpattern(solid) lwidth(*2)) ///
         (line mean_topcoded`k'F mean_labor if mean_labor < 80 & lb >= 2.3 & male == 1, lcolor(blue) lpattern(longdash) lwidth(*2)), ///
          ytitle("Share of `k'-Year Growth Rates" "Affected by Top-Coding") legend(position(11) order(1 "Women" 2 "Men")) ///
          xline(60, lcolor(gs5) lpattern(dash)) ///
          xtitle("Annual Earnings (in 1000 Euro)") xlabel(#8)
  graph export "$figs_folder/app-tppiab/researn`k'F_share_affected_by_topcoding.pdf", replace
}        

// Differences in Growth Rate Distribution by Earnings
//----------------------------------------------------------------------
foreach k in 1 5 {
  // Load data
  tempfile tppdata iabdata
  load_csvdata, filename("$tpp_folder/$mydate 206_Distributions (labor, rv)/volatility/sumstats_researn`k'F_by_labor_male.csv") dropsuffix(researn`k'F)
  generate source = "TPP"
  save "`tppdata'", replace
  load_csvdata, filename("$iab_folder/$mydate 206_Distributions/volatility/sumstats_researn`k'F_by_labor_male.csv") dropsuffix(researn`k'F)
  generate source = "IAB"
  save "`iabdata'", replace
  load_csvdata, filename("$joint_folder/volatility/sumstats_researn`k'F_by_labor_male.csv") dropsuffix(researn`k'F)

  replace source = "JOINT"
  append using "`tppdata'"
  append using "`iabdata'"  
  
  // Add statistics
  add_statistics

  // Average over years
  keep if year >= 2001 & year <= 2016 - `k'
  gcollapse (mean) p10 p50 p90 p90p10 skewk kurtcs mean_labor, by(source male lb ub) labelformat(#sourcelabel#)

  keep if lb < 100000 & lb >= 2000
  replace mean_labor = mean_labor / 1000

  
  // Growth rate stats
  foreach male in 1 0 {
    if `male' == 1 local suffix = "male"
    else local suffix = "female"
    
    // percentiles
    twoway  (line p90 p50 p10 mean_labor if male == `male' & source == "IAB", lcolor(blue green red) lwidth(*1.5...)) ///
            (line p90 p50 p10 mean_labor if male == `male' & source == "TPP", lcolor(blue green red) lwidth(*1.5...) lpat(longdash...)) ///
            , legend(order(1 "P90 IAB" 2 "P50 IAB" 3 "P10 IAB" 4 "P90 TPP+" 5 "P50 TPP+" 6 "P10 TPP+" )) xlabel(#6) ///
            xline(60, lpat(dash) lcol(gs5)) ///
            xtitle("Annual Earnings (in 1000 Euro)") ytitle("Selected Percentiles of g{sup:`k'}{sub:it}")
    graph export "$figs_folder/app-tppiab/researn`k'F_percentiles_by_labor_`suffix'.pdf", replace
    
    foreach var in p90p10 skewk kurtcs {
      if "`var'" == "N" local ytitle = "Number of Observations"
      if "`var'" == "p90p10" local ytitle = "P90-P10 of g{sup:`k'}{sub:it}"
      if "`var'" == "sd" local ytitle = "Standard Deviation of g{sup:`k'}{sub:it}"
      if "`var'" == "skewk" local ytitle = "Kelley Skewness of g{sup:`k'}{sub:it}"
      if "`var'" == "kurtcs" local ytitle = "Excess Crow-Siddiqui Kurtosis of g{sup:`k'}{sub:it}"
     
      twoway  (line `var' mean_labor if male == `male' & source == "IAB", lcolor(blue) lwidth(*2)) ///
              (line `var' mean_labor if male == `male' & source == "TPP", lcolor(green) lwidth(*2) lpat(longdash)) ///
              , legend(order(1 "IAB" 2 "TPP+")) xlabel(#6) ///
              xline(60, lpat(dash) lcol(gs5)) ///
              xtitle("Annual Earnings (in 1000 Euro)") ytitle("`ytitle'")
      graph export "$figs_folder/app-tppiab/researn`k'F_`var'_by_labor_`suffix'.pdf", replace
    }
  }
}
