// ==========================================================================
//  Reweighting
// ==========================================================================


// Counterfactuals
// ==========================================================================

clear 
foreach suf in "" rw2 rw3 rw5b rw6 rw7 {
  
  if "`suf'" == "" local sufclean = "baseline"  
  if "`suf'" == "rw2" local sufclean = "jobtype"
  if "`suf'" == "rw3" local sufclean = "unemp"
  if "`suf'" == "rw5b" local sufclean = "educ"
  if "`suf'" == "rw6" local sufclean = "age"
  if "`suf'" == "rw7" local sufclean = "nongerman"
  
  if "`suf'" == ""  local folder = "$mydate Inequality - short"
  if "`suf'" == "rw2" local folder = "$mydate Inequality - short_`suf'"
  if "`suf'" == "rw3" local folder = "$mydate Inequality - short_`suf'"
  if "`suf'" == "rw5b" local folder = "$mydate Inequality - short_`suf'"
  if "`suf'" == "rw6" local folder = "$mydate Inequality - short_`suf'"
  if "`suf'" == "rw7" local folder = "$mydate Inequality - short_`suf'"
  
  
  // Append data  
  tempfile rwdata
  preserve
    load_csvdata, filename("$iab_folder/`folder'/L_logearn_male_sumstat.csv") dropsuffix(logearn)
    generate rw = "`sufclean'"
    save "`rwdata'", replace
  restore
  append using "`rwdata'"
  preserve
    load_csvdata, filename("$iab_folder/`folder'/L_logearn_sumstat.csv") dropsuffix(logearn)
    generate rw = "`sufclean'"
    generate male = 9
    save "`rwdata'", replace
  restore
  append using "`rwdata'"  
}

keep if year >= 2001 & year <= 2016
add_statistics

keep p10 p25 p50 p75 p90 p90p10 p90p50 p50p10 p75p25 year male rw
greshape wide p10 p25 p50 p75 p90 p90p10 p90p50 p50p10 p75p25, by(year male) keys(rw) string

foreach subgp in all male female {
  preserve 
    if "`subgp'" == "all"    keep if male == 9
    if "`subgp'" == "male"    keep if male == 1
    if "`subgp'" == "female"  keep if male == 0
    
    foreach var in p10 p25 p50 p75 p90 p90p10 p50p10 p90p50 p75p25 {
      local ytitle = subinstr("`var'", "p", "P", 1)
      local ytitle = subinstr("`ytitle'", "p", "-", 1)
      
      if      "`var'" == "p10" local ylabel = "-0.3(0.1)0.15"
      else if "`var'" == "p25" local ylabel = "-0.2(0.05)0.15"
      else if "`var'" == "p50" local ylabel = "-0.1(0.05)0.1"
      else if "`var'" == "p75" local ylabel = "-0.05(0.025)0.1"
      else if "`var'" == "p90" local ylabel = "-0.02(0.02)0.13"
      else if "`var'" == "p75p25" local ylabel = "-0.1(0.05)0.2"
      else if "`var'" == "p90p10" local ylabel = "-0.1(0.1)0.4"
      else if "`var'" == "p90p50" local ylabel = "0(0.03)0.15"
      else if "`var'" == "p50p10" local ylabel = "-0.15(0.05)0.25"
      plot_timeseries `var'baseline `var'jobtype `var'educ `var'age `var'nongerman `var'unemp, index ///
                          legend(order(2 "Baseline" 3 "Job Type" 4 "Education" 5 "Age" 6 "Nationality" 7 "Days in Empl.")) ///
                          ytitle("`ytitle' of Log Earnings") ylabel(`ylabel') colors(blue green red navy pink black mint) lwidth(*1.5...)
      graph export "$figs_folder/core/reweighting_logearn_`var'_`subgp'.pdf", replace
    }
  restore
}
     
     
// Change in the Number of Observations by Education
// ==========================================================================
load_csvdata, filename("$iab_folder/$mydate Data ddv cohort plot/data_diff_dep_var_cohort_plot_v2.csv") 

gcollapse (sum) N, by(year male educ)
replace N = N / 1e6 / 0.1
greshape wide N, by(year male) keys(educ)
keep if year >= 2001
generate Ntotal = N1 + N2 + N9
generate share1 = N1 / Ntotal
generate share2 = N2 / Ntotal
generate share9 = N9 / Ntotal

foreach subgp in male female {
  preserve
    keep if male == cond("`subgp'" == "male", 1, 0)
    
    // Headcount by education
    plot_timeseries N1 N2 N9 Ntotal,  ///
                    legend(order(2 "Non-College" 3 "College" 4 "No Education Data" 5 "Total" )) ///
                    ytitle("Number of Observations (in mill.)") ///
                    colors(blue green red black) msymbol(O S D T) lpattern(longdash dash shortdash solid) ylabel(0(2)14)
    graph export "$figs_folder/core/headcount_by_educ_`subgp'.pdf", replace     
    
    // Headcount by education (indexed)
    plot_timeseries N1 N2 N9 Ntotal, index ///
                    legend(order(2 "Non-College" 3 "College" 4 "No Education Data" 5 "Total" )) ///
                    ytitle("Change in Number of Observations (in mill.)") ///
                    colors(blue green red black)  msymbol(O S D T) lpattern(longdash dash shortdash solid) ylabel(-1(0.5)1)
    graph export "$figs_folder/core/headcount_by_educ_index_`subgp'.pdf", replace
    
    // Education shares
    plot_timeseries share1 share2 share9 ,  ///
                    legend(order(2 "Non-College" 3 "College" 4 "No Education Data" )) ///
                    ytitle("Share of Population") ///
                    colors(blue green red) msymbol(S D T)lpattern(longdash dash shortdash) ylabel(0(0.2)1)
    graph export "$figs_folder/core/educ_shares_`subgp'.pdf", replace     
    
    
  restore
}


// Change in the Number of Observations by Job Type
// ==========================================================================
load_csvdata, filename("$iab_folder/$mydate Data ddv cohort plot/data_diff_dep_var_cohort_plot_v2.csv") 

gcollapse (sum) N, by(year male jobtype)
replace N = N / 1e6 / 0.1
greshape wide N, by(year male) keys(jobtype)
keep if year >= 2001
generate Ntotal = N1 + N2 + N3
generate share1 = N1 / Ntotal
generate share2 = N2 / Ntotal
generate share3 = N3 / Ntotal

foreach subgp in male female {
  preserve
    keep if male == cond("`subgp'" == "male", 1, 0)
    
    // Headcount by education
    plot_timeseries N1 N2 N3 Ntotal,  ///
                    legend(order(2 "Full-Time" 3 "Part-Time" 4 "Mini-Job" 5 "Total")) ///
                    ytitle("Number of Observations (in mill.)") ///
                    colors(blue green red black) msymbol(O S D T) lpattern(longdash dash shortdash solid) ylabel(0(2)14)
    graph export "$figs_folder/core/headcount_by_jobtype_`subgp'.pdf", replace     
    
    // Headcount by education (indexed)
    plot_timeseries N1 N2 N3 Ntotal, index ///
                    legend(order(2 "Full-Time" 3 "Part-Time" 4 "Mini-Job" 5 "Total")) ///
                    ytitle("Change in Number of Observations (in mill.)") ///
                    colors(blue green red black)  msymbol(O S D T) lpattern(longdash dash shortdash solid) ylabel(-1.5(0.5)2)
    graph export "$figs_folder/core/headcount_by_jobtype_index_`subgp'.pdf", replace
    
    // Education shares
    plot_timeseries share1 share2 share3 ,  ///
                    legend(order(2 "Full-Time" 3 "Part-Time" 4 "Mini-Job")) ///
                    ytitle("Share of Population") ///
                    colors(blue green red) msymbol(S D T) lpattern(longdash dash shortdash) ylabel(0(0.2)1)
    graph export "$figs_folder/core/jobtype_shares_`subgp'.pdf", replace     
    
    
  restore
}
