cap mkdir "${figs_folder}/specific"

global incvars labinc totinc totinc_noKV nonlabinc_noKV businc_noSE capinc_noKV inc_kv inc_selfempl




//==========================================================================================
// Density of Positive Part of Income Components
//==========================================================================================


foreach subgp in all male female {

  if      "`subgp'" == "all"    local keepsubpopulation = ""
  else if "`subgp'" == "male"   local keepsubpopulation = "keep if male == 1"
  else if "`subgp'" == "female" local keepsubpopulation = "keep if male == 0"

  // Clear data
  clear
  
  // Loop over income sources
  qui foreach incvar of global incvars {
  
    // compute cdf and density
    preserve

    // Load data
      if "`subgp'" == "all"  import delimited using "$tpp_folder/$mydate 106_descriptives/post/bins_`incvar'.csv", clear case(preserve)
      else import delimited using "$tpp_folder/$mydate 106_descriptives/post/bins_`incvar'_male.csv", clear case(preserve)
      keep if lb >= 2300 & lb <= 25000000
      `keepsubpopulation'
      
      //if "`incvar'" == "inc_kv" keep if year < 2009
      keep if year < 2009
      
      // Midpoint (time-invariant)
      generate midpoint = (ub + lb) / 2 / 1000 
      generate logmidpoint = log(midpoint)
      generate width = ub-lb
      generate logwidth = log(ub) - log(lb)
      
      // Aggregate years
      gcollapse (sum) N=N (mean) width logwidth (firstnm) midpoint logmidpoint, by(lb)
      gegen Ntotal = total(N)
      generate pmf = N / Ntotal
      generate density = pmf / width
      generate logdensity = pmf / logwidth
      generate logmass = Ntotal * logdensity / 1e6
      generate mass = N / width
            
      // Save density and cdf
      drop width N Ntotal pmf      
      generate source = "`incvar'"
      tempfile thissource
      save "`thissource'", replace
    
    restore
    
    // Append
    append using "`thissource'"
  
  }
  
  
  // Graph
  local yvar logmass
  twoway  (line `yvar' midpoint if source == "inc_selfempl", lcolor(red) lpattern(dash) lwidth(*1.5) ylabel(#8, axis(1) grid)) ///
          (line `yvar' midpoint if source == "businc_noSE", lcolor(green) lpattern(longdash) lwidth(*1.5) ylabel(#8, axis(1) grid)) ///         
          (line `yvar' midpoint if source == "capinc_noKV", lcolor(navy) lpattern(dash_dot) lwidth(*1.5) ylabel(#8, axis(1) grid)) ///
          (line `yvar' midpoint if source == "inc_kv", lcolor(pink) lpattern(longdash_shortdash) lwidth(*1.5) ylabel(#8, axis(1) grid)) ///
          (line `yvar' midpoint if source == "labinc", yaxis(2) lcolor(blue) lpattern(solid) lwidth(*1.5) ylabel(#8, axis(2) nogrid)) ///
          , legend(pos(2) order(5 "Labor" 1 "Self-Empl." 2 "Business" 3 "Rental" 4 "Capital")) ///
          xscale(log) xlabel(2.5 5 10 20 50 100 200 500 1000 2500 10000 25000, labsize(medium)) /// 
          ytitle("Number of Observations (in mill.)", axis(1)) ytitle("Number of Observations (in mill.)", axis(2)) xtitle("Income (in 1000€)") 
  graph export "$figs_folder/specific/mass_income_components_`subgp'.pdf", replace
 
  local yvar logdensity
  twoway  (line `yvar' midpoint if source == "labinc", lcolor(blue) lpattern(solid) lwidth(*1.5)) ///
          (line `yvar' midpoint if source == "inc_selfempl", lcolor(red) lpattern(dash) lwidth(*1.5)) ///
          (line `yvar' midpoint if source == "businc_noSE", lcolor(green) lpattern(longdash) lwidth(*1.5)) ///
          (line `yvar' midpoint if source == "capinc_noKV", lcolor(navy) lpattern(dash_dot) lwidth(*1.5)) ///
          (line `yvar' midpoint if source == "inc_kv", lcolor(pink) lpattern(longdash_shortdash) lwidth(*1.5)) ///
          , legend(pos(2) order(1 "Labor" 2 "Self-Empl." 3 "Business" 4 "Rental" 5 "Capital")) ///
          xscale(log) xlabel(2.5 5 10 20 50 100 200 500 1000 2500 10000 25000, labsize(medium)) /// 
          ytitle("Density") xtitle("Income (in 1000€)") ylabel(#8)
  graph export "$figs_folder/specific/density_income_components_`subgp'.pdf", replace

} // subgp


//==========================================================================================
// Correlation between Income Components
//==========================================================================================

global incvars_select totinc_noKV labinc nonlabinc_noKV businc_noSE inc_selfempl inc_kv capinc_noKV


cap program drop table_correlations_incsources
program table_correlations_incsources

//--------------------------------------------------------------------------------------------
syntax using , gender(string) [source(string) incvars(string) width(real 1.0) year(int 2008) colnumbers]
//--------------------------------------------------------------------------------------------

  if "`source'" == ""      local source tppfull_log
  if "`incvars'" == ""      local incvars totinc labinc nonlabinc businc_noSE inc_selfempl inc_kv capinc_noKV
  if "`width'" == ""        local width = 1
  assert inlist("`gender'", "male", "female")
  
  // Load Data
  local sample = cond(strpos("`source'", "log") != 0, "_logsample", "")
  local weight = cond(strpos("`source'", "raw") != 0, "_hrf", "")
  local file = "${tpp_folder}/$mydate 106_descriptives/correlations`sample'`weight'_incomesources_male.csv"
  load_csvdata, filename("`file'")
  keep if year == `year' & male == cond("`gender'" == "male", 1, 0)

  // Initiate table
  //-------------------------------------

  local nincvars: word count `incvars'
  local ncols = `nincvars' + 1

  // Initiate tex-file
  cap file close table
  file open table `using', write replace

  // Begin tabular
  file write table "\newcolumntype{Y}{>{\raggedleft\arraybackslash}X}" _n
  file write table "\begin{tabularx}{`width'\textwidth}{l*{`=`ncols'-1'}{Y}}" _n
  file write table "\toprule \toprule" _n

  // Column Header: Incvars
  local thisline = ""
  foreach incvar of local incvars {
    if strpos("`incvar'", "totinc") != 0 local varlabel = "Total"
    if strpos("`incvar'", "nonlabinc") != 0 local varlabel = "Non-Labor"
    if "`incvar'" == "labinc" local varlabel = "Labor"
    if "`incvar'" == "businc_noSE" local varlabel = "Business"
    if "`incvar'" == "inc_selfempl" local varlabel = "Self-Empl."  
    if "`incvar'" == "inc_kv" local varlabel = "Capital"    
    if "`incvar'" == "capinc_noKV" local varlabel = "Rental"    
    local thisline = "`thisline' & \multicolumn{1}{c}{`varlabel'}"
  }
  file write table "`thisline' \\" _n

  // Column Numbers
  if "`colnumbers'" != "" {
    local thisline = ""
    foreach col of numlist 1/`=`ncols'-1' {
      local thisline = "`thisline' & \multicolumn{1}{c}{(`col')}"
    }
    file write table "`thisline' \\" _n
  }

  file write table "\midrule" _n

  // Loop over income sources
  qui foreach incvar1 of local incvars {
    if strpos("`incvar1'", "totinc") != 0 local varlabel = "Total"
    if strpos("`incvar1'", "nonlabinc") != 0 local varlabel = "Non-Labor"
    if "`incvar1'" == "labinc" local varlabel = "Labor"
    if "`incvar1'" == "businc_noSE" local varlabel = "Business"
    if "`incvar1'" == "inc_selfempl" local varlabel = "Self-Empl."  
    if "`incvar1'" == "inc_kv" local varlabel = "Capital"    
    if "`incvar1'" == "capinc_noKV" local varlabel = "Rental"    
    local thisline = "`varlabel'"
    foreach incvar2 of local incvars {
      noi sum `incvar1' if incvar == "`incvar2'"
      local rho = strofreal(`r(mean)', "%9.4f")
      local thisline "`thisline' & `rho'" 
    }
    file write table "`thisline' \\" _n
  }

  // End tabular
  file write table "\bottomrule" _n
  file write table "\end{tabularx}" _n

  // Close tex-file
  file close table
  
end

table_correlations_incsources using "${figs_folder}/data/correlations_incsources_male.tex", year(2008) ///
  gender(male) incvars($incvars_select) width(1.0)
table_correlations_incsources using "${figs_folder}/data/correlations_incsources_female.tex", year(2008) ///
  gender(female) incvars($incvars_select) width(1.0)
  
//==========================================================================================
// Average Income by Components over Time
//==========================================================================================


foreach subgp in all male female {
  
  if      "`subgp'" == "all"    local keepsubpopulation = ""
  else if "`subgp'" == "male"   local keepsubpopulation = "keep if male == 1"
  else if "`subgp'" == "female" local keepsubpopulation = "keep if male == 0"

  // Loop over income sources
  clear
  qui foreach incvar of global incvars {
    preserve
    // Load data by total income bin
      if "`subgp'" == "all" import delimited using "$tpp_folder/$mydate 106_descriptives/sumstats_logsample_`incvar'.csv", clear case(preserve)
      else import delimited using "$tpp_folder/$mydate 106_descriptives/sumstats_logsample_`incvar'_male.csv", clear case(preserve)
      `keepsubpopulation'      
      if "`incvar'" == "inc_kv" drop if year >= 2009
      rename mean`incvar' mean
      generate log_mean = log(mean)
      // Save density and cdf
      generate source = "`incvar'"
      tempfile thissource
      save "`thissource'", replace
    restore   
    // Append
    append using "`thissource'"
  
  }
  
  // Levels: Non-Labor only
  local yvar mean
  twoway  (line `yvar' year if source == "nonlabinc_noKV", lcolor(gs10) lpattern(solid) lwidth(*1.5)) ///
          (line `yvar' year if source == "businc_noSE", lcolor(green) lpattern(longdash) lwidth(*1.5)) ///
          (line `yvar' year if source == "inc_selfempl", lcolor(red) lpattern(shortdash) lwidth(*1.5)) ///
          (line `yvar' year if source == "capinc_noKV", lcolor(navy) lpattern(dash_dot) lwidth(*1.5)) ///
          (line `yvar' year if source == "inc_kv", lcolor(pink) lpattern(longdash_shortdash) lwidth(*1.5)) ///
          , legend(pos(11) order(1 "Non-Labor" 2 "Business" 3 "Self-Empl." 4 "Rental" 5 "Capital (pre 2009)")) ///
          xlabel(2000(2)2016) ytitle("Average Income") xtitle("") ylabel(0(2000)8000) name(`subgp', replace)
  graph export "$figs_folder/specific/mean_income_by_components_`subgp'.pdf", replace

  // Logs
  local yvar log_mean
  twoway  (line `yvar' year if source == "totinc_noKV", lcolor(gs10) lpattern(solid) lwidth(*1.5)) ///
          (line `yvar' year if source == "labinc", lcolor(blue) lpattern(dash) lwidth(*1.5)) ///
          (line `yvar' year if source == "businc_noSE", lcolor(green) lpattern(longdash) lwidth(*1.5)) ///
          (line `yvar' year if source == "inc_selfempl", lcolor(red) lpattern(shortdash) lwidth(*1.5)) ///
          (line `yvar' year if source == "capinc_noKV", lcolor(navy) lpattern(dash_dot) lwidth(*1.5)) ///
          (line `yvar' year if source == "inc_kv", lcolor(pink) lpattern(longdash_shortdash) lwidth(*1.5)) ///
          , legend(pos(7) order(1 "Total" 2 "Labor" 3 "Business" 4 "Self-Empl." 5 "Rental" 6 "Capital (pre 2009)")) ///
          xlabel(2000(2)2016) ytitle("Log Average Income") xtitle("") ylabel(2/11) name(`subgp', replace)
  graph export "$figs_folder/specific/logmean_income_by_components_`subgp'.pdf", replace

  
} // subgp



//==========================================================================================
// Main Income Sources by Total Income
//==========================================================================================


// Load Data
load_csvdata, filename("$tpp_folder/$mydate 406_distributions (totinc_noKV)/inequality/mean_income_by_rankincome_malemainsrc4.csv")

// Aggregate Groups
recode rankincome (0/20 = 1 "P0-P20") (21/40 = 2 "P20-P40") (41/60 = 3 "P40-P60") (61/80 = 4 "P60-P80") (81/90 = 5 "P80-P90") (91/95 = 6 "P90-P95") ///
                  (96/99 = 7 "P95-P99") (99.1/99.9 = 8 "P99-P99.9") (99.91/99.99 = 9 "P99.9-P99.99") (99.991/100 = 10 "P99.99-P100"), ///
                  generate(group) label(lblgroup)

// Fill lower and upper bound
replace lbincome = 2300 if group == 1
replace ubincome = 1e10 if group == 10

// Reshape
gcollapse (percent) sharetotal=N [aw=sum_weights], by(year male group) merge
gcollapse (min) lb=lbincome (max) ub=ubincome (mean) mean=meanincome [aw=sum_weights], by(year male group) merge
gcollapse (percent) share=N (firstnm) sharetotal mean (min) lb (max) ub [aw=sum_weights], by(year male group mainsrc)
replace share = share / sharetotal
sort mainsrc group
drop sharetotal
// replace missings with 0
greshape wide share, by(year male group) key(mainsrc4)
mvencode share*, mv(0)
greshape long share, by(year male group) key(mainsrc4)
// save as csv
export delimited using "$tpp_folder/$mydate 406_distributions (totinc_noKV)/inequality/mainsrc4_by_incomegroup_logsample_male.csv", replace

// Year
gcollapse lb ub mean share, by(male group mainsrc4)

// reshape wide
greshape wide share, by(male group) key(mainsrc4)
order male group lb ub mean share*


// Graph
foreach subgp in male female {
  twoway connect share1-share4 group if male == cond("`subgp'" == "male", 1, 0), ///
          xlabel(1/10, valuelabel angle(45) labsize(*0.75)) ylabel(0(0.2)1) ///
          legend(order(1 "Workers" 2 "Self-Empl." 3 "Business Owners" 4 "Landlords") position(9)) ///
          xtitle("Partition of Total Income Distribution") ytitle("Share of Observations") ///
          color(blue red green navy) mfcolor(%25...) msymbol(O S D T) lpattern(solid dash longdash shortdash)
  graph export "${figs_folder}/specific/mainsrc4_by_incomerank_`subgp'.pdf", replace
}
        
  
//==========================================================================================
// Average Income by Main Income Source over Time
//==========================================================================================

foreach mainsrc in /*mainsrc2*/ mainsrc4 {
foreach subgp in /*all*/ male female {
//local mainsrc mainsrc4
//local subgp male
  if "`subgp'" == "male"   local keepsubpopulation = "keep if male == 1"
  else if "`subgp'" == "female" local keepsubpopulation = "keep if male == 0"
  else local keepsubpopulation = ""
  
  local suf = cond("`subgp'" == "all", "", "male")
  local sufpop = cond("`subgp'" == "all", "", "_male")
  
  load_csvdata, filename("$tpp_folder/$mydate 406_distributions (totinc_noKV)/inequality/sumstats_income_`suf'`mainsrc'.csv") dropsuffix(income)
  preserve
    load_csvdata, filename("$tpp_folder/$mydate 406_distributions (totinc_noKV)/inequality/sumstats_income`sufpop'.csv") dropsuffix(income)
    generate mainsrc4 = 9
    tempfile popdata
    save "`popdata'", replace
  restore
  append using "`popdata'"
  `keepsubpopulation'    
  keep year mean `mainsrc'
  replace mean = mean / 1000
  generate logmean = log(mean)

  greshape wide mean logmean, by(year) key(`mainsrc')
  
  local moveup = cond("`subgp'" == "male" & "`mainsrc'" == "mainsrc4", 22, 0)
  local legpos = cond("`subgp'" == "male" & "`mainsrc'" == "mainsrc4", 9, 11)
  if "`mainsrc'" == "mainsrc4" local legendorder = `"2 "$label_labor" 3 "$label_self" 4 "$label_business" 5 "$label_rental" 6 "Population""'
  else local legendorder = `"2 "$label_labor" 3 "$label_nonlabor" 4 "Population""'

  * levels
  plot_timeseries mean?,  ///
      legend(bmargin(b+`moveup') order(`legendorder')) legpos(`legpos') ///
      ylabel(10(10)100) ytitle("Average Total Income (in 1000€)") ///
      colors(${colors_`mainsrc'} black) lpattern(${patterns_`mainsrc'} dash) msymbol(${symbols_`mainsrc'} none)
  graph export "$figs_folder/specific/mean_income_by_`mainsrc'_`subgp'.pdf", replace
  
  * index
  plot_timeseries logmean?, index ///
      legend(order(`legendorder')) ///
      ylabel(-0.1(0.1)0.4) ytitle("Log Mean Income Relative to 2001") ///
      colors(${colors_`mainsrc'} black) lpattern(${patterns_`mainsrc'} dash) msymbol(${symbols_`mainsrc'} none)
  graph export "$figs_folder/specific/mean_income_logdiff_by_`mainsrc'_`subgp'.pdf", replace
  
} // subgp
} // mainsrc


//==========================================================================================
// Income, Non-Zero, Negative Shares over Time
//==========================================================================================

local nvar N_weight
foreach subgp in all male female {
  
  if      "`subgp'" == "all"    local keepsubpopulation = ""
  else if "`subgp'" == "male"   local keepsubpopulation = "keep if male == 1"
  else if "`subgp'" == "female" local keepsubpopulation = "keep if male == 0"

  // Clear data
  clear
  
  // Loop over income sources
  qui foreach incvar of global incvars {
  
    preserve

      // Load data and housekeeping
      load_csvdata, filename("${tpp_folder}/$mydate 105_overviewdata/distribution_stats_`incvar'_male.csv")  
      `keepsubpopulation'
      
      rename bin_ bin
      rename lb_ lb
      rename ub_ ub
      replace lb = -1e10 if ub < 0 & missing(lb)
      replace ub =  1e10 if lb > 0 & missing(ub)
      keep year male bin lb ub `nvar' `incvar'
      rename `nvar' N
      generate nlbneg = N if lb < 0
      generate nubneg = N if ub < 0
      generate N_zero = N if bin == 0    
      replace lb = . if lb > 0 | bin == 0
      replace ub = . if ub < 0 | bin == 0
      
      // Collapse
      gcollapse (rawsum) N N_zero nlbneg nubneg (max) lb (min) ub (mean) mean_income=`incvar' [aw=N], by(year)
      
      // Share of negative incomes
      generate N_neg = (nlbneg * abs(lb) + nubneg * abs(ub)) / (abs(lb) + abs(ub))
      drop nlbneg nubneg lb ub
      generate share_neg = N_neg / (N - N_zero)
      // Share of zero incomes
      generate share_zero = N_zero / N
      generate share_nonzero = 1 - N_zero / N

      generate source = "`incvar'"
      tempfile thissource
      save "`thissource'", replace
      
    restore
    
    append using "`thissource'"
    
  }
  
  // Income Shares
  generate mean_totinc = mean_income if source == "totinc"
  bysort year: ereplace mean_totinc = min(mean_totinc)
  generate share_income = mean_income / mean_totinc
  drop mean_totinc
    
  // Income Share (including zeros)
  auto_legend_position share_income year if inlist(source, "businc_noSE", "inc_selfempl", "capinc_noKV", "inc_kv")
  twoway  (line share_income year if source == "businc_noSE", lcolor(green) lpattern(longdash) lwidth(*2)) ///
          (line share_income year if source == "inc_selfempl", lcolor(red) lpattern(dash) lwidth(*2)) ///
          (line share_income year if source == "capinc_noKV", lcolor(navy) lpattern(dash_dot) lwidth(*2)) ///
          (line share_income year if source == "inc_kv", lcolor(pink) lpattern(longdash_shortdash) lwidth(*2)) ///
          , legend(pos(11) order(1 "Business" 2 "Self-Empl." 3 "Rental" 4 "Capital")) ///
          xlabel(2000(2)2016) ylabel(-0.02(0.02)0.1) ytitle("Share of Total Income") xtitle("") yline(0, lpattern(dash) lcol(gs5))
  graph export "$figs_folder/specific/incomeshare_by_source_`subgp'.pdf", replace
  
  // Negative
  auto_legend_position share_neg year if inlist(source, "totinc" "businc_noSE", "inc_selfempl", "capinc_noKV", "inc_kv")
  twoway  (line share_neg year if source == "totinc", lcolor(gs10) lpattern(solid) lwidth(*2)) ///
          (line share_neg year if source == "businc_noSE", lcolor(red) lpattern(longdash) lwidth(*2)) ///
          (line share_neg year if source == "inc_selfempl", lcolor(green) lpattern(dash) lwidth(*2)) ///
          (line share_neg year if source == "capinc_noKV", lcolor(navy) lpattern(dash_dot) lwidth(*2)) ///
          (line share_neg year if source == "inc_kv", lcolor(pink) lpattern(longdash_shortdash) lwidth(*2)) ///
          , legend(pos(2) order(1 "Total" 2 "Business" 3 "Self-Empl." 4 "Rental" 5 "Capital")) ///
          xlabel(2000(2)2016) ytitle("Share of Negative Among Non-Zero Obs.") xtitle("") ylabel(0(0.2)0.6)
  graph export "$figs_folder/specific/share_negative_among_nonzero_by_source_`subgp'.pdf", replace

  // Non-Zero
  twoway  (line share_nonzero year if source == "businc_noSE", lcolor(green) lpattern(longdash) lwidth(*2)) ///
          (line share_nonzero year if source == "inc_selfempl", lcolor(red) lpattern(dash) lwidth(*2)) ///
          (line share_nonzero year if source == "capinc_noKV", lcolor(navy) lpattern(dash_dot) lwidth(*2)) ///
          (line share_nonzero year if source == "inc_kv", lcolor(pink) lpattern(longdash_shortdash) lwidth(*2)) ///
          , legend(pos(11) order(1 "Business" 2 "Self-Empl." 3 "Rental" 4 "Capital")) ///
          xlabel(2000(2)2016) ytitle("Share of Non-Zero Income Obs.") xtitle("") ylabel(0(0.05)0.2)
  graph export "$figs_folder/specific/share_nonzero_by_source_`subgp'.pdf", replace

}



//==========================================================================================
// Income Components by Total and Labor Income
//==========================================================================================

foreach xvar in totinc totinc_noKV {
foreach subgp in all male female {

  if      "`subgp'" == "all"    local keepsubpopulation = ""
  else if "`subgp'" == "male"   local keepsubpopulation = "keep if male == 1"
  else if "`subgp'" == "female" local keepsubpopulation = "keep if male == 0"

  // By total income including KV (pre 2009)
  //---------------------------------------------------

  // Load data
  import delimited using "$tpp_folder/$mydate 105_overviewdata/distribution_stats_`xvar'_male.csv", clear case(preserve)
  keep if year < 2009
  rename bin_`xvar' bin
  drop if bin == 0
  `keepsubpopulation'
  keep if `xvar' > 2000
  
  keep bin N_weight `xvar' labinc nonlabinc_noKV businc_noSE inc_selfempl capinc_noKV inc_kv
  rename `xvar' inc_total
  rename labinc inc_labor
  rename nonlabinc_noKV inc_nonlabor
  rename inc_selfempl inc_selfempl
  rename businc_noSE inc_business
  rename capinc_noKV inc_rental
  rename inc_kv inc_capital
  
  // Aggregate years
  gcollapse (mean) inc_* [aw=N_weight], by(bin)

  // Share of total income
  qui foreach var in labor nonlabor selfempl business rental capital {
    generate share_`var' = inc_`var' / inc_total
  }
  keep inc_total share_*
  
  // Rescale
  replace inc_total = inc_total / 1000

 
  local ylabel = cond("`xvar'" == "totinc", "-0.2(0.2)1.2", "0(0.1)1")

  twoway line share_labor share_business share_selfempl share_rental share_capital inc_total, ///
    legend(pos(9) order(1 "Labor" 3 "Self-Empl." 2 "Business" 4 "Rental" 5 "Capital")) ///
    lcolor(blue green red navy pink) lwidth(*1.5..) lpattern(solid longdash dash shortdash_dot longdash_shortdash) ///
    xscale(log) xlabel(2.5 5 10 20 50 100 200 500 1000 2500 10000 25000, labsize(medium)) ///
    xtitle("Total Income (in 1000 €)") ytitle("Share of Total Income") ylabel(`ylabel')
  graph export "$figs_folder/specific/income_components_by_`xvar'_pre2009_`subgp'.pdf", replace

 
}
}
