//=======================================================================================
// Inequality
//=======================================================================================

cd "$tpp_folder/$mydate 406_distributions (totinc_nokv)"


// Standard Graphs
//--------------------------------------------------------


foreach var in loginc {

// Loop over (Sub-)Populations
qui foreach subgp in all male female {

  // Load data
	if "`subgp'" == "all"   local suffix = ""
	else                    local suffix = "_male"
  load_csvdata, filename("inequality/sumstats_`var'`suffix'.csv") dropsuffix(`var')
  if "`subgp'" == "male"    keep if male == 1
  if "`subgp'" == "female"  keep if male == 0
  

  // Additional statistics
  add_statistics
  
  
  // Core percentiles
  local ylabel = "ylabel(8.0(0.5)11.5)"
  plot_timeseries p90 p75 p50 p25 p10, ///
                  legend(order(2 "P90" 3 "P75" 4 "P50" 5 "P25" 6 "P10")) ///
                  ytitle("Log Income Percentiles") `ylabel'
  graph export "$figs_folder/specific/`var'_core_percentiles_`subgp'.pdf", replace      
  
  // Top percentiles
  local ylabel = "ylabel(10/15)"
  plot_timeseries p99_99 p99_9 p99 p95 p90, ///
                  legend(order(2 "P99.99" 3 "P99.9" 4 "P99" 5 "P95" 6 "P90")) ///
                  ytitle("Log Income Percentiles") `ylabel'
  graph export "$figs_folder/specific/`var'_top_percentiles_`subgp'.pdf", replace
  
  // Core percentiles indexed
  local ylabel = cond("`var'" == "loginc", "ylabel(-0.2(0.1)0.2)", "ylabel(-0.2(0.1)0.3)") 
  plot_timeseries p90 p75 p50 p25 p10, index ///
                  legend(order(2 "P90" 3 "P75" 4 "P50" 5 "p25" 6 "P10")) ///
                  ytitle("Log Income Percentiles Relative to $yrfirst") `ylabel'
  graph export "$figs_folder/specific/`var'_core_percentiles_index_`subgp'.pdf", replace      
  
  // Top percentiles indexed
  local ylabel = cond("`var'" == "loginc", "ylabel(-0.2(0.1)0.5)", "ylabel(-0.2(0.1)0.5)") 
  plot_timeseries p99_99 p99_9 p99 p95 p90, index ///
                  legend(order(2 "P99.99" 3 "P99.9" 4 "P99" 5 "P95" 6 "P90")) ///
                  ytitle("Log Income Percentiles Relative to $yrfirst") `ylabel'
  graph export "$figs_folder/specific/`var'_top_percentiles_index_`subgp'.pdf", replace

  // Standard deviation and P90-P10
  local ylabel = cond("`var'" == "loginc", "ylabel(1.7(0.1)2.4)", "ylabel(2/8)") 
  plot_timeseries sd256 p90p10, ///
                  colors(blue red) msymbol(O S) ///
                  legend(order(2 "2.56*{&sigma}" 3 "P90-P10")) ///
                  ytitle("Dispersion of Log Income") `ylabel'
  graph export "$figs_folder/specific/`var'_sd_p90p10_`subgp'.pdf", replace

  // P50-P10 and P90-P50
  local ylabel = cond("`var'" == "loginc", "ylabel(0.6(0.2)1.6)", "ylabel(0.6(0.2)1.8)") 
  plot_timeseries p90p50 p50p10, ///
                  colors(blue red) msymbol(O S) ///
                  legend(order(2 "P90-P50" 3 "P50-P10")) ///
                  ytitle("Dispersion of Log Income") `ylabel'
  graph export "$figs_folder/specific/`var'_p90p50_p50p10_`subgp'.pdf", replace     
  
} // subgp   

} // var    


// Standard Graphs by Main Income Source
//--------------------------------------------------------

local mainsrc mainsrc2
foreach var in loginc {

// Loop over (Sub-)Populations
qui foreach subgp in male female {

  // Load data
	if "`subgp'" == "all"   local suffix = "_`mainsrc'"
	else                    local suffix = "_male`mainsrc'"
  load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/inequality/sumstats_`var'`suffix'.csv") dropsuffix(`var')
  if "`subgp'" == "male"    keep if male == 1
  if "`subgp'" == "female"  keep if male == 0
  
  if "`mainsrc'" == "mainsrc2" local legendorder = `"2 "${label_labor}" 3 "${label_nonlabor}""'
  if "`mainsrc'" == "mainsrc3" local legendorder = `"2 "${label_labor}" 3 "${label_business}" 4 "${label_rental}""'
  if "`mainsrc'" == "mainsrc4" local legendorder = `"2 "${label_labor}" 3 "${label_self}" 4 "${label_business}" 5 "${label_rental}""'

  // Additional statistics
  add_statistics

  qui levelsof `mainsrc', local(msvals)
  foreach ms of local msvals {
  
    preserve
      keep if `mainsrc' == `ms'
      
      // Core percentiles
      local ylabel = "ylabel(8.0(0.5)12)"
      plot_timeseries p90 p75 p50 p25 p10, ///
                      legend(order(2 "P90" 3 "P75" 4 "P50" 5 "P25" 6 "P10")) ///
                      ytitle("Log Income Percentiles") `ylabel'
      graph export "$figs_folder/specific/`var'_core_percentiles_`subgp'`mainsrc'`ms'.pdf", replace      
      
      // Top percentiles
      local ylabel = "ylabel(10/17)"
      plot_timeseries p99_99 p99_9 p99 p95 p90, ///
                      legend(order(2 "P99.99" 3 "P99.9" 4 "P99" 5 "P95" 6 "P90")) ///
                      ytitle("Log Income Percentiles") `ylabel'
      graph export "$figs_folder/specific/`var'_top_percentiles_`subgp'`mainsrc'`ms'.pdf", replace
      
      // Core percentiles indexed
      local ylabel = cond("`var'" == "loginc", "ylabel(-0.2(0.1)0.3)", "ylabel(-0.2(0.1)0.3)") 
      plot_timeseries p90 p75 p50 p25 p10, index ///
                      legend(order(2 "P90" 3 "P75" 4 "P50" 5 "p25" 6 "P10")) ///
                      ytitle("Log Income Percentiles Relative to $yrfirst") `ylabel'
      graph export "$figs_folder/specific/`var'_core_percentiles_index_`subgp'`mainsrc'`ms'.pdf", replace      
      
      // Top percentiles indexed
      local ylabel = cond("`var'" == "loginc", "ylabel(-0.5(0.1)0.5)", "ylabel(-0.2(0.1)0.5)") 
      plot_timeseries p99_99 p99_9 p99 p95 p90, index ///
                      legend(order(2 "P99.99" 3 "P99.9" 4 "P99" 5 "P95" 6 "P90")) ///
                      ytitle("Log Income Percentiles Relative to $yrfirst") `ylabel'
      graph export "$figs_folder/specific/`var'_top_percentiles_index_`subgp'`mainsrc'`ms'.pdf", replace

      // Standard deviation and P90-P10
      local ylabel = cond("`var'" == "loginc", "ylabel(1.8(0.4)3)", "ylabel(2/8)") 
      plot_timeseries sd256 p90p10, ///
                      colors(blue red) msymbol(O S) ///
                      legend(order(2 "2.56*{&sigma}" 3 "P90-P10")) ///
                      ytitle("Dispersion of Log Income") `ylabel'
      graph export "$figs_folder/specific/`var'_sd_p90p10_`subgp'`mainsrc'`ms'.pdf", replace

      // P50-P10 and P90-P50
      local ylabel = cond("`var'" == "loginc", "ylabel(0.6(0.2)1.6)", "ylabel(0.6(0.2)1.8)") 
      plot_timeseries p90p50 p50p10, ///
                      colors(blue red) msymbol(O S) ///
                      legend(order(2 "P90-P50" 3 "P50-P10")) ///
                      ytitle("Dispersion of Log Income") `ylabel'
      graph export "$figs_folder/specific/`var'_p90p50_p50p10_`subgp'`mainsrc'`ms'.pdf", replace     

    restore
    
  } // ms
  
} // subgp   

} // var    
 
              
// Income Shares
//--------------------------------------------------------

// Loop over (Sub-)Populations
foreach subgp in all male female {

  // Load data
	if "`subgp'" == "all"   local suffix = ""
	else                    local suffix = "_male"
  load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/inequality/mean_income_by_rankincome`suffix'.csv") dropsuffix(income)
  if "`subgp'" == "male"    keep if male == 1
  if "`subgp'" == "female"  keep if male == 0
    
  // Income Shares
  compute_incshares, by(year)
  // Selected Shares
  preserve
    plot_timeseries share_Q1-share_Q5 share_top10 share_top1 share_top0_1, index ///
                colors(green black maroon red blue pink navy orange) msymbol(O X D S T Oh Dh Sh) ///
                legend(order(9 "Top 0.1%" 8 "Top 1%" 7 "Top 10%" 6 "Q5 (Top 20%)" 5 "Q4" 4 "Q3" 3 "Q2" 2 "Q1")) ///
                ytitle("Change in Income Shares Relative to $yrfirst") ylabel(-0.02(0.01)0.05)
    graph export "$figs_folder/specific/income_logsample_incshares_selected_index_`subgp'.pdf", replace     
  restore

  // Selected Shares, indexed using ratios
  preserve
    index_timeseries share*, method(ratio)    
    plot_timeseries share_Q1-share_Q5 share_top10 share_top1 share_top0_1, ///
                colors(green black maroon red blue pink navy orange) msymbol(O X D S T Oh Dh Sh) ///
                legend(order(9 "Top 0.1%" 8 "Top 1%" 7 "Top 10%" 6 "Q5 (Top 20%)" 5 "Q4" 4 "Q3" 3 "Q2" 2 "Q1")) ///
                ytitle("Rel. Change in Income Shares Relative to $yrfirst") ylabel(-0.2(0.2)0.4)
    graph export "$figs_folder/specific/income_logsample_incshares_selected_indexratio_`subgp'.pdf", replace     
  restore

  
  // Quintile Shares
  preserve
    plot_timeseries share_Q1-share_Q5, index ///
                colors(green black maroon red blue) msymbol(O X D S T) ///
                legend(order(6 "Q5 (top)" 5 "Q4" 4 "Q3" 3 "Q2" 2 "Q1 (bottom)")) ///
                ytitle("Change in Income Shares Relative to $yrfirst") ylabel(-0.02(0.02)0.06)
    graph export "$figs_folder/specific/income_logsample_incshares_quintiles_index_`subgp'.pdf", replace     
  restore

  // Quintile Shares, indexed using ratios
  preserve
    index_timeseries share*, method(ratio)    
    plot_timeseries share_Q1-share_Q5, ///
                colors(green black maroon red blue) msymbol(O X D S T) ///
                legend(order(6 "Q5 (top)" 5 "Q4" 4 "Q3" 3 "Q2" 2 "Q1 (bottom)")) ///
                ytitle("Rel. Change in Income Shares Relative to $yrfirst") ylabel(-0.2(0.05)0.1)
    graph export "$figs_folder/specific/income_logsample_incshares_quintiles_indexratio_`subgp'.pdf", replace     
  restore

  // Selected Shares 2
  preserve
    index_timeseries share_*, method(diff)
    plot_timeseries share_bot50 share_top10 share_top5 share_top1 share_top0_1 share_top0_01, ///
                colors(green black maroon red blue olive) msymbol(O T D S dh X) ///
                legend(order(7 "Top 0.01%" 6 "Top 0.1%" 5 "Top 1%" 4 "Top 5%" 3 "Top 10%" 2 "Bottom 50%")) ///
                ytitle("Abs. Change in Income Shares Relative to $yrfirst") ylabel(-0.04(0.02)0.05)
    graph export "$figs_folder/specific/income_logsample_incshares_selected2_index_`subgp'.pdf", replace     
  restore

  // Selected Shares 2, indexed using ratios
  preserve
    index_timeseries share_*, method(ratio)
    plot_timeseries share_bot50 share_top10 share_top5 share_top1 share_top0_1 share_top0_01, ///
                colors(green black maroon red blue olive) msymbol(O T D S dh X) ///
                legend(order(7 "Top 0.01%" 6 "Top 0.1%" 5 "Top 1%" 4 "Top 5%" 3 "Top 10%" 2 "Bottom 50%")) ///
                ytitle("Rel. Change in Income Shares Relative to $yrfirst") ylabel(-0.2(0.2)0.6)
    graph export "$figs_folder/specific/income_logsample_incshares_selected2_indexratio_`subgp'.pdf", replace     
  restore

  // Table
  table_income_shares using "$figs_folder/specific/income_logsample_incshares_`subgp'.tex"
  

} // subgp



// Pareto Tails
//--------------------------------------------------------


// Loop over (Sub-)Populations
qui foreach subgp in all male female {
foreach p in 1 5 {

  // Load Percentiles
	if "`subgp'" == "all"   local suffix = ""
	else                    local suffix = "_male"
  load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/inequality/sumstats_loginc`suffix'.csv") dropsuffix(loginc)
  if "`subgp'" == "male"    keep if male == 1
  if "`subgp'" == "female"  keep if male == 0
  
  keep year p*
  
  greshape long p , by(year) keys(pstr) string

  generate cdf = subinstr(pstr, "_", ".", .)
  destring cdf, replace
  
  // Dependent variable
  keep if cdf >= 100 - `p'
  generate yvar = log(1 - cdf/100)
  
  // Slope
  reg yvar p if year == 2005
  local alpha2005 = strofreal(round(_b[p], 0.01), "%9.2f")
  reg yvar p if year == 2015
  local alpha2015 = strofreal(round(_b[p], 0.01), "%9.2f")
  twoway  (line yvar p if year == 2005, lcolor(blue) lpattern(solid) lwidth(*2)) ///
          (lfit yvar p if year == 2005, lcolor(blue) lpattern(dash)) ///
          (line yvar p if year == 2015, lcolor(red) lpattern(solid) lwidth(*2)) ///
          (lfit yvar p if year == 2015, lcolor(red) lpattern(dash)) ///
          , legend(order(1 "2005 Level (Slope: `alpha2005')" 3 "2015 Level (Slope: `alpha2015')")) ///
          ytitle("log(1-CDF(y{sub:it}))") xtitle("log(y{sub:it})") ylabel(-12(2)-2) xlabel(11/16)
          
  graph export "$figs_folder/specific/income_paretotail_top`p'_`subgp'.pdf", replace
  
}
}
