//=======================================================================================
// Volatility
//=======================================================================================


//=======================================================================================
// Overall
//=======================================================================================

foreach var in resinc {
foreach k in 1 5 {

  // Load data by gender  
  load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/volatility/sumstats_`var'`k'F_male.csv") dropsuffix(`var'`k'F)
  preserve
    load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/volatility/sumstats_`var'`k'F.csv") dropsuffix(`var'`k'F)
    generate male = 9
    tempfile aggdata
    save "`aggdata'", replace
  restore
  append using "`aggdata'"

  // Additional statistics
  add_statistics
  
  // Shift year to center changes
  local shiftyear = `k'/2 - 0.5
  local xlabel = cond(`k' == 1, "xlabel(2000(2)2016)", "xlabel(2000(2)2016)")

    
  foreach subgp in all male female {
    if "`subgp'" == "all"    local ifcond = "if male == 9"
    if "`subgp'" == "male"    local ifcond = "if male == 1"
    if "`subgp'" == "female"  local ifcond = "if male == 0"
    
    // Core percentiles
    plot_timeseries p90 p75 p50 p25 p10 `ifcond', shiftyear(`shiftyear') `xlabel' ///
                    legend(order(2 "P90" 3 "P75" 4 "P50" 5 "p25" 6 "P10")) ///
                    ytitle("Percentiles of g{sup:`k'}{sub:it}")
    graph export "$figs_folder/specific/`var'`k'F_percentiles_`subgp'.pdf", replace 

    // Core percentiles indexed
    plot_timeseries p90 p75 p50 p25 p10 `ifcond', index shiftyear(`shiftyear') `xlabel' ///
                    legend(order(2 "P90" 3 "P75" 4 "P50" 5 "p25" 6 "P10")) ///
                    ytitle("Percentiles of g{sup:`k'}{sub:it} Relative to $yrfirst")
    graph export "$figs_folder/specific/`var'`k'F_percentiles_index_`subgp'.pdf", replace    

    // Lower and upper tail: P50-P10 and P90-P50
    plot_timeseries p90p50 p50p10 `ifcond', shiftyear(`shiftyear') `xlabel' ///
                    colors(blue red) msymbol(O S) ///
                    legend(order(2 "P90-P50" 3 "P50-P10")) ///
                    ytitle("Dispersion of g{sup:`k'}{sub:it}")
    graph export "$figs_folder/specific/`var'`k'F_p90p50_p50p10_`subgp'.pdf", replace    

  }

  // Reshape wide by gender
  keep year male sd p90p10 skew skewk kurt kurtcs
  greshape wide sd p90p10 skew skewk kurt kurtcs, by(year) keys(male)

  // Standard Deviation
  plot_timeseries sd1 sd0, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(3 "Women" 2 "Men")) ///
                  ytitle("Std. Dev. of g{sup:`k'}{sub:it}")
  graph export "$figs_folder/specific/`var'`k'F_sd_gender.pdf", replace    
  
  // P90-P10
  plot_timeseries p90p101 p90p100, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(3 "Women" 2 "Men")) ///
                  ytitle("P90-P10 Differential of g{sup:`k'}{sub:it}")
  graph export "$figs_folder/specific/`var'`k'F_p90p10_gender.pdf", replace    
  plot_timeseries p90p109, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(off order(3 "Women" 2 "Men")) ///
                  ytitle("P90-P10 Differential of g{sup:`k'}{sub:it}")
  graph export "$figs_folder/specific/`var'`k'F_p90p10_all.pdf", replace    
           
  // Kelley Skewness
  plot_timeseries skewk1 skewk0, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(3 "Women" 2 "Men")) ///
                  ytitle("Kelley Skewness of g{sup:`k'}{sub:it}")
  graph export "$figs_folder/specific/`var'`k'F_skewk_gender.pdf", replace    
  plot_timeseries skewk9, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(off order(3 "Women" 2 "Men")) ///
                  ytitle("Kelley Skewness of g{sup:`k'}{sub:it}")
  graph export "$figs_folder/specific/`var'`k'F_skewk_all.pdf", replace    

  // Excess Crow-Siddiqui Kurtosis
  plot_timeseries kurtcs1 kurtcs0, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(3 "Women" 2 "Men")) ///
                  ytitle("Excess Crow-Siddiqui Kurtosis of g{sup:`k'}{sub:it}")
  graph export "$figs_folder/specific/`var'`k'F_kurtcs_gender.pdf", replace    
  plot_timeseries kurtcs9, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(off order(3 "Women" 2 "Men")) ///
                  ytitle("Excess Crow-Siddiqui Kurtosis of g{sup:`k'}{sub:it}")
  graph export "$figs_folder/specific/`var'`k'F_kurtcs_all.pdf", replace    

  // Skewness (3rd Stand. Moment)
  plot_timeseries skew1 skew0, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(3 "Women" 2 "Men")) ///
                  ytitle("Skewness of g{sup:`k'}{sub:it}")
  graph export "$figs_folder/specific/`var'`k'F_skew_gender.pdf", replace    

  // Excess Kurtosis (4th Stand. Moment)
  plot_timeseries kurt1 kurt0, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red) msymbol(S O) lpattern(longdash solid) ///
                  legend(order(3 "Women" 2 "Men")) ///
                  ytitle("Excess Kurtosis of g{sup:`k'}{sub:it}")    
  graph export "$figs_folder/specific/`var'`k'F_kurt_gender.pdf", replace    

} // k
} // var


//=======================================================================================
// By Main Income Source: Non-Labor vs Labor
//=======================================================================================


foreach mainsrc in mainsrc2 {
foreach var in resinc {
foreach k in 1 5 {
foreach subgp in male female {

  //local mainsrc mainsrc4
  //local var resinc
  //local k 1
  //local subgp male


  if "`mainsrc'" == "mainsrc2" local legendorder = `"2 "${label_labor}" 3 "${label_nonlabor}""'
  if "`mainsrc'" == "mainsrc3" local legendorder = `"2 "${label_labor}" 3 "${label_business}" 4 "${label_rental}""'
  if "`mainsrc'" == "mainsrc4" local legendorder = `"2 "${label_labor}" 3 "${label_self}" 4 "${label_business}" 5 "${label_rental}""'
  
  // Load data by gender  
  load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/volatility/sumstats_`var'`k'F_male`mainsrc'.csv") dropsuffix(`var'`k'F)
  drop if `mainsrc' == .
  
  *if "`mainsrc'" == "mainsrc3" drop if mainsrc3 == 3
  *if "`mainsrc'" == "mainsrc4" drop if mainsrc4 == 4
    
  if "`subgp'" == "male"    keep if male == 1
  if "`subgp'" == "female"  keep if male == 0
  
  
  // Additional statistics
  add_statistics
  
  // Shift year to center changes
  local shiftyear = `k'/2 - 0.5
  local xlabel = cond(`k' == 1, "xlabel(2000(2)2016)", "xlabel(2000(2)2016)")
  

  // Reshape wide by mainsrc2
  replace N = N / 1e6
  keep year male N sd p90 p50 p10 p90p10 skew skewk kurt kurtcs p90p50 p50p10 p75p25 p97_5p2_5 `mainsrc'
  greshape wide N sd p90 p50 p10 p90p10 skew skewk kurt kurtcs p90p50 p50p10 p75p25 p97_5p2_5, by(year) keys(`mainsrc')

  // N
  plot_timeseries N?, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red green navy) msymbol(O S D T) lpattern(solid dash longdash shortdash) ///
                  legend(order(`legendorder')) ///
                  ytitle("Dispersion of g{sup:`k'}{sub:it}")
  graph export "$figs_folder/specific/`var'`k'F_headcount_by_`mainsrc'_`subgp'.pdf", replace    
  

  // P90, P50, P10
  if "`mainsrc'" == "mainsrc2" {
    local ylabel = cond(`k' == 1, "-1(0.25)1", "-1.5(0.5)1.5")
    local colors = cond("`mainsrc'" == "mainsrc2", "blue red", "blue red green navy")
    local symbols = cond("`mainsrc'" == "mainsrc2", "O S", "O S D T")
    local patterns = cond("`mainsrc'" == "mainsrc2", "solid dash", "solid dash longdash shortdash")
    plot_timeseries p90? p50? p10?, shiftyear(`shiftyear') `xlabel' ///
                    colors(blue red blue red blue red) msymbol(O Oh S Sh D Dh) lpattern(solid dash solid dash solid dash) ///
                    legend(rowgap(*0.8) size(*0.9) cols(2) order(2 "P90 Labor" 3 "P90 Non-Labor" 4 "P50 Labor" 5 "P50 Non-Labor" 6 "P10 Labor" 7 "P10 Non-Labor")) ///
                    ytitle("Percentiles of g{sup:`k'}{sub:it}") ylabel(`ylabel') legpos(5)
    graph export "$figs_folder/specific/`var'`k'F_p90_p50_p10_by_`mainsrc'_`subgp'.pdf", replace    
  }


  // P75-P25
  plot_timeseries p75p25?, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red green navy) msymbol(O S D T) lpattern(solid dash longdash shortdash) ///
                  legend(order(`legendorder')) ///
                  ytitle("P75-P25 of g{sup:`k'}{sub:it}")
  graph export "$figs_folder/specific/`var'`k'F_p75p25_by_`mainsrc'_`subgp'.pdf", replace    

  // P97.5-P2.5
  plot_timeseries p97_5p2_5?, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red green navy) msymbol(O S D T) lpattern(solid dash longdash shortdash) ///
                  legend(order(`legendorder')) ///
                  ytitle("P97.5-P2.5 of g{sup:`k'}{sub:it}")
  graph export "$figs_folder/specific/`var'`k'F_p97_5p2_5_by_`mainsrc'_`subgp'.pdf", replace    

  // P90-P50
  plot_timeseries p90p50?, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red green navy) msymbol(O S D T) lpattern(solid dash longdash shortdash) ///
                  legend(order(`legendorder')) ///
                  ytitle("P90-P50 of g{sup:`k'}{sub:it}")
  graph export "$figs_folder/specific/`var'`k'F_p90p50_by_`mainsrc'_`subgp'.pdf", replace    

  // P50-P10
  plot_timeseries p50p10?, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red green navy) msymbol(O S D T) lpattern(solid dash longdash shortdash) ///
                  legend(order(`legendorder')) ///
                  ytitle("P50-P10 of g{sup:`k'}{sub:it}")
  graph export "$figs_folder/specific/`var'`k'F_p50p10_by_`mainsrc'_`subgp'.pdf", replace    
  
  // Standard Deviation
  plot_timeseries sd?, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red green navy) msymbol(O S D T) lpattern(solid dash longdash shortdash) ///
                  legend(order(`legendorder')) ///
                  ytitle("Std. Dev. of g{sup:`k'}{sub:it}")
  graph export "$figs_folder/specific/`var'`k'F_sd_by_`mainsrc'_`subgp'.pdf", replace    

  // P90-P10
  local ylabel = cond("`var'" == "resinc", "0.4(0.2)1.4", "#6")
  plot_timeseries p90p10?, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red green navy) msymbol(O S D T) lpattern(solid dash longdash shortdash) ///
                  legend(order(`legendorder')) ///
                  ytitle("P90-P10 Differential of g{sup:`k'}{sub:it}") ylabel(`ylabel')
  graph export "$figs_folder/specific/`var'`k'F_p90p10_by_`mainsrc'_`subgp'.pdf", replace    
           
  // Kelley Skewness
  local ylabel = cond("`var'" == "resinc", "-0.1(0.1)0.5", "#6")
  plot_timeseries skewk?, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red green navy) msymbol(O S D T) lpattern(solid dash longdash shortdash) ///
                  legend(order(`legendorder')) ///
                  ytitle("Kelley Skewness of g{sup:`k'}{sub:it}") ylabel(`ylabel')
  graph export "$figs_folder/specific/`var'`k'F_skewk_by_`mainsrc'_`subgp'.pdf", replace    

  // Excess Crow-Siddiqui Kurtosis
  local ylabel = cond("`var'" == "resinc", "0(5)20", "#6")
  plot_timeseries kurtcs?, shiftyear(`shiftyear') `xlabel' ///
                  colors(blue red green navy) msymbol(O S D T) lpattern(solid dash longdash shortdash) ///
                  legend(order(`legendorder')) ///
                  ytitle("Excess Crow-Siddiqui Kurtosis of g{sup:`k'}{sub:it}") ylabel(`ylabel')
  graph export "$figs_folder/specific/`var'`k'F_kurtcs_by_`mainsrc'_`subgp'.pdf", replace    


} // subgp
} // k
} // var
} // mainsrc


//=======================================================================================
// Densities by Main Income Source
//=======================================================================================


foreach subgp in male female {
foreach yy in 2005 2010 {
foreach k in 1 5 {
foreach mainsrc in labor nonlabor {
   
  if "`subgp'" == "male"    local male = 1
  if "`subgp'" == "female"  local male = 0
  
  if "`mainsrc'" == "labor"   local g = 1
  if "`mainsrc'" == "nonlabor"  local g = 2

  
  // Moments
  load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/volatility/sumstats_resloginc`k'F_malemainsrc2.csv") dropsuffix(resloginc`k'F)
  keep if year == `yy' & male == `male' & mainsrc == `g'
  
  sum sd, meanonly
  local sd = r(mean)
  local sdplot: di %4.2f  `sd'
  
  sum skew, meanonly
  local skew = r(mean)
  local skewplot: di %4.2f `skew'

  sum kurt, meanonly
  local kurt = r(mean)
  local kurtplot: di %4.2f `kurt'

  // Density
  load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/volatility/density_resloginc`k'f_malemainsrc2.csv")
  keep if year == `yy' & male == `male' & mainsrc == `g'
  
  rename value_ mid
  rename density_ pdf_y    
  keep mid pdf_y

  // More (log) densities
  gen log_pdf_y = log(pdf_y)
  gen pdf_normal = normalden(mid, 0, `sd')
  gen log_pdf_normal = log(pdf_normal)

  // Slopes
  qui regress log_pdf_y mid if mid < -1 & mid > -4
  local blefttail: di %4.2f _b[mid]
  predict lefttail if e(sample), xb

  reg log_pdf_y mid if mid > 1 & mid < 4
  local brighttail: di %4.2f _b[mid]
  predict righttail if e(sample), xb

  // Trimming for plots
  drop if abs(mid) > 4
  replace log_pdf_normal = . if log_pdf_normal < -12
  replace log_pdf_y = . if log_pdf_y < -12
  
  // Figure: Log Density
  twoway line log_pdf_y log_pdf_normal lefttail righttail mid, ///
          lcolor(blue red black black navy forest_green)  ///
          lpattern(solid dash longdash longdash longdash dash)  ///
          lwidth(medthick..) ///
          ytitle("Log Density") ///
          ylabel(-12(2)3)  ///
          xtitle("One-Year Log Income Growth") ///
          xlabel(-4/4) ///
          legend(position(11) col(1) order(1 "Data Density" 2 "N(0,`sdplot'{sup:2})" 3 "Left   Slope: `blefttail'" 4 "Right Slope: `brighttail'")) ///
            text(`=cond(`k'==1, 2, 2)' 1.8 "St. Dev.: `sdplot'", place(e) size(${legesize})) ///
            text(`=cond(`k'==1, 1, 1)' 1.8 "Skewness: `skewplot'", place(e) size(${legesize})) ///
            text(`=cond(`k'==1, 0, 0)' 1.8 "Kurtosis: `kurtplot'", place(e) size(${legesize})) name(logden_`mainsrc', replace)
  graph export "${figs_folder}/specific/logdensity_resloginc`k'F_`yy'_`mainsrc'_`subgp'.pdf", replace

  // Figure: Density
  twoway line pdf_y pdf_normal mid if abs(mid) <= 2.5, ///
            lcolor(blue red black black navy forest_green)  ///
            lpattern(solid dash longdash longdash longdash dash)  ///
            lwidth(medthick..) ///
            ytitle("Density") ///
            ylabel(0/7)  ///
            xtitle("One-Year Log Income Growth") ///
            xlabel(-2.5(1)2.5) ///
            legend(position(11) col(1) order(1 "Data Density" 2 "N(0,`sdplot'{sup:2})")) ///
            text(5.5 1 "St. Dev.: `sdplot'", place(e) size(${legesize})) ///
            text(5.0 1 "Skewness: `skewplot'", place(e) size(${legesize})) ///
            text(4.5 1 "Kurtosis: `kurtplot'", place(e) size(${legesize})) name(den_`mainsrc', replace)
  graph export "${figs_folder}/specific/density_resloginc`k'F_`yy'_`mainsrc'_`subgp'.pdf", replace

} // mainsrc
}	// k
}	// years
}	// subgp


// Labor and Non-Labor in one Figure
foreach subgp in male female {
foreach yy in 2005 /*2010*/ {
foreach k in 1 5 {   
  if "`subgp'" == "male"    local male = 1
  if "`subgp'" == "female"  local male = 0
  
  if "`mainsrc'" == "labor"   local g = 1
  if "`mainsrc'" == "nonlabor"  local g = 2

  
  // Density
  load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/volatility/density_resloginc`k'f_malemainsrc2.csv")
  preserve
    load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/volatility/density_resloginc`k'f_male.csv")
    generate mainsrc2 = 9
    tempfile popdata
    save "`popdata'", replace
  restore
  append using "`popdata'"
  keep if year == `yy' & male == `male'
  
  rename value_ mid
  rename density_ pdf_y    
  keep mid pdf_y mainsrc2

  // More (log) densities
  gen log_pdf_y = log(pdf_y)

  // Trimming for plots
  drop if abs(mid) > 4
  replace log_pdf_y = . if log_pdf_y < -12

  // Figure: Log Density
  twoway  (line log_pdf_y mid if mainsrc2 == 1, lcolor(blue) lwidth(medthick) lpattern(solid)) ///
          (line log_pdf_y mid if mainsrc2 == 2, lcolor(red) lwidth(medthick) lpattern(dash)), ///
          ytitle("Log Density") ///
          ylabel(-12(2)3)  ///
          xtitle("One-Year Log Income Growth") ///
          xlabel(-4/4) ///
          legend(position(11) col(1) order(1 "${label_labor}" 2 "${label_nonlabor}"))
  graph export "${figs_folder}/specific/logdensity_resloginc`k'F_`yy'_by_mainsrc2_`subgp'.pdf", replace

  // Figure: Density
  twoway  (line pdf_y mid if mainsrc2 == 1 & abs(mid) < 1.5, lcolor(blue) lwidth(medthick) lpattern(solid)) ///
          (line pdf_y mid if mainsrc2 == 2 & abs(mid) < 1.5, lcolor(red) lwidth(medthick) lpattern(dash)), ///
          ytitle("Density") ///
          ylabel(0/7)  ///
          xtitle("One-Year Log Income Growth") ///
          xlabel(-1.5(1)1.5) ///
          legend(position(11) col(1) order(1 "${label_labor}" 2 "${label_nonlabor}"))
  graph export "${figs_folder}/specific/density_resloginc`k'F_`yy'_by_mainsrc2_`subgp'.pdf", replace

}	// k
}	// years
}	// subgp




//=======================================================================================
// Heterogeneity by Permanent Income
//=======================================================================================

foreach mainsrc in mainsrc2 mainsrc4 {
foreach k in 1 5  {
foreach subgp in male female {

  if "`mainsrc'" == "mainsrc2" local legendorder = `"1 "$label_labor" 2 "$label_nonlabor""'
  if "`mainsrc'" == "mainsrc3" local legendorder = `"1 "$label_labor" 2 "$label_business" 3 "$label_rental""'
  if "`mainsrc'" == "mainsrc4" local legendorder = `"1 "$label_labor" 2 "$label_self" 3 "$label_business" 4 "$label_rental""'
  
  if "`subgp'" == "male"    local ifcond = "if male == 1"
  if "`subgp'" == "female"  local ifcond = "if male == 0"

  // Append TPP and IAB results
  load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/volatility/sumstats_resinc`k'F_by_perminc_male`mainsrc'.csv") dropsuffix(resinc`k'F)
  keep `ifcond'
  
  // Add statistics
  add_statistics
  drop if mainsrc == .

  *if "`mainsrc'" == "mainsrc3" drop if mainsrc3 == 3
  *if "`mainsrc'" == "mainsrc4" drop if mainsrc4 == 4
  
  // Average over Years
  gcollapse sd p90p10 skew skewk kurt kurtcs p90p50 p50p10 mean_perminc, by(`mainsrc' rank_perminc)
  
  // Reshape wide by mainsrc
  greshape wide sd p90p10 skew skewk kurt kurtcs p90p50 p50p10, by(rank_perminc mean_perminc) keys(`mainsrc')
  
  // growth rate stats
  foreach stat in p90p10 skewk kurtcs {
  
    if "`stat'" == "p90p10" local ytitle = "P90-P10 of g{sup:`k'}{sub:it}"
    if "`stat'" == "skewk" local ytitle = "Kelley Skewness of g{sup:`k'}{sub:it}"
    if "`stat'" == "kurtcs" local ytitle = "Excess Crow-Siddiqui Kurtosis of g{sup:`k'}{sub:it}"
    else local ytitle "`var' of g{sup:`k'}{sub:it}"
    
    if "`stat'" == "p90p10" local ylabel = cond("" == "log", "0(0.5)1.5", "#6")
    else if "`stat'" == "skewk" local ylabel = cond("" == "log", "-0.1(0.1)0.6", "#6")
    else if "`stat'" == "kurtcs" local ylabel = cond("" == "log", "0(5)20", "#6")
    else local ylabel = "#6"
    
    auto_legend_position `stat'? rank_perminc
    local legpos = r(position)
    twoway  (line `stat'? rank_perminc, lcolor(blue red green navy) lpattern(solid dash longdash shortdash) lwidth(*2...)) ///
            , legend(position(2) order(`legendorder')) xlabel(#6) ylabel(`ylabel') ///
            xtitle("Quantiles of Residualized Log Permanent Income") ytitle("`ytitle'") name(`stat'_`subgp', replace)
    graph export "$figs_folder/specific/resinc`k'F_`stat'_by_perminc_`mainsrc'_`subgp'.pdf", replace

    auto_legend_position `stat'? rank_perminc
    local legpos = r(position)
    local xlabel = `" `=log(5000)' "5" `=log(15000)' "15" `=log(35000)' "35" `=log(100000)' "100" `=log(250000)' "250" `=log(1000000)' "1000" "'
    twoway  (line `stat'? mean_perminc, lcolor(blue red green navy) lpattern(solid dash longdash shortdash) lwidth(*2...)) ///
            , legend(position(2) order(`legendorder')) xlabel(`xlabel') ylabel(`ylabel') ///
            xtitle("exp(Mean Residualized Log Permanent Income) (in 1000€)") ytitle("`ytitle'") name(`stat'_`subgp', replace)
    graph export "${figs_folder}/specific/resinc`k'F_`stat'_by_meanperminc_`mainsrc'_`subgp'.pdf", replace
    
  }

}
}
}
