//=======================================================================================
// MAIN FIGURES
//=======================================================================================


//=======================================================================================
// TRANSITIONS
//=======================================================================================

// total population ranks (log sample)
foreach k in 1 5 {

  // Grouping A
  load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/mobility/transitions_rankincome`k'F_by_total.csv")
  drop if missing(rankincome) | missing(rankincome`k'F)
  foreach f in "" "`k'F" {
    generate group`f' = .
    replace group`f' = 1 if rankincome`f' >= 99
    replace group`f' = 2 if rankincome`f' < 99 & rankincome`f' >= 90
    replace group`f' = 3 if rankincome`f' < 90
  }
  gcollapse (sum) N=n_weight, by(year group group`k'F)
  gcollapse (sum) Ntotal=N, by(year group) merge

  generate share = N / Ntotal
  keep year group* share
  greshape wide share, by(year group) keys(group`k'F)

  plot_timeseries share* if group == 1, index legend(order(2 "Top 1" 3 "Next 9" 4 "Bottom 90")) ///
        xlabel(2000(2)2016) ytitle("Change in Transition Prob. for Top 1%")
  graph export "$figs_folder/specific/transitions`k'F_income_out_of_top1.pdf", replace
      
      
  // Grouping B
  load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/mobility/transitions_rankincome`k'F_by_total.csv")
  drop if missing(rankincome) | missing(rankincome`k'F)
  foreach f in "" "`k'F" {
    generate group`f' = .
    replace group`f' = 1 if rankincome`f' >= 99.9
    replace group`f' = 2 if rankincome`f' < 99.9 & rankincome`f' >= 99
    replace group`f' = 3 if rankincome`f' < 99 & rankincome`f' >= 90
    replace group`f' = 4 if rankincome`f' < 90
  }
  gcollapse (sum) N=n_weight, by(year group group`k'F)
  gcollapse (sum) Ntotal=N, by(year group) merge

  generate share = N / Ntotal
  keep year group* share
  greshape wide share, by(year group) keys(group`k'F)

  plot_timeseries share* if group == 1, index legend(order(2 "Top 0.1" 3 "Next 0.9" 4 "Next 9" 5 "Bottom 90")) ///
        xlabel(2000(2)2016) ytitle("Change in Transition Prob. for Top 0.1%")      
  graph export "$figs_folder/specific/transitions`k'F_income_out_of_top0_1.pdf", replace

}


// By Main Income Source
//------------------------------------------------------

foreach k in 1 5 {
  // Grouping A
  load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/mobility/transitions_rankincome`k'F_by_total_mainsrc2.csv")
  drop if missing(rankincome) | missing(rankincome`k'F)
  foreach f in "" "`k'F" {
    generate group`f' = .
    replace group`f' = 1 if rankincome`f' >= 99 & !missing(rankincome`f')
    replace group`f' = 2 if rankincome`f' < 99 & rankincome`f' >= 90
    replace group`f' = 3 if rankincome`f' < 90
  }
  gcollapse (sum) N=n_weight, by(year mainsrc2 group group`k'F)
  gcollapse (sum) Ntotal=N, by(year mainsrc2 group) merge

  generate share = N / Ntotal
  keep year mainsrc2 group* share

  keep if group == 1 & group`k'F == 1
  greshape wide share, by(year) keys(mainsrc2)

  plot_timeseries share* if group == 1, legend(order(2 "Workers" 3 "Entrepreneurs")) ///
        xlabel(2000(2)2016) ytitle("Prob. to Stay in Top 1%") ///
        colors(blue red) lpattern(solid longdash) msymbol(O S)
  graph export "$figs_folder/specific/transitions`k'F_income_stay_in_top1_by_mainsrc2.pdf", replace
      
      
  // Grouping B
  load_csvdata, filename("$tpp_folder/$mydate 406_Distributions (totinc_nokv)/mobility/transitions_rankincome`k'F_by_total_mainsrc2.csv")
  drop if missing(rankincome) | missing(rankincome`k'F)
  foreach f in "" "`k'F" {
    generate group`f' = .
    replace group`f' = 1 if rankincome`f' >= 99.9 & !missing(rankincome`f')
    replace group`f' = 2 if rankincome`f' < 99.9 & rankincome`f' >= 99
    replace group`f' = 3 if rankincome`f' < 99 & rankincome`f' >= 90
    replace group`f' = 4 if rankincome`f' < 90
  }
  gcollapse (sum) N=n_weight, by(year mainsrc2 group group`k'F)
  gcollapse (sum) Ntotal=N, by(year mainsrc2 group) merge

  generate share = N / Ntotal
  keep year mainsrc2 group* share

  keep if group == 1 & group`k'F == 1
  greshape wide share, by(year) keys(mainsrc2)

  plot_timeseries share* if group == 1, legend(order(2 "Workers" 3 "Entrepreneurs")) ///
        xlabel(2000(2)2016) ytitle("Prob. to Stay in Top 0.1%") ///
        colors(blue red) lpattern(solid longdash) msymbol(O S)
  graph export "$figs_folder/specific/transitions`k'F_income_stay_in_top0_1_by_mainsrc2.pdf", replace
}