cap program drop plot_timeseries
program plot_timeseries

  syntax varlist [if] [, index baseyear(int $yrfirst) shiftyear(real 0) colors(string) lpattern(string) msymbol(string) lwidth(string) ytitle(string asis) legpos(string) legend(string asis) ylabel(string) xlabel(string)]
  
  if "`colors'" == "" local colors blue green red navy black
  if "`msymbol'" == "" local msymbol O + S X D
  if "`lpattern'" == "" local lpattern solid longdash dash dash_dot shortdash longdash_dot
  if "`lwidth'" == "" local lwidth *1...
  if "`ylabel'" == "" local ylabel = "#6"

  // Fill colors
  local fcolors = ""
	foreach co of local colors {
		local fcolors = "`fcolors'" + " " + "`co'*0.25"
	}
 
  marksample touse, novarlist

  preserve
    
    keep if `touse'
    
    // Shift year variable
    generate yearshifted = year
    replace year = year + `shiftyear'
    qui sum year
    local firstyear = r(min)
    local lastyear = r(max)
    
    if "`xlabel'" == "" local xlabel = "2000(2)`lastyear'"
    
    if "`index'" != "" index_timeseries `varlist', yearvar(yearshifted) baseyear(`baseyear')

    // Generate recession vars
    tempvar rece
    gen `rece' = inlist(yearshifted, ${receyears})
    replace yearshifted = . if `rece' == .
    if inlist(substr("`xlabel'", 1, 2), "19", "20") {
      local firstxyear = substr("`xlabel'", 1, 4)
      replace `rece' = . if yearshifted < `firstxyear'
      replace yearshifted = . if `rece' == .
    }
    
    // Legend position
    if "`legpos'" == "" {
      auto_legend_position `varlist' yearshifted, ylabel(`ylabel')
      local legpos = r(position)
    }

    twoway (bar `rece' yearshifted, c(l) color(gray*0.5) yscale(off) ylabel(, axis(1) nogrid)) ///
           (connected `varlist' year, ///
              lcolor(`colors')  /// Line colors
              lpattern(`lpattern') lwidth(`lwidth') ///
              msymbol(`msymbol') /// Markers
              mlcolor(`colors') mfcolor(`fcolors')  /// Marker line and fill color
              yaxis(2)  yscale(alt axis(2)) ///
              ytitle(`ytitle', axis(2)) ///
              ylabel(`ylabel', axis(2) grid)),  ///
            xtitle("") ///
            xlabel(`xlabel', grid) ///
            legend(position(`legpos') `legend')
          
  restore

end



cap program drop plot_cohortage_timeseries
program plot_cohortage_timeseries
	syntax varlist(min=2 max=2) [if], cohorts(numlist) ages(numlist) ///
		[cohortvar(string) twowayoptions(string) arrow1(string asis) arrow2(string asis) arrow3(string asis) agesarrow(numlist) legpos(int 7) ///
     colors(string) msymbols(string)]

	tokenize `varlist'
	local yvar `1'
	local xvar `2'
  
  marksample touse, novarlist
  
  
  preserve
  
  keep if `touse'
  
  if "`cohortvar'" == "" local cohortvar = "cohort"

	// Number of ages
	local nages = 0
	foreach a of numlist `ages' {
		local ++nages
	}

	// First and latest cohort
  qui sum cohort
	local lastcohort = r(max)
	local firstcohort = 9999
	foreach c of numlist `cohorts' {
		local firstcohort = min(`firstcohort', `c')
	}

	// Initiate indicator for plotted observations
	tempvar inplot
	generate `inplot' = 0

	//legend positions
	local lpos=`legpos'

	// Cohort lines
	local cplots = ""
	if "`colors'" == "" local colors = "blue red black green"
	if "`msymbols'" == "" local msymbols = "O S T D"
	local i = 1
	local legendorder = ""
	foreach c of numlist `cohorts' {
		local wcolor `: word `i' of `colors''
		local wsymbol `: word `i' of `msymbols''
		local wpatt `: word `i' of `lpatters''

		local cplots = "`cplots' (connected `yvar' `xvar' if `cohortvar' == `c', lpattern(solid) lcolor(`wcolor') mfcolor(`wcolor'*0.25) mlcolor(`wcolor') msymbol(`wsymbol'))"
		replace  `inplot' = 1 if `cohortvar' == `c'

		local j = `nages' + `i'
		local legendorder = `"`legendorder' `j' "Cohort `c'" "'
		local ++i
	}

	// Age lines
	local aplots = ""
	local colors = "gray gray gray gray gray gray"
	local lpatterns = "dash dash dash dash dash dash" // "dash longdash dash_dot dash longdash dash_dot"
	local i = 1
	foreach a in `ages' {
		local wcolor `: word `i' of `colors''
		local wpatt `: word `i' of `lpatterns''

		local aplots = "`aplots' (line `yvar' `xvar' if age == `a' & `cohortvar' >= `firstcohort' & `cohortvar' <= `lastcohort', lpattern(`wpatt') lcolor(`wcolor'))"
		replace  `inplot' = 1 if age == `a' & `cohortvar' >= `firstcohort' & `cohortvar' <= `lastcohort'

		local ++i
	}

	// range of y variable
	qui sum `yvar' if  `inplot' == 1
	local yrange = r(max) - r(min)

	// Arrows
	local arrowplots = ""
	if `"`arrow1'"' != "" | `"`arrow2'"' != "" | `"`arrow3'"' != "" {
		foreach k in 1 2 3 {
			if `"`arrow`k''"' != "" {
				local arrowplots = `"`arrowplots'"' + "(pcarrowi " + `"`arrow`k''"' + ", mlwidth(medthick) mlcolor(black) lcolor(black) mlabcolor(black))"
			}
		}
	}
	else if "agesarrow" != "" {
		local check = 1
		foreach a of numlist `agesarrow' {
			// check if a in ages
			local check = strpos("`ages'", "`a'")
			if `check' == 0 {
				disp as error "plot_cohortage_inequality: age for arrow needs to be included in ages-option"
				assert `check' > 0
			}
			local xto = ${yrfirst} + `a' - 25 + 2
			qui summarize `yvar' if (age == `a') & (year == `xto')
			local yto = r(mean)
			local xfrom = `xto' + 0.5
			local yfrom = `yto' + 0.1*`yrange'
			local arrowplots = `"`arrowplots'"' + `"(pcarrowi `yfrom' `xfrom' `yto' `xto' (12) "`a' yrs old""' ///
			                      + ", mlwidth(medthick) mlcolor(black) lcolor(black) mlabcolor(black))"
		}
	}


	// Plot
	twoway `aplots' `cplots' `arrowplots', ///
			`twowayoptions' ///
			legend(position(`lpos') order(`"`legendorder'"'))
			// (pcarrowi 1.3 2006 1.2 2004 (12) "cohort 2002")
      
  restore
end

cap program drop auto_legend_position
program auto_legend_position, rclass
  syntax varlist(min=2) [if] [, ylabel(string) xlabel(string)]

  local nvars = 0
  foreach var of varlist `varlist' {
    local ++nvars
  }
  local nyvars = `nvars' - 1
  
  
  local xvar = ""
  local yvarlist = ""
  local k = 1
  foreach var of varlist `varlist' {
    if `k' <= `nyvars' local yvarlist = "`yvarlist' `var'"
    else local xvar = "`var'"
    local ++k
  }

  local ymin = 1e10
  local ymax = -1e10 
  local xmin = 1e10
  local xmax = -1e10 
  
  // y axis
  capture numlist "`ylabel'", ascending
  if _rc == 0 {
    foreach y of numlist `r(numlist)' {
      local ymin = min(`y', `ymin')
      local ymax = max(`y', `ymax')     
    }
  }
  else if _rc != 0 {
    foreach yvar of varlist `yvarlist' {
      qui sum `yvar'
      local ymin = min(r(min), `ymin')
      local ymax = max(r(max), `ymax')
    }
  }
  
  local ymid = (`ymin' + `ymax') / 2
  local ymid1 = `ymin' + (`ymax' - `ymin') / 3
  local ymid2 = `ymin' + (`ymax' - `ymin') * 2 / 3

  // x axis
  capture numlist "`xlabel'", ascending
  if _rc == 0 {
    foreach x of numlist `r(numlist)' {
      local xmin = min(`x', `xmin')
      local xmax = max(`x', `xmax')     
    }
  }
  else {
    qui sum `xvar'
    local xmin = r(min)
    local xmax = r(max) 
  }
  local xmid = (`xmin' + `xmax') / 2


  // number of points in each quadrant
  local measure_2 = 0
  local measure_3 = 0
  local measure_5 = 0
  local measure_7 = 0
  local measure_9 = 0
  local measure_11 = 0
  
  tempvar xdist ydist dist
  generate `xdist' = abs(`xvar' - `xmid')
  generate `ydist' = .
  generate `dist' = .

  foreach yvar of varlist `yvarlist' {
  
  disp "`yvar'"
    
    replace `ydist' = abs(`yvar' - `ymid') 
    replace `dist' = sqrt(`ydist'^2 + `xdist'^2)
    
    qui sum `dist' if `yvar' > `ymid2' & `xvar' > `xmid', meanonly
    if r(N) > 0    local measure_2 = `measure_2' + r(N) * r(mean)

    qui sum `dist' if `yvar' > `ymid1' & `yvar' <= `ymid2' & `xvar' > `xmid', meanonly
    if r(N) > 0    local measure_3 = `measure_3' + r(N) * r(mean)

    qui sum `dist' if `yvar' <= `ymid1' & `xvar' > `xmid', meanonly
    if r(N) > 0    local measure_5 = `measure_5' + r(N) * r(mean)
    
    qui sum `dist' if `yvar' <= `ymid1' & `xvar' < `xmid', meanonly
    if r(N) > 0    local measure_7 = `measure_7' + r(N) * r(mean)

    qui sum `dist' if `yvar' > `ymid1' & `yvar' <= `ymid2' & `xvar' < `xmid', meanonly
    if r(N) > 0    local measure_9 = `measure_9' + r(N) * r(mean)

    qui sum `dist' if `yvar' > `ymid2' & `xvar' < `xmid', meanonly
    if r(N) > 0    local measure_11 = `measure_11' + r(N) * r(mean)

  }

  local F_min = `measure_2'
  local legendpos = 2 // ne
  
  foreach p in 11 5 7 3 9 {
    if `measure_`p'' < `F_min' {
      local F_min = `measure_`p''
      local legendpos = `p'
    }
  }
  
  return scalar position = `legendpos'
    
end