// Load data
cap program drop load_csvdata
program load_csvdata
  syntax , filename(string asis) [dropsuffix(string) delim(string)]
  
  if "`delim'" == "" local delim = ","
  
  import delimited using `filename', clear delim("`delim'") case(preserve)
  
  if "`dropsuffix'" != "" {
    foreach var of varlist * {
      local nchar = strlen("`dropsuffix'")
      if substr("`var'", -`nchar', .) == "`dropsuffix'" {
        local newvar = subinstr("`var'", "`dropsuffix'", "", .)
        rename `var' `newvar'
      }
    }
  }

end

// Index data
cap program drop index_timeseries
program index_timeseries
  syntax varlist [, baseyear(int 2001) yearvar(string) by(varlist) method(string)]
  
  if "`yearvar'" == "" local yearvar = "year"
  
  assert inlist("`method'", "", "diff", "ratio", "logdiff") 
  if "`method'" == "" local method = "diff"
  
  if "`by'" == "" local byprefix = ""
  else            local byprefix = "bysort `by' (year):"
   
  tempvar base
  
  qui foreach var of varlist `varlist' {
    generate `base' = `var' if `yearvar' == `baseyear'
    `byprefix' ereplace `base' = min(`base')
    if "`method'" == "diff"    replace `var' = `var' - `base'
    else if "`method'" == "ratio"    replace `var' = `var' / `base' - 1
    else if "`method'" == "logdiff"    replace `var' = log(`var') - log(`base')
    drop `base'
  }
  
end

cap program drop add_statistics
program add_statistics
  generate p90p10 = p90 -p10
  generate p90p50 = p90 -p50
  generate p50p10 = p50 -p10
  generate sd256 = 2.56 * sd
  generate skewk = (p90 - 2*p50 + p10) / (p90 - p10)
  cap generate kurtcs = (p97_5 - p2_5) / (p75 - p25) -2.91
  if _rc {
    cap generate p97_5 = (p97+p98)/2
    cap generate p2_5 = (p2+p3)/2
    cap generate kurtcs = (p97_5 - p2_5) / (p75 - p25) -2.91
  }
  cap generate p97_5p2_5 = p97_5 -p2_5
  cap generate p75p25 = p75 - p25

end


cap program drop compute_incshares
program compute_incshares

  syntax , by(string) [nvar(string)]
  
  if "`nvar'" == "" local nvar = "sum_weights"
  
  // Income Shares
  bysort `by' (rank): gegen total = total(mean * `nvar')
  generate share = mean * `nvar' / total
  drop total

  // Quintiles
  gcollapse (sum) share_Q1 = share if rank < 20, by(`by') merge
  gcollapse (sum) share_Q2 = share if rank < 40 & rank >= 20, by(`by') merge
  gcollapse (sum) share_Q3 = share if rank < 60 & rank >= 40, by(`by') merge
  gcollapse (sum) share_Q4 = share if rank < 80 & rank >= 60, by(`by') merge
  gcollapse (sum) share_Q5 = share if rank < 100 & rank >= 80, by(`by') merge
  
  // Selected
  gcollapse (sum) share_bot50 = share if rank < 50, by(`by') merge
  gcollapse (sum) share_mid40 = share if rank >= 50 & rank < 90, by(`by') merge
  gcollapse (sum) share_bot90 = share if rank < 90, by(`by') merge
  gcollapse (sum) share_top10 = share if rank >= 90, by(`by') merge
  gcollapse (sum) share_top5 = share if rank >= 95, by(`by') merge
  gcollapse (sum) share_top1 = share if rank >= 99, by(`by') merge
  gcollapse (sum) share_top0_1 = share if rank >= 99.9, by(`by') merge
  gcollapse (sum) share_top0_01 = share if rank >= 99.99, by(`by') merge      
  
  // Collapse
  gcollapse (firstnm) share_*, by(`by') 

end
