cap program drop table_income_shares
program table_income_shares

  syntax using [, years(numlist ascending int) groups(string)]
    
  if "`years'" == ""    local years 2001/2016
  if "`groups'" == ""   local groups Q1 Q2 Q3 Q4 Q5 bot50 bot90 mid40 top10 top5 top1 top0_1 top0_01   
  
  // Tex-table
  //------------------------------------
  
  // Initiate tex-file
  cap file close table
  file open table `using', write replace

  local ngroups: word count `groups'
  local ncols = `ngroups' + 1

  // Begin tabular
  file write table "\begin{tabular}{l*{`=`ncols'-1'}{r}}" _n
  file write table "\toprule \toprule" _n
  
  // Header
  local coltitles = "Year"
  foreach group of local groups {
    local grouplabel = subinstr("`group'", "_", ".", .)
    local grouplabel = subinstr("`grouplabel'", "top", "Top ", .)
    local grouplabel = subinstr("`grouplabel'", "bot", "Bot ", .)
    local grouplabel = subinstr("`grouplabel'", "mid", "Mid ", .)
    local coltitles = "`coltitles' & \multicolumn{1}{c}{`grouplabel'}"
  }
  file write table "`coltitles' \\" _n
  file write table "\midrule" _n

  // Content
  qui foreach year of numlist `years' {
    local thisline = "`year'"
    foreach group of local groups {
      sum share_`group' if year == `year', meanonly
      local value = strofreal(`=`r(mean)'*100', "%9.2f")
      local thisline = "`thisline' & `value'"
    }
    file write table "`thisline' \\" _n
  }

  // End tabular
  file write table "\bottomrule" _n
  file write table "\end{tabular}" _n

  // Close tex-file
  file close table

      
end



cap program drop table_changes_summary
program table_changes_summary

  syntax using [, years(numlist ascending int) groups(string)]
    
  if "`years'" == ""    local years 2001/2016
  if "`groups'" == ""   local groups Q1 Q2 Q3 Q4 Q5 bot50 bot90 mid40 top10 top5 top1 top0_1 top0_01   
  
  // Tex-table
  //------------------------------------
  
  // Initiate tex-file
  cap file close table
  file open table `using', write replace

  local ngroups: word count `groups'
  local ncols = `ngroups' + 1

  // Begin tabular
  file write table "\begin{tabular}{l*{`=`ncols'-1'}{r}}" _n
  file write table "\toprule \toprule" _n
  
  // Header
  local coltitles = "Year"
  foreach group of local groups {
    local grouplabel = subinstr("`group'", "_", ".", .)
    local grouplabel = subinstr("`grouplabel'", "top", "Top", .)
    local grouplabel = subinstr("`grouplabel'", "bot", "Bot", .)
    local grouplabel = subinstr("`grouplabel'", "mid", "Mid", .)
    local coltitles = "`coltitles' & \multicolumn{1}{c}{`grouplabel'}"
  }
  file write table "`coltitles' \\" _n
  file write table "\midrule" _n

  // Content
  qui foreach year of numlist `years' {
    local thisline = "`year'"
    foreach group of local groups {
      sum share_`group' if year == `year', meanonly
      local value = strofreal(`=`r(mean)'*100', "%9.2f")
      local thisline = "`thisline' & `value'"
    }
    file write table "`thisline' \\" _n
  }

  // End tabular
  file write table "\bottomrule" _n
  file write table "\end{tabular}" _n

  // Close tex-file
  file close table

      
end

