*! v20211219 hw, fix weight bug (mdg, 20220103)
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This program generates the base sample 
// This version Dec 01, 2020
// Serdar Ozkan and Sergio Salgado
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

clear
set more off

// PLEASE MAKE THE APPROPRIATE CHANGES BELOW. 
// You should change the below directory. 
if "${curr_user}"=="IAB" global maindir="${root}"+"${sep}"
do "${maindir}/do/0_Initialize.do"

global logname="${mydate}"
global logname="$logname BaseSample"+" - "+"${vsample}${rvl}"
capture log close
capture noisily log using "${maindir}${sep}log${sep}$logname.log", replace

cd "${maindir}${sep}dta${sep}"
*	
if($wide==1){
	use $personid_var $male_var $yob_var $yod_var $educ_var ${labor_var}* using ${datafile}
	order  ${labor}*, alphabetic
	keep $personid_var $male_var $yob_var $yod_var $educ_var  ${labor_var}${yrfirst}-${labor_var}${yrlast}
	order $personid_var $male_var $yob_var $yod_var $educ_var  ${labor_var}*
	describe
}
else{
	use $personid_var $male_var $yob_var $yod_var $educ_var $year_var $labor_var $weight_var ///
		if ${year_var} >= ${yrfirst} & ${year_var} <= ${yrlast} using ${datafile}
	describe
	tab ${year_var}
	/*  The default STATA reshape commend is slow! 
	timer clear 1
	timer on 1
	sort $personid_var $year_var
	reshape wide $labor_var, i($personid_var) j($year_var)
	timer off 1
	timer list 1
	*/
	// The below part reshapes data in long format to wide. Faster than RESHAPE commend. 
	sort $personid_var $year_var
	forvalues yr = $yrfirst/$yrlast{
		preserve
		keep if $year_var ==`yr'
		
		rename $labor_var $labor_var`yr'
		rename $weight_var ${weight_var}`yr' //!mdg
		
		keep $personid_var $labor_var`yr' $male_var $yob_var $yod_var $educ_var ${weight_var}`yr'		
			// Need to keep all variable. If only keep for first year, we 
			// miss the data for observations that enter in the sample after 
			// the first year. 
		
		sort $personid_var
		save "temp`yr'.dta",replace
		restore
	}
	
	local first=$yrfirst+1
	use "temp$yrfirst.dta", clear
	erase temp${yrfirst}.dta
	forvalues yr=`first'/$yrlast{
		merge 1:1 $personid_var using "temp`yr'.dta", nogen update replace
				// update replace makes sure the variables such as year of birth 
				// are replaced by noin missing values for observations that enter 
				// in the sample after the first year. 
		erase temp`yr'.dta
		sort $personid_var
	}
	
	order $personid_var $male_var $yob_var $yod_var $educ_var ${labor_var}*
}

rename $personid_var personid
rename $male_var male
rename $yob_var yob
rename $yod_var yod
rename $educ_var educ


// Drop anybody who is too old or too young or too dead. 
// Criteria 1 (Age) in CS Sample
drop if yob==.
drop if $yrfirst-yob+1>$end_age | $yrlast-yob+1<$begin_age 
drop if yod<=$yrfirst & yod~=.
describe

global base_price_index = ${base_price}-${yrfirst}+1	// The base year nominal values are converted to real. 

forvalues yr = $yrfirst/$yrlast{

	rename ${labor_var}`yr' labor`yr'
	
	label var labor`yr' "Real labor earnings in `yr'"

	// Covert to real values
	// Criteria d (Inflation) in CS Sample
	
	local cpi_index = `yr'-${yrfirst}+1
	replace labor`yr'=labor`yr'/cpimat[`cpi_index',1]		//Coverting to real values

	// Winsorization
	gen temp=labor`yr' if `yr'-yob+1>= $begin_age & `yr'- yob+1<= $end_age & `yr'< yod  // yod=. id very big number  
	
	gen weight=${weight_var}`yr'									// !hw bugfix of mdg file
	_pctile temp $weights, p($winsor)
	replace labor`yr'= r(r1) if labor`yr'>=r(r1) & labor`yr'!=. 
	drop temp weight												// !hw bugfix of mdg file
	
	// Add a small noise
	gen temp=${noise}*(uniform()-0.5)
	replace labor`yr'=labor`yr'+labor`yr'*temp 
	drop temp

	if(${miss_earn}==0){
	// Any earnings that are missing inside of $begin_age and $end_age are set to zero.
	replace labor`yr'= 0 if labor`yr'== . &  ///
	   `yr'-yob+1 >= $begin_age & `yr'- yob+1<=$end_age & `yr'< yod
	}
		
	// Assing missing if outside of $begin_age and $end_age
	replace labor`yr'= . if `yr'-yob+1 < $begin_age | `yr'- yob+1>$end_age 
	replace labor`yr'= . if `yr'>= yod & yod~=.  // (yod=. is very big number)
	
}

// Base sample creation completed.
order personid male yob yod educ labor*

save "${maindir}${sep}dta${sep}base_sample.dta", replace

/* !hw: Outcomment here the previous attempt to replicate the graph?! 								//!hw ->

use "${maindir}${sep}dta${sep}base_sample.dta", clear
reshape long labor, i(personid) j(year)

gen logearn = log(labor) if labor>=6000 & labor~=.
drop if labor ==.
 cellgraph logearn , by(year) stat(p5 p10 p25 p50 p75 p90) baseline(1993) name("GID")
graph export "${maindir}\log\2020_12_22\Sample_1_LongTimeSeries_NoMini\pctiles_lrearn_imp_gid.pdf", as(pdf) name("GID") replace
*/ 																									//!hw <-

																
// Creating log-earnings and saving the coefficients

cd "${maindir}${sep}dta${sep}"

forvalues yr = $yrfirst/$yrlast{	
	use personid male yob educ labor`yr' ${weight_var}`yr' using ///
	"${maindir}${sep}dta${sep}base_sample.dta" if labor`yr'~=. , clear   

	// Create year
	gen year=`yr'
	
	// Create age 
	gen age = `yr'-yob+1
	drop if age<${begin_age} | age>${end_age}
	
	// Create log earn if earnings above the min treshold
	// Criteria c (Trimming) in CS Sample
	// Notice we do not drop the observations but log-earnings are generated for those with
	// income below 1/3*min threshold. Variable logearn`yr'c is used for growth rates conditional
	// on permanent income only
	
	gen logearn`yr' = log(labor`yr') if labor`yr'>=rmininc[`yr'-${yrfirst}+1,1] & labor`yr'!=. 
	label var logearn`yr' "Real log-labor earnings of year `yr' above min threshold"

	drop if logearn`yr' == .

	
	// Save data set for later append
	preserve
		keep personid logearn`yr' labor`yr' male yob ${weight_var}`yr'
		sort personid
		save "researn`yr'.dta", replace
	restore 
	
}

forvalues yr = $yrfirst/$yrlast{
	if (`yr' == $yrfirst){
		use researn`yr'.dta, clear
		erase researn`yr'.dta
	}
	else{
		merge 1:1 personid using researn`yr'.dta, nogen
		erase researn`yr'.dta
	}
	sort personid
}
save "researn.dta", replace 


// END: Residuals calculation complete


/* !mdg
  Remove unnecessary part of data prep as we only need the logearn variable
*/

// Merge all data sets to a master code

use "${maindir}${sep}dta${sep}base_sample.dta", clear 
merge 1:1 personid using "researn.dta", nogen 

order  personid male yob yod educ labor* logearn*
save "${maindir}${sep}dta${sep}master_sample.dta", replace 

capture log close

// END OF DO-FILE
//////////////////////////////////////////////
