*! v20211219 hw
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This program generates the time series of concetration and inequality
// This version Dec 01, 2020
// Serdar Ozkan and Sergio Salgado
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

clear all
set more off
set type double
 
// You should change the below directory. 

if "${curr_user}"=="IAB" global maindir="${root}"+"${sep}" 										//!hw

// Do not make change from here on. Contact Ozkan/Salgado if changes are needed. 
do "$maindir/do/0_Initialize.do"

// Create folder for output and log-file
global outfolder="${mydate}" 																	//!hw
global outfolder="$outfolder Inequality"+" - "+"${vsample}"+"${rvl}" 							//!hw
capture noisily mkdir "$maindir${sep}out${sep}$outfolder"
capture log close
capture noisily log using "$maindir${sep}log${sep}$outfolder.log", replace

// Cd to the output file, create the program for moments, and load base sample.
cd "$maindir${sep}out${sep}$outfolder"
do "$maindir${sep}do${sep}myprogs.do"		

// Defines the number of points in the Kernel Density Estimator
global kpoints =  400

// Loop over the years
timer clear 1
timer on 1

foreach yr of numlist $yrlist{
	disp("Working in year `yr'")
// 	local yr = 2000			// For checking bugs

	// Load data 
  use  male yob educ labor`yr' logearn`yr' ${weight_var}`yr' using /// !mdg
  "$maindir${sep}dta${sep}master_sample.dta" if labor`yr'~=. , clear   

	// Create year
	gen year=`yr'
	
	// Create age and restrict to CS sample
	gen age = `yr'-yob+1
	qui: drop if age<${begin_age} | age>${end_age}
	
	// Create the alternative age/cohort for plots
	qui: sum yob
	local minyob = r(min) 		
	gen yob2 = yob + mod(`minyob',${mergecohort}) - mod(yob,${mergecohort})
	
	gen agealt = `yr'-yob2+1
	qui: drop if agealt<${begin_age} | agealt>${end_age}
	
	// Drop if log earnings does not exist
	qui: drop if logearn`yr'==.																		//!hw
	
	// Gen earnings adjusted by the real min income
	gen earn = labor`yr' if labor`yr'>=rmininc[`yr'-${yrfirst}+1,1]
	
	// Age group 
	gen agegp = . 
	replace agegp = 1 if age <= 34 & agegp == .
	replace agegp = 2 if age <= 44 & agegp == .
	replace agegp = 3 if age <= 55 & agegp == .

	
	// A1. Moments of log earnings
	// Calculate cross sectional moments for year `yr'
	rename labor`yr' labor 																		//!hw
	rename logearn`yr' logearn 																//!hw
	rename ${weight_var}`yr' ${weight_var}										//!mdg
	
	bymysum_w "logearn" "L_" "_`yr'" "year"
	
	bymyPCT_w "logearn" "L_" "_`yr'" "year"
	
	// Calculate cross sectional moments for year `yr' within heterogeneity groups
	foreach  vv in male { 
		local suf=subinstr("`vv'"," ","",.)
		
		bymysum_w "logearn" "L_" "_`suf'`yr'" "year `vv'"
	
		bymyPCT_w "logearn" "L_" "_`suf'`yr'" "year `vv'"
	}
		
} // END of loop over years



// Collect data across years 
clear

foreach vari in logearn  {

foreach yr of numlist $yrlist{

	use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`yr'.dta", clear
	merge 1:1 year using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`yr'.dta", ///
		nogenerate
	erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`yr'.dta"
	erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`yr'.dta"
	
	save "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta", replace
}
clear 
foreach yr of numlist $yrlist{
	
	append using "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta"
	erase "$maindir${sep}out${sep}$outfolder/L_`vari'_`yr'.dta"	

}

outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_sumstat.csv", replace comma nol 		//!hw: added nol

// Collect data across all years and heterogeneity groups. saves one output file per group 
foreach  vv in male {

	clear 
	local suf=subinstr("`vv'"," ","",.)
	foreach yr of numlist $yrlist{
		
		use "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`suf'`yr'.dta", clear
		merge 1:1 year `vv' using "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`suf'`yr'.dta", ///
			nogenerate	
			
		erase "$maindir${sep}out${sep}$outfolder/S_L_`vari'_`suf'`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/PC_L_`vari'_`suf'`yr'.dta"
		
		save "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta", replace
	}	
	clear 
	foreach yr of numlist $yrlist{
		append using "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta"
		erase "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'`yr'.dta"
	}
	
	outsheet using "$maindir${sep}out${sep}$outfolder/L_`vari'_`suf'_sumstat.csv", replace comma nol 		//!hw: added nol 		
} 	// END loop over heterogeneity group


}	// END loop over variables 


	

timer off 1
timer list 1

*END OF THE CODE 
