*! v20211219 hw
********************************************************************************
* This program generates the core figures for the draft						   *
* This version January 11, 2020												   *
* Serdar Ozkan and Sergio Salgado											   *
********************************************************************************
*------------------------------------------------------------------------------*

*** Preamble
{

* clear 
clear
set more off

* set dirs dep on user
if "${curr_user}"=="IAB" { 															
	global maindir ="${root}"+"${sep}"
}
else{
	global maindir ="/Users/johannes/Dropbox/Research/Global_Income_Dynamics/Stata"
} 						 																

	global filedate="$mydate" //set to current date
	local i=1
	local filesearch = "${maindir}"+"\out\"+"${filedate}"+" Inequality"+" - "+"${vsample}"+"${rvl}"
	cap cd "`filesearch'"
	while _rc {
		global filedate: display %tdCY-N-D date("`c(current_date)'", "DMY") - `i'
		global filedate=strltrim("$filedate")
		local i=`i'+1
		local filesearch = "${maindir}out/${filedate} Inequality - ${vsample}${rvl}"
		cap cd "`filesearch'"
	}
global ineqdata = "${maindir}"+"\out\"+"${filedate}"+" Inequality"+" - "+"${vsample}"+"${rvl}"	


* Where the firgures are going to be saved 
global outfolder="${mydate}"+"_"+"${vsample}"+"${rvl}"
capture noisily mkdir "$maindir${sep}figs${sep}${outfolder}"
global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"
capture noisily mkdir "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"	

* Read initialize and plotting code. Do not change myplots.do
do "$maindir/do/0_Initialize.do"
do "$maindir${sep}do${sep}myplots.do"		

* Define these variables for your dataset
global yrfirst = ${yrsample} 	// First year in the dataset 
global yrlast =  2018 		// Last year in the dataset

* Define some common charactristics of the plots 
qui do "${do}/myplotsettings.do"

* change working dir to folder with out 
cd "$maindir${sep}" // Cd to the folder containing the files
	
// Which section are we ploting 
	global figineq =  "yes"			// Inequality
	global figcoh =   "no"			// Cohorts and initial inequality
	global figvol =   "no"			// Volatility
	global figquan =  "no"			// Income growth heterogeneity 
	global figmob =   "no"			// Mobility
	global figtail =  "no"			// Tail 
	global figcon =   "no"			// Concentration 
	global figden =   "no"			// Density Plots

// timeframe selectio to replace the original/initial points in time, depending on short/long sample
if "$vsample"=="short_rw" {							
	global gr_yr1=2005
	global gr_yr2=2010
	global gr_yr3=2008
	global gr_yr4=2015
	global gr_yr5=2003 //mob T+10 t1
	global gr_yr6=2008 //mob T+10 t2
	global gr_yr7=2003 //mob T+5  t1
	global gr_yr8=2009 //mob T+5  t1
} 
else if "$vsample"=="long_rw" {
	global gr_yr1=1995
	global gr_yr2=2005
	global gr_yr3=2005
	global gr_yr4=2015
	global gr_yr5=1995 //mob T+10 t1
	global gr_yr6=2000 //mob T+10 t2
	global gr_yr9=2005 //mob T+10 t3
	global gr_yr7=1995 //mob T+5  t1
	global gr_yr8=2005 //mob T+5  t2			
} 
}

*------------------------------------------------------------------------------*
	
//===================================================//	
//--- Inequality
//===================================================//

if "${figineq}" == "yes"{ 	

// PLOTS OF LOG EARN: The limints need to change for each variable; Better seperate them
foreach subgp in fem male all {	
	
	*For residual-education earnings we are only ploting the aggregated results
	if 	"`subgp'" == "all"{
		local wlist = "logearn"			
	}	
	else {
		local wlist = "logearn"	
	}
	
	*Start main loop over variables
	foreach var of local wlist {
	
	*Which variable will be ploted
	global vari = "`var'"						 
	
	*What is the group under analysis? 
	*You can add more groups to this section 
	if "`subgp'" == "all"{
		insheet using "${ineqdata}/L_`var'_sumstat.csv", clear									//!hw
		local labname = "All"
	}
	if "`subgp'" == "male"{
		insheet using "${ineqdata}/L_`var'_male_sumstat.csv", clear							//!hw
		keep if male == 1	// Keep the group we want to plot 
		local labname = "Men"
	}
	
	if "`subgp'" == "fem"{
	    insheet using "${ineqdata}/L_`var'_male_sumstat.csv", clear							//!hw
		keep if male == 0	// Keep the group we want to plot 
		local labname = "Women"
	}
	
	*What is the label for title 
	if "${vari}" == "logearn"{
		local labtitle = "Log Earnings"
// 		local labtitle = "log y{sub:it}"
	}
	if "${vari}" == "researn" | "${vari}" == "researne"{
		local labtitle = "Residual Log Earnings"
// 		local labtitle = "{&epsilon}{sub:it}"
	}

	*What are the x-axis limits
	local lyear = ${yrfirst}
	local ryear = ${yrlast}
	
	*Normalize Percentiles 
	gen var${vari} = sd${vari}^2
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9901${vari} = p99${vari} - p1${vari}
	gen p99901${vari} = p99_9${vari} - p1${vari}
	gen p999901${vari} = p99_99${vari} - p1${vari}
	
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p999_p99${vari} = p99_9${vari} - p99${vari}
	gen p9999_p999${vari} = p99_99${vari} - p99_9${vari}
		
	gen p9505${vari} = p95${vari} - p5${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	
	*Rescale by first year 
	foreach vv in sd$vari  var$vari p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
		p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
		p97_5$vari p99$vari p99_9$vari p99_99$vari p9010$vari  p9901$vari  p9505$vari p9050${vari} p5010${vari} ksk${vari} ///
		p99901${vari} p999901${vari} p9990${vari} p999_p99${vari} p9999_p999${vari}{
		sum  `vv' if year == `lyear', meanonly
		gen n`vv' = `vv' - r(mean)
		}
	
	*Generate recession vars
	gen rece = inlist(year,${receyears})
	
	*Rescale standard deviation for plots
	replace sd${vari} = 2.56*sd${vari}

	// Keep selected years
	keep if year>=${yrfirst} & year<=${yrlast}	
	
**********************************************
//--- Figure 1 (percentiles) ---//

	local colors blue green red navy black
	local fcolors = ""
	foreach co of local colors {
		local fcolors = "`fcolors'" + " " + "`co'*0.25"
	}

*** Figure 1A: normalized percentiles
	if "${vari}"=="logearn" local yrange="range(-0.25 0.2)"
	if "${vari}"=="researn" local yrange="range(-0.15 0.1)"
	twoway (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
	       (connected np90${vari} np75${vari} np50${vari} np25${vari} np10${vari} year, ///
    			lcolor(`colors')  /// Line colors
    			lpattern(solid longdash dash dash_dot solid) ///
    			msymbol(O + S X D) /// Markers
    			mlcolor(`colors')  /// Marker  line color
                mfcolor(`fcolors')  ///	Fill color
    			yaxis(2)  yscale(alt axis(2) `yrange') ///
                ytitle("Percentiles Relative to `lyear'", axis(2)) ///
                ylabel(#6, axis(2))),  ///
    	xtitle("") ///
        xlabel(2000(3)2018, grid) ///
    	legend(position(11) order(2 "p90" 3 "p75" 4 "p50" 5 "p25" 6 "p10"))
  cap noisily: graph export "${folderfile}/fig1A_`subgp'_${vari}.${formatfile}", replace

*** Figure 1B: normalized top percentiles 
	twoway (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
	       (connected np99_99${vari} np99_9${vari} np99${vari} np95${vari} np90${vari} year, ///
    			lcolor(`colors')  /// Line colors
    			lpattern(solid longdash dash dash_dot solid) ///
    			msymbol(O + S X D) /// Markers
    			mlcolor(`colors')  /// Marker  line color
                mfcolor(`fcolors')  ///	Fill color
    			yaxis(2)  yscale(alt axis(2) range(-0.2 0.3)) ///
                ytitle("Percentiles Relative to `lyear'", axis(2)) ///
                ylabel(#6, axis(2)) ///
            ),  ///
    	xtitle("") ///
        xlabel(2000(3)2018, grid) ///		xaxis options
    	legend(position(11) order(2 "p99.99" 3 "p99.9" 4 "p99" 5 "p95" 6 "p90"))
  cap noisily: graph export "${folderfile}/fig1B_`subgp'_${vari}.${formatfile}", replace

  
********************************************** 
//--- Figure 2 (Inequality) ---//  

	local colors blue red
	local fcolors = ""
	foreach co of local colors {
		local fcolors = "`fcolors'" + " " + "`co'*0.25"
	}
	
*** Figure 2A: std. dev. and P90-P10
	if "${vari}"=="logearn" local yrange="range(1.3 2.4)"
	if "${vari}"=="researn" local yrange="range(1.1 2.4)"
	twoway (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
	       (connected sd${vari} p9010${vari} year, ///
    			lcolor(`colors')  /// Line colors
    			lpattern(solid longdash) ///
    			msymbol(O S) /// Markers
    			mlcolor(`colors')  /// Marker  line color
                mfcolor(`fcolors')  ///	Fill color
    			yaxis(2)  yscale(alt axis(2) `yrange') ///
                ytitle("Dispersion of `labtitle'", axis(2)) ///
                ylabel(#6, axis(2)) ///
            ),  ///
    	xtitle("") ///
        xlabel(2000(3)2018, grid) ///		xaxis options
    	legend(position(7) order(2 "2.56*{&sigma}" 3 "P90-P10"))
  cap noisily: graph export "${folderfile}/fig2A_`subgp'_${vari}.${formatfile}", replace

*** Figure 2B: P90-P50 and P50-P10
	if "${vari}"=="logearn" local yrange="range(0.6 1.6)"
	if "${vari}"=="researn" local yrange="range(0.55 1.6)"
	local legpos=11
	if "`subgp'"=="fem" local legpos=5
	twoway (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
	       (connected p9050${vari} p5010${vari} year, ///
    			lcolor(`colors')  /// Line colors
    			lpattern(solid longdash) ///
    			msymbol(O S) /// Markers
    			mlcolor(`colors')  /// Marker  line color
                mfcolor(`fcolors')  ///	Fill color
    			yaxis(2)  yscale(alt axis(2) `yrange') ///
                ytitle("Dispersion of `labtitle'", axis(2)) ///
                ylabel(#6, axis(2)) ///
            ),  ///
    	xtitle("") ///
        xlabel(2000(3)2018, grid) ///		xaxis options
    	legend(position(`legpos') order(2 "P90-P50" 3 "P50-P10"))
    cap noisily: graph export "${folderfile}/fig2B_`subgp'_${vari}.${formatfile}", replace

}	// END of loop over subgroups
}	// END loop over variables
}	// END of inequality section
	
*------------------------------------------------------------------------------*

*END OF THE CODE
