*! v20220525 hw
/*---------------------------------------------------------*/
*! Researchproject: Inequality and Inceom Dynamics in Germany (GRID project)
*! Author: Johannes F. Schmieder / Hannes Walz
/*---------------------------------------------------------*/


// =============== Preamble ================ //

{
//--- Settings ---//

* clearing
clear all
program drop _all
macro drop _all
cap log close _all
clear matrix

* set
version 16.1
set more off, perm
set varabbrev off, perm
set matsize 10000, perm
set maxiter 1000, perm
set iterlog on, perm
set linesize 255
set pagesize 100
set rmsg off, perm
set trace on
set tracedepth 2
set traceexpand off, perm
set tracesep off, perm
set traceindent off, perm
set tracenumber off, perm    

* date
global mydate: di %td_CY-N-D date("$S_DATE", "DMY")
global mydate=strltrim("$mydate")

* seed
set seed 190424


//--- paths ---//

* checks
pwd 
sysdir

* paths
global root     = "...\" 	 				// !!! change main dir path here !!!
	global do     = "${root}`c(dirsep)'do`c(dirsep)'"
	global data     = "${root}`c(dirsep)'dta`c(dirsep)'"
	global log      = "${root}`c(dirsep)'log`c(dirsep)'"
	global orig     = "${root}`c(dirsep)'orig`c(dirsep)'"
	global figs     = "${root}`c(dirsep)'figs`c(dirsep)'"
	global out      = "${root}`c(dirsep)'out`c(dirsep)'"	
foreach dir in "log" "data" "figs" "out" {
	cap mkdir "$`dir'"
}
cd "${root}"

* main log path
global mainlog "${log}${mydate}"
cap mkdir "${log}${mydate}"

* set project ado dir
adopath ++ "${do}/"

*check ado paths
adopath
}

/*===========================================================================================*/
/*                                      Main Program                                         */
/*===========================================================================================*/
capture program drop main
program define main
	set matsize 4000
	set li 120 // 200
	set trace on
	set tracesep off
	set tracedepth 1 //2
  
	local time = subinstr("`=c(current_time)'",":","",.)
	scalar d = date("`=c(current_date)'","DMY") 	// create log file including time and date in file name
	local b  _`=subinstr("`c(current_date)'"," ","",.)'_`time'
	global logfile ${mainlog}/${mydate}_GRID_Germany_reweighting.log
	log using $logfile , text replace name(reweighting_`b')
	
	
	// =====================================
    // Reweighted IAB Core Analysis
    // =====================================

	*** calculate weights for reweighting   
	* single reweights
	reweighting2, in(clean_yearly_data) yearfirst(2001) rwvl(2) 
	reweighting2, in(clean_yearly_data) yearfirst(2001) rwvl(3)  
	reweighting2, in(clean_yearly_data) yearfirst(2001) rwvl(5) 
	reweighting2, in(clean_yearly_data) yearfirst(2001) rwvl(6) 
	reweighting2, in(clean_yearly_data) yearfirst(2001) rwvl(7) 	
	
	*** analysis   
	*single reweights
	reweighted_analysis, vs(short) dfopt(data) rwvl(1) womj(0)
	reweighted_analysis, vs(short) dfopt(data) rwvl(2) womj(0)
	reweighted_analysis, vs(short) dfopt(data) rwvl(3) womj(0)
	reweighted_analysis, vs(short) dfopt(data) rwvl(5) womj(0)
	reweighted_analysis, vs(short) dfopt(data) rwvl(6) womj(0)
	reweighted_analysis, vs(short) dfopt(data) rwvl(7) womj(0)
	
	** weighting var meta graphs
	pre_reweighted_analysis_meta, vs(short) dfopt(data) rvl(0)
	
	
	cap log reweighting_`b'

end // main program

/*===========================================================================================*/
/*                                   Main Programs                                           */
/*===========================================================================================*/

/*-------------------------------------------------------*/
/* Reweighting 2  */
/*-------------------------------------------------------*/
capture program drop reweighting2
program define reweighting2 /* options: in(str) [yearfirst(int 2001) rwvl(int 1)] */
	syntax, in(str) [yearfirst(int 2001) rwvl(int 1)]

	* Matching variables:
	local weightvarlist2 = "jobtype2" //FT/PT/MJ
	local weightvarlist3 = "days_work_c" //working days this year
	local weightvarlist5 = "educ4" //working days last year
	local weightvarlist5b = "educ2" //working days last year
	local weightvarlist6 = "age3y" //working days last 3 years
	local weightvarlist7 = "nonger" //working days last 5 years

	local rvl=`rwvl'
	if `rwvl'==5 local rvl=5b
	
	* for single match vars
	if (`rwvl'<=9){
		local weightvarlist = "`weightvarlist`rvl''"
	}
	* for several vars
	if (`rwvl'>9) { 
		local numList=`rwvl'
		local weightvarlist=""
		forval i=1/10 {
			local j=10-`i'
			di (10^`j')
			local num=(floor(`numList'/(10^`j')))
			if (`num'>0) {
				local weightvarlist="`weightvarlist'"+" "+"`weightvarlist`num''"
				local numList = `numList'-(`num' * (10^`j'))
				di `num'
				di `numList'
			}
		}
	}

	// Year to which we want to reweight:
	local baselineyear = `yearfirst'
	local lastyear = 2018
	
	* create frame
	frame create reweight`rvl'
	frame reweight`rvl' {

	*** calculating weights
	//get data set
	use persid year male `weightvarlist' ///
		using "${data}/`in'"
	
	* group by weight variables
	//foreach var in `weightvarlist' {
	//	drop if missing(`var')
	//}
	egen grouping=group(`weightvarlist')	
	save "${data}/temp_rw", replace
	
	//get baselineyear
	keep if year==`baselineyear'
	collapse (count) N = persid (mean) `weightvarlist' year, by(male grouping)
	save "${data}/temp_rw_bly", replace
	clear
	
	//loop over years
	forval g=0/1 {
		forval yr ==`=`baselineyear'+1'/`lastyear' {
			local lag=`yr'-`baselineyear'
			use persid year male grouping `weightvarlist' ///
				if year==`yr' & male==`g' ///
				using "${data}/temp_rw" 
				
			//collapse sample
			collapse (count) N = persid (mean) `weightvarlist' year, by(grouping)				
			gen male=`g'
			count
			append using "${data}/temp_rw_bly"
			count
			drop if male!=`g'
			count

			//gen weight 
			xtset grouping year
			gen weight`rvl' = year==`baselineyear'
			replace weight`rvl'= L`lag'.N/N if year==`yr'
			xtset, clear
			drop grouping
			bysort year `weightvarlist': keep if _n==1
			drop if year==`baselineyear' & `yr'>(`baselineyear'+1)
			save "${data}/reweights_y`yr'_m`g'_`rvl'", replace
			clear
		}
	}
	* merge weight data
	//loop over years
	use "${data}/reweights_y`=`baselineyear'+1'_m0_`rvl'", clear
	append using "${data}/reweights_y`=`baselineyear'+1'_m1_`rvl'"
	forval yr ==`=`baselineyear'+2'/`lastyear' {
		append using "${data}/reweights_y`yr'_m0_`rvl'" "${data}/reweights_y`yr'_m1_`rvl'"
	}
	
	* save and drop frame
	bysort year male `weightvarlist': keep if _n==1
	save "${data}/reweights_rvl`rvl'_`in'", replace
	
	* erase partial data sets
	erase "${data}/temp_rw.dta"
	erase "${data}/temp_rw_bly.dta"
	forval yr ==`=`baselineyear'+1'/`lastyear' {	
		erase "${data}/reweights_y`yr'_m0_`rvl'.dta"
		erase "${data}/reweights_y`yr'_m1_`rvl'.dta"
	}
	
	* close frame
	}
	frame drop reweight`rvl'	
	
end // reweighting2

/*-------------------------------------------------------*/
/* Reweighted Analysis  */
/*-------------------------------------------------------*/
capture program drop reweighted_analysis
program define reweighted_analysis /* options: vs(str) dfopt(str) [rwvl(int 1) womj(int 0)] */
	syntax, vs(str) dfopt(str) [rwvl(int 1) womj(int 0)]
	
	local rvl=`rwvl'
	if `rwvl'==5 local rvl=5b
	
//--- init ---//	
	
	global vsample="`vs'"			
	if "${vsample}"=="short" global yrsample=2001
	if "${vsample}"=="long" global yrsample=1993
	if "${vsample}"=="siab" global yrsample=1975
	global rvl="`rwvl'"

	
//--- matching varibles for weigh definition ---//
	
	* Matching variables:
	local weightvarlist2 = "jobtype2" //FT/PT/MJ
	local weightvarlist3 = "days_work_c" //working days this year
	local weightvarlist5 = "educ4" //working days last 2 years
	local weightvarlist5b = "educ2" //working days last year
	local weightvarlist6 = "age3y" //working days last 3 years
	local weightvarlist7 = "nonger" //working days last 5 years
	
	* for single match vars
	if (`rwvl'<=9){
		local weightvarlist = "`weightvarlist`rvl''"
	}
	* for several vars
	if (`rwvl'>9) { 
		local numList=`rwvl'
		local weightvarlist=""
		forval i=1/10 {
			local j=10-`i'
			di (10^`j')
			local num=(floor(`numList'/(10^`j')))
			if (`num'>0) {
				local weightvarlist="`weightvarlist'"+" "+"`weightvarlist`num''"
				local numList = `numList'-(`num' * (10^`j'))
				di `num'
				di `numList'
			}
		}
	}
	
//--- load data and merge weights ---//
	
	cap confirm "${data}/clean_yearly_`dfopt'_rw${rvl}"
	if _rc {
		use "${data}/clean_yearly_`dfopt'", clear
	
		replace age=year-byear+1
		keep if ag>=25 & age<=55
		cap drop weights 
		cap drop weight
		cap drop _merge
		merge m:1 male year `weightvarlist' using "${data}/reweights_rvl`rvl'_clean_yearly_`dfopt'"
		rename weight`rvl' weight
		drop _merge
		drop if persid==.
		
		save "${data}/clean_yearly_`dfopt'_rw${rvl}", replace	
	}
	else {
		use "${data}/clean_yearly_`dfopt'_rw${rvl}", clear
	}
	
//--- meta graphs for reweighting ---//

	cap mkdir "${figs}/${mydate} reweight meta/"
	
	foreach var in `weightvarlist' {
		// Compare distribution of matching variables with and without reweighting:
		tabstat `var' if male==0, by(year) stat(mean sd var)
		tabstat `var' if male==1, by(year) stat(mean sd var)
		// with reweighting these should stay approx constant over time.
		tabstat `var' if male==0 [aweight=weight], by(year) stat(mean sd var)
		tabstat `var' if male==1 [aweight=weight], by(year) stat(mean sd var)

		cellgraph `var' if male==0 & year>=2001, by(year) title(`var' (in `rvl') - female, unweighted)
		graph export "${figs}/${mydate} reweight meta/`var'_unweighted_m0_rvl`rvl'.pdf", replace as(pdf)
		graph save "${figs}/${mydate} reweight meta/`var'_unweighted_m0_rvl`rvl'", replace 
		cellgraph `var' if male==1 & year>=2001, by(year) title(`var' (in `rvl') - male, unweighted)
		graph export "${figs}/${mydate} reweight meta/`var'_unweighted_m1_rvl`rvl'.pdf", replace as(pdf)
		graph save "${figs}/${mydate} reweight meta/`var'_unweighted_m1_rvl`rvl'", replace 
		cellgraph `var' if male==0 & year>=2001 [aw=weight], by(year) title(`var' (in `rvl') - female, weighted)
		graph export "${figs}/${mydate} reweight meta/`var'_weighted_m0_rvl`rvl'.pdf", replace as(pdf)
		graph save "${figs}/${mydate} reweight meta/`var'_weighted_m0_rvl`rvl'", replace 
		cellgraph `var' if male==1 & year>=2001 [aw=weight], by(year) title(`var' (in `rvl') - female, weighted)
		graph export "${figs}/${mydate} reweight meta/`var'_weighted_m1_rvl`rvl'.pdf", replace as(pdf)
		graph save "${figs}/${mydate} reweight meta/`var'_weighted_m1_rvl`rvl'", replace 
		
	}
	
	* log earn variance
	// Now we can compare distribution of outcome variables with and without reweighting:
	tabstat lrearn_all_imputed if male==0 , by(year) stat(mean sd var)
	tabstat lrearn_all_imputed if male==1 , by(year) stat(mean sd var)
	// with reweighting these should stay approx constant over time since in the DGP
	// the variance only increases because of edyrs
	tabstat lrearn_all_imputed if male==0 [aweight=weight], by(year) stat(mean sd var)
	tabstat lrearn_all_imputed if male==1 [aweight=weight], by(year) stat(mean sd var)
	
	cellgraph lrearn_all_imputed if male==0, stat(var) by(year) tit(Variance of Log Earnings - female, unweighted) 
	graph export "${figs}/${mydate} reweight meta/logearn_var_unweighted_m0_rvl`rvl'.pdf", replace as(pdf)
	cellgraph lrearn_all_imputed if male==1, stat(var) by(year) tit(Variance of Log Earnings - male, unweighted) 
	graph export "${figs}/${mydate} reweight meta/logearn_var_unweighted_m1_rvl`rvl'.pdf", replace as(pdf)

	cellgraph lrearn_all_imputed if male==0 [aweight=weight], stat(var) by(year) tit(Variance of Log Earnings - Weighted) 
	graph export "${figs}/${mydate} reweight meta/logearn_var_weighted_m0_rvl`rvl'.pdf" , replace as(pdf)
	cellgraph lrearn_all_imputed if male==1 [aweight=weight], stat(var) by(year) tit(Variance of Log Earnings - Weighted) 
	graph export "${figs}/${mydate} reweight meta/logearn_var_weighted_m1_rvl`rvl'.pdf" , replace as(pdf)

	
//--- core code ---//	
			
	* settings
	//real minimum income threshold
	global wo_mini_inc_threshold=`womj'  			// !!! set to 1 for using REAL MINIMUM INCOME THRESHOLD w/o mini jobs, to 0 /w mini jobs !!!
	//data file options (data, data_01perc, siab, data_rw)
	global DATAFILEOPT="`dfopt'_rw${rvl}"
	//sample name (short, long, siab, short_rw)
	global vsample="`vs'_rw"

	* 0
	do "${do}0_Initialize.do"

	* 1	
	do "${do}1_Gen_Base_Sample_rw_v2.do"

	* 3
	do "${do}3_Inequality_rw_v2.do"

	* 7
	global vsample="`vs'_rw"
	do "${do}7_Paper_Figs_${vsample}.do"
	
end // reweighted_analysis	

/*-------------------------------------------------------*/
/* Pre-Reweighted Analysis Meta Graphs */
/*-------------------------------------------------------*/
capture program drop pre_reweighted_analysis_meta
program define pre_reweighted_analysis_meta /* options: vs(str) dfopt(str) [rwvl(int 1) womj(int 0)] */
	syntax, vs(str) dfopt(str) [rwvl(int 1) womj(int 0)]
	
	local rvl=`rwvl'
	if `rwvl'==5 local rvl=5b
	
//--- init ---//	
	
	* sample settings
	global vsample="`vs'"			
	if "${vsample}"=="short" global yrsample=2001
	if "${vsample}"=="long" global yrsample=1993
	if "${vsample}"=="siab" global yrsample=1975
	global rvl="`rwvl'"		
	global wo_mini_inc_threshold=`womj'
	global DATAFILEOPT="`dfopt'_rw${rvl}"	
	

	* do files needed
	run "${do}/0_Initialize"
	run "${do}/myplotsettings"	
	
	* load and set folder
	cap mkdir "${figs}/${mydate} pre-reweight meta graphs/"
	use "${data}/clean_yearly_`dfopt'", clear
	
	* locals plot settings
	local colors1 blue
	local colors2 blue red
	local colors3 blue red black
	local colors4 blue red black green
	local colors5 blue red black green navy
	forval cn=1/5 {
		local fcolors`cn' = ""
		foreach co of local colors`cn' {
			local fcolors`cn' = "`fcolors`cn''" + " " + "`co'*0.25"
		}		
	}
	
	* prep variables (just to be sure)
	replace age=year-byear+1
	keep if age>=25 & age <=55
	drop if mi(earn_all_imputed)
	drop if year<2001 
	drop if year>2018
	cap recode educ4 (.=9)
	cap recode educ2 (.=9)
	
	
//--- matching varibles for weigh definition ---//
	
	* Matching variables:
	local weightvarlist = "age age3y educ2 educ4 nonger jobtype2 days_work_c" 
	
//--- meta graphs for reweighting ---//
	
	foreach var in `weightvarlist' {
		
		if ("`var'"=="age3y" | "`var'"=="age") local xsca = "38(1)43"
		if ("`var'"=="nonger") local xsca = "0(0.05)0.3"	
		if ("`var'"=="days_work_c") local xsca = "300(10)350 365"	
		if ("`var'"=="days_work_c") local xsca = "300(10)350 365"	
		
		if ("`var'"=="age3y" | "`var'"=="age" | "`var'"=="nonger" | "`var'"=="days_work_c") {
			forval i=0/1 {
				preserve
				keep if male==`i'
				keep year `var' 
				if ("`var'"=="age3y") {
					replace `var'=`var'+1.5 if `var'<=26
					replace `var'=`var'+1 if `var'>26 & `var'<54
					replace `var'=`var'+0.5 if `var'>=54
				}
				if ("`var'"=="days_work_c") replace days_work_c=365-days_work_c 
				collapse (mean) `var', by(year)
				gen rece = inlist(year,${receyears})	
				if ("`var'"=="age3y") local xlab = "Mean age (age groups)"
				if ("`var'"=="age") local xlab = "Mean age"
				if ("`var'"=="nonger") local xlab = "Share Non_German"	
				if ("`var'"=="days_work_c") local xlab = "Mean days in employment"	
				label var `var' "`xlab'"
				tw (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
					(connected `var' year  if year>=2001 & year<=2018, ///
        			lcolor(`colors1')  /// Line colors
        			lpattern(solid) ///
        			msymbol(O) /// Markers
        			mlcolor(`colors1')  /// Marker  line color
                    mfcolor(`fcolors1')  ///	Fill color
        			yaxis(2)  yscale(alt axis(2)) ///
                    ytitle("`xlab'", axis(2)) ///
                    ylabel(`xsca', axis(2)) ///
					),  ///
					xtitle("") ///
					xlabel(2000(2)2018, grid) ///		xaxis options					
					legend(off)  					
				graph export "${figs}/${mydate} pre-reweight meta graphs/`var'_decomposed_unweighted_m`i'_rvl`rvl'.pdf", replace as(pdf)
				restore		
			}	
		}
		
		if ("`var'"=="jobtype1") {
			forval i=0/1 {
				preserve
				keep year jobtype1 male 
				keep if male==`i'
				gen jt1=(jobtype1==1)
				gen jt2=(jobtype1==2)
				gen jt3=(jobtype1==3)
				keep year jt* 
				collapse (mean) jt1 jt2 jt3, by(year)
				gen rece = inlist(year,${receyears})
				label var jt1 "Full-time"
				label var jt2 "Part-time"
				label var jt3 "Mini-job"
				tw (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
					(connected jt1 jt2 jt3 year  if year>=2001 & year<=2018, ///
        			lcolor(`colors3')  /// Line colors
        			lpattern(solid longdash dash) ///
        			msymbol(O + S) /// Markers
        			mlcolor(`colors3')  /// Marker  line color
                    mfcolor(`fcolors3')  ///	Fill color
        			yaxis(2)  yscale(alt axis(2)) ///
                    ytitle("Shares of working time", axis(2)) ///
                    ylabel(0(0.2)1, axis(2)) ///
					),  ///
					xtitle("") ///
					xlabel(2000(2)2018, grid) ///		xaxis options					
					legend(position(9) order(2 "Full-time" 3 "Part-time" 4 "Mini-job"))  					
				graph export "${figs}/${mydate} pre-reweight meta graphs/`var'_decomposed_unweighted_m`i'_rvl`rvl'.pdf", replace as(pdf)
				restore	
			}	
		}

		if ("`var'"=="jobtype2") {
			forval i=0/1 {
				if (`i'==1) local lpos="9" 
				if (`i'==0) local lpos="11" 		
				preserve
				keep year jobtype2 male 
				keep if male==`i'
				gen jt1=(jobtype2==1)
				gen jt2=(jobtype2==2)
				gen jt3=(jobtype2==3)
				keep year jt* 
				collapse (mean) jt1 jt2 jt3, by(year)
				gen rece = inlist(year,${receyears})
				label var jt1 "Full-time"
				label var jt2 "Part-time"
				label var jt3 "Mini-job"
				tw (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
					(connected jt1 jt2 jt3 year  if year>=2001 & year<=2018, ///
        			lcolor(`colors3')  /// Line colors
        			lpattern(solid longdash dash) ///
        			msymbol(O + S) /// Markers
        			mlcolor(`colors3')  /// Marker  line color
                    mfcolor(`fcolors3')  ///	Fill color
        			yaxis(2)  yscale(alt axis(2)) ///
                    ytitle("Shares of working time", axis(2)) ///
                    ylabel(0(0.2)1, axis(2)) ///
					),  ///
					xtitle("") ///
					xlabel(2000(2)2018, grid) ///		xaxis options					
					legend(position(`lpos') order(2 "Full-time" 3 "Part-time" 4 "Mini-job"))  					
				graph export "${figs}/${mydate} pre-reweight meta graphs/`var'_decomposed_unweighted_m`i'_rvl`rvl'.pdf", replace as(pdf)
				restore		
			}	
		}
		
		if "`var'"=="educ4" {
			forval i=0/1 {
				preserve
				keep if male==`i'				
				keep year educ4  
				gen ed1=educ4==1
				gen ed2=educ4==2
				gen ed3=educ4==3
				gen ed4=educ4==4
				gen ed5=educ4==9
				collapse (mean) ed1 ed2 ed3 ed4 ed5, by(year)
				gen rece = inlist(year,${receyears})
				label var ed1 "No professional qualification"
				label var ed2 "Lower secondary + professional qualification"
				label var ed3 "Higher secondary + professional qualification"
				label var ed4 "College or univeristy degree"
				label var ed5 "Missing"
				tw (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
					(connected ed1 ed2 ed3 ed4 ed5 year if year>=2001 & year<=2018, ///
        			lcolor(`colors5')  /// Line colors
        			lpattern(solid longdash dash dash_dot) ///
        			msymbol(O + S X) /// Markers
        			mlcolor(`colors5')  /// Marker  line color
                    mfcolor(`fcolors5')  ///	Fill color
        			yaxis(2)  yscale(alt axis(2)) ///
                    ytitle("Shares of educational attainment", axis(2)) ///
                    ylabel(0(0.2)1, axis(2)) ///
					),  ///
					xtitle("") ///
					xlabel(2000(2)2018, grid) ///		xaxis options					
					legend(position(9) order(2 "Lower secondary" 3 "Voc. training" 4 "Abitur (+ voc. training)" 5 "College degree"))  
				graph export "${figs}/${mydate} pre-reweight meta graphs/`var'_decomposed_unweighted_m`i'_rvl`rvl'_v2.pdf", replace as(pdf)
				restore	
			}	
		}
		
		if "`var'"=="educ2" {
			forval i=0/1 {
				preserve
				keep if male==`i'				
				keep year educ2  
				gen ed1=educ2==1
				gen ed2=educ2==2 
				collapse (mean) ed1 ed2, by(year)
				gen rece = inlist(year,${receyears})
				label var ed1 "college or univeristy degree"
				label var ed2 "all but college degree"
				tw (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
					(connected ed1 ed2 year if year>=2001 & year<=2018, ///
        			lcolor(`colors2')  /// Line colors
        			lpattern(solid longdash) ///
        			msymbol(O S) /// Markers
        			mlcolor(`colors2')  /// Marker  line color
                    mfcolor(`fcolors2')  ///	Fill color
        			yaxis(2)  yscale(alt axis(2)) ///
                    ytitle("Shares of educational attainment", axis(2)) ///
                    ylabel(0(0.2)1, axis(2)) ///
					),  ///
					xtitle("") ///
					xlabel(2000(2)2018, grid) ///		xaxis options					
					legend(position(9) order(2 "College degree" 3 "No college degree"))  
				graph export "${figs}/${mydate} pre-reweight meta graphs/`var'_decomposed_unweighted_m`i'_rvl`rvl'_v2.pdf", replace as(pdf)
				restore	
			}	
		}

		if ("`var'"=="days_work_c") {
			forval i=0/1 {		
				*
				preserve
				replace days_work_c=365-days_work_c
				cap drop days_weight
				gen days_weight=365/days_work_c
				gen dw_above_med=.
				forval yy=2001/2018 {
					sum rearn_all_imputed [aw=days_weight] if year==`yy', de
					replace dw_above_med=1 if year==`yy' & rearn_all_imputed>r(p50)
					replace dw_above_med=0 if year==`yy' & rearn_all_imputed<r(p50)
				}
				keep year male days_work_c dw_above_med
				keep if male==`i'
				gen dw_above=.
				replace dw_above=days_work_c if dw_above_med==1
				gen dw_below=.
				replace dw_below=days_work_c if dw_above_med==0 
				collapse (mean) days_work_c dw_above dw_below, by(year)
				tab year, sum(days_work_c)
				tab year, sum(dw_above)
				tab year, sum(dw_below)
				gen rece = inlist(year,${receyears})
				tw (bar rece year, c(l) color(gray*0.5) yscale(off)) ///
					(connected days_work_c dw_above dw_below year  if year>=2001 & year<=2018, ///
        			lcolor(`colors3')  /// Line colors
        			lpattern(solid longdash dash) ///
        			msymbol(O + S) /// Markers
        			mlcolor(`colors3')  /// Marker  line color
                    mfcolor(`fcolors3')  ///	Fill color
        			yaxis(2)  yscale(alt axis(2)) ///
                    ytitle("Days in employement", axis(2)) ///
                    ylabel(260(20)340 365, axis(2)) ///
					),  ///
					xtitle("") ///
					xlabel(2000(2)2018, grid) ///		xaxis options					
					legend(position(5) order(2 "All" 3 "Above median earnings" 4 "Below median earnings"))  					
				graph export "${figs}/${mydate} pre-reweight meta graphs/`var'_decomposedMed2_unweighted_m`i'_rvl`rvl'.pdf", replace as(pdf)
				restore			
			}	
		}		
		
	}
	
	clear
	
end // pre_reweighted_analysis_meta
		

	
/*---------------------------------------------------------*/
/* Run Main Program */
/*---------------------------------------------------------*/
main // run main program

cap log close _all
set trace off
clear
exit

/*========================================= END ==============================================*/
